/* ---------------------------------------------------- */
/*  Generated by Enterprise Architect Version 15.2 		*/
/*  Created On : 04-May-2022 21:43:55 				*/
/*  DBMS       : PostgreSQL 						*/
/* ---------------------------------------------------- */

/* Drop Tables */

DROP TABLE IF EXISTS "Dataformattype" CASCADE
;

/* Create Tables */

CREATE TABLE "Dataformattype"
(
	"DataformattypeID" varchar NOT NULL
)
;

/* Create Primary Keys, Indexes, Uniques, Checks */

ALTER TABLE "Dataformattype" ADD CONSTRAINT "PK_Dataformattype"
	PRIMARY KEY ("DataformattypeID")
;

/* Create Table Comments, Sequences for Autonumber Columns */

COMMENT ON TABLE "Dataformattype"
	IS 'Data format codelist'
;