/* ---------------------------------------------------- */
/*  Generated by Enterprise Architect Version 15.2 		*/
/*  Created On : 04-May-2022 21:43:56 				*/
/*  DBMS       : PostgreSQL 						*/
/* ---------------------------------------------------- */

/* Drop Tables */

DROP TABLE IF EXISTS "Equipment-valid" CASCADE
;

/* Create Tables */

CREATE TABLE "Equipment-valid"
(
	"Equipment-validID" varchar NOT NULL
)
;

/* Create Primary Keys, Indexes, Uniques, Checks */

ALTER TABLE "Equipment-valid" ADD CONSTRAINT "PK_Equipment-valid"
	PRIMARY KEY ("Equipment-validID")
;

/* Create Table Comments, Sequences for Autonumber Columns */

COMMENT ON TABLE "Equipment-valid"
	IS 'XML encodings of Equipment shall conform to the XML form for Equipment specified in the WMDR XML Schema.'
;