/* ---------------------------------------------------- */
/*  Generated by Enterprise Architect Version 15.2 		*/
/*  Created On : 04-May-2022 21:43:55 				*/
/*  DBMS       : PostgreSQL 						*/
/* ---------------------------------------------------- */

/* Drop Tables */

DROP TABLE IF EXISTS "Attribution" CASCADE
;

/* Create Tables */

CREATE TABLE "Attribution"
(
	"Originator" varchar NULL,	-- Identifies the individual and/or organization at the origin of the resource. This is typically the owner of the ressource, e.g., a data set.
	"Originatorurl" varchar NULL,
	"Source" varchar NULL,
	"Title" varchar NULL,	-- The title of the attributed work.
	"AttributionID" varchar NOT NULL
)
;

/* Create Primary Keys, Indexes, Uniques, Checks */

ALTER TABLE "Attribution" ADD CONSTRAINT "PK_Attribution"
	PRIMARY KEY ("AttributionID")
;

/* Create Table Comments, Sequences for Autonumber Columns */

COMMENT ON COLUMN "Attribution"."Originator"
	IS 'Identifies the individual and/or organization at the origin of the resource. This is typically the owner of the ressource, e.g., a data set.'
;

COMMENT ON COLUMN "Attribution"."Title"
	IS 'The title of the attributed work.'
;