/* ---------------------------------------------------- */
/*  Generated by Enterprise Architect Version 15.2 		*/
/*  Created On : 04-May-2022 21:43:56 				*/
/*  DBMS       : PostgreSQL 						*/
/* ---------------------------------------------------- */

/* Drop Tables */

DROP TABLE IF EXISTS "Instrumentoperatingstatus" CASCADE
;

/* Create Tables */

CREATE TABLE "Instrumentoperatingstatus"
(
	"Instrumentoperatingstatus" varchar NULL,
	"Validperiod" varchar NULL,	-- The time period for which the specified instrumentOperatingStatus is known to be valid. Normally, this will be specified as a "from" date, implying that the validity extends but does not include the next instrumentOperatingStatus on record. If only one instrumentOperatingStatus is specified for an equipment, the time stamp is optional.
	"InstrumentoperatingstatusID" varchar NOT NULL
)
;

/* Create Primary Keys, Indexes, Uniques, Checks */

ALTER TABLE "Instrumentoperatingstatus" ADD CONSTRAINT "PK_Instrumentoperatingstatus"
	PRIMARY KEY ("InstrumentoperatingstatusID")
;

/* Create Table Comments, Sequences for Autonumber Columns */

COMMENT ON COLUMN "Instrumentoperatingstatus"."Validperiod"
	IS 'The time period for which the specified instrumentOperatingStatus is known to be valid. Normally, this will be specified as a "from" date, implying that the validity extends but does not include the next instrumentOperatingStatus on record. If only one instrumentOperatingStatus is specified for an equipment, the time stamp is optional.'
;