/* ---------------------------------------------------- */
/*  Generated by Enterprise Architect Version 15.2 		*/
/*  Created On : 04-May-2022 21:43:58 				*/
/*  DBMS       : PostgreSQL 						*/
/* ---------------------------------------------------- */

/* Drop Tables */

DROP TABLE IF EXISTS "Well-formed" CASCADE
;

/* Create Tables */

CREATE TABLE "Well-formed"
(
	"Well-formedID" varchar NOT NULL
)
;

/* Create Primary Keys, Indexes, Uniques, Checks */

ALTER TABLE "Well-formed" ADD CONSTRAINT "PK_Well-formed"
	PRIMARY KEY ("Well-formedID")
;

/* Create Table Comments, Sequences for Autonumber Columns */

COMMENT ON TABLE "Well-formed"
	IS 'XML encodings of WMDR shall be well formed XML documents (syntactically correct). A well-formed XML document conforms to the XML specification. (https://www.w3.org/TR/REC-xml/ )'
;