/* ---------------------------------------------------- */
/*  Generated by Enterprise Architect Version 15.2 		*/
/*  Created On : 04-May-2022 21:43:55 				*/
/*  DBMS       : PostgreSQL 						*/
/* ---------------------------------------------------- */

/* Drop Tables */

DROP TABLE IF EXISTS "EquipmentEquipment" CASCADE
;

/* Create Tables */

CREATE TABLE "EquipmentEquipment"
(
	"subEquipment" varchar NULL,
	"EquipmentID" varchar NULL
)
;

/* Create Foreign Key Constraints */

ALTER TABLE "EquipmentEquipment" ADD CONSTRAINT "FK_EquipmentEquipment_subEquipment"
	FOREIGN KEY ("subEquipment") REFERENCES "Equipment" ("EquipmentID") ON DELETE No Action ON UPDATE No Action
;

ALTER TABLE "EquipmentEquipment" ADD CONSTRAINT "FK_EquipmentEquipment_Equipment"
	FOREIGN KEY ("EquipmentID") REFERENCES "Equipment" ("EquipmentID") ON DELETE No Action ON UPDATE No Action
;