/* ---------------------------------------------------- */
/*  Generated by Enterprise Architect Version 15.2 		*/
/*  Created On : 04-May-2022 21:43:56 				*/
/*  DBMS       : PostgreSQL 						*/
/* ---------------------------------------------------- */

/* Drop Tables */

DROP TABLE IF EXISTS "Observation-observed-property" CASCADE
;

/* Create Tables */

CREATE TABLE "Observation-observed-property"
(
	"Observation-observed-propertyID" varchar NOT NULL
)
;

/* Create Primary Keys, Indexes, Uniques, Checks */

ALTER TABLE "Observation-observed-property" ADD CONSTRAINT "PK_Observation-observed-property"
	PRIMARY KEY ("Observation-observed-propertyID")
;

/* Create Table Comments, Sequences for Autonumber Columns */

COMMENT ON TABLE "Observation-observed-property"
	IS 'The value for om:observedProperty (observed variable) shall be taken from the code table published online at http://codes.wmo.int/common/wmdr/ObservedVariable'
;