/* ---------------------------------------------------- */
/*  Generated by Enterprise Architect Version 15.2 		*/
/*  Created On : 04-May-2022 21:43:58 				*/
/*  DBMS       : PostgreSQL 						*/
/* ---------------------------------------------------- */

/* Drop Tables */

DROP TABLE IF EXISTS "Xml-rules" CASCADE
;

/* Create Tables */

CREATE TABLE "Xml-rules"
(
	"Xml-rules" varchar NULL,
	"Xml-rulesID" varchar NOT NULL
)
;

/* Create Primary Keys, Indexes, Uniques, Checks */

ALTER TABLE "Xml-rules" ADD CONSTRAINT "PK_Xml-rules"
	PRIMARY KEY ("Xml-rulesID")
;