/* ---------------------------------------------------- */
/*  Generated by Enterprise Architect Version 15.2 		*/
/*  Created On : 04-May-2022 21:43:58 				*/
/*  DBMS       : PostgreSQL 						*/
/* ---------------------------------------------------- */

/* Drop Tables */

DROP TABLE IF EXISTS "Valid-local-references" CASCADE
;

/* Create Tables */

CREATE TABLE "Valid-local-references"
(
	"Valid-local-referencesID" varchar NOT NULL
)
;

/* Create Primary Keys, Indexes, Uniques, Checks */

ALTER TABLE "Valid-local-references" ADD CONSTRAINT "PK_Valid-local-references"
	PRIMARY KEY ("Valid-local-referencesID")
;

/* Create Table Comments, Sequences for Autonumber Columns */

COMMENT ON TABLE "Valid-local-references"
	IS 'Where xlink:href is used to refer to a local object (using the #id notation) there must be a corresponding object with gml:id equal to "id" in the same XML document.

Where xlink:href is used to make a reference to a non-local object, e.g. using a WIGOS identifier or a link to a term in a codelist then this is not applicable.'
;