/* ---------------------------------------------------- */
/*  Generated by Enterprise Architect Version 15.2 		*/
/*  Created On : 04-May-2022 21:43:55 				*/
/*  DBMS       : PostgreSQL 						*/
/* ---------------------------------------------------- */

/* Drop Tables */

DROP TABLE IF EXISTS "Altitude-or-depth" CASCADE
;

/* Create Tables */

CREATE TABLE "Altitude-or-depth"
(
	"Altitude-or-depthID" varchar NOT NULL
)
;

/* Create Primary Keys, Indexes, Uniques, Checks */

ALTER TABLE "Altitude-or-depth" ADD CONSTRAINT "PK_Altitude-or-depth"
	PRIMARY KEY ("Altitude-or-depthID")
;

/* Create Table Comments, Sequences for Autonumber Columns */

COMMENT ON TABLE "Altitude-or-depth"
	IS 'The value for altitudeOrDepth, if supplied, shall be taken from the code table published online at http://codes.wmo.int/common/wmdr/AltitudeOrDepth.

This codelist is also described in the WIGOS Metadata Standard, Chapter VII.'
;