/* ---------------------------------------------------- */
/*  Generated by Enterprise Architect Version 15.2 		*/
/*  Created On : 04-May-2022 21:43:58 				*/
/*  DBMS       : PostgreSQL 						*/
/* ---------------------------------------------------- */

/* Drop Tables */

DROP TABLE IF EXISTS "Wmo-region" CASCADE
;

/* Create Tables */

CREATE TABLE "Wmo-region"
(
	"Wmo-regionID" varchar NOT NULL
)
;

/* Create Primary Keys, Indexes, Uniques, Checks */

ALTER TABLE "Wmo-region" ADD CONSTRAINT "PK_Wmo-region"
	PRIMARY KEY ("Wmo-regionID")
;

/* Create Table Comments, Sequences for Autonumber Columns */

COMMENT ON TABLE "Wmo-region"
	IS 'The value for wmoRegion shall be taken from the code table published online at http://codes.wmo.int/common/wmdr/WMORegion.


This codelist is also described in the WIGOS Metadata Standard, Chapter VII.'
;