/* ---------------------------------------------------- */
/*  Generated by Enterprise Architect Version 15.2 		*/
/*  Created On : 04-May-2022 21:43:57 				*/
/*  DBMS       : PostgreSQL 						*/
/* ---------------------------------------------------- */

/* Drop Tables */

DROP TABLE IF EXISTS "Representativenesstype" CASCADE
;

/* Create Tables */

CREATE TABLE "Representativenesstype"
(
	"RepresentativenesstypeID" varchar NOT NULL
)
;

/* Create Primary Keys, Indexes, Uniques, Checks */

ALTER TABLE "Representativenesstype" ADD CONSTRAINT "PK_Representativenesstype"
	PRIMARY KEY ("RepresentativenesstypeID")
;

/* Create Table Comments, Sequences for Autonumber Columns */

COMMENT ON TABLE "Representativenesstype"
	IS 'Representativeness codelist.'
;