INSERT INTO public.wx_stationprofile (id,created_at,updated_at,"name",description,color,is_automatic,is_manual) VALUES
	 (1,'2015-01-21 18:01:29+01','2020-05-23 00:38:34.222+02','Climat','Weather stations measuring Rainfall and or Temperature','#005B96',true,true),
	 (2,'2015-01-21 18:01:29+01','2020-05-23 01:00:58.04+02','Agro-Met','Weather stations measuring elements supporting agriculture','#008860',true,true),
	 (3,'2015-01-21 18:01:29+01','2020-05-23 00:39:02.568+02','Rainfall','HOBO rainfall stations from ONSET','#3BD6C6',true,true),
	 (4,'2016-04-01 03:58:36+02','2020-05-23 00:39:27.835+02','Aviation','Weather station measuring parameters supporting aviation','#f9f008',true,true),
	 (5,'2016-04-01 04:05:09+02','2020-05-23 00:40:10.979+02','Met','Weather stations measuring all basic meteorological elements; Rainfall, Temperature, Relative Humidity, Wind Speed and Direction(10m), Atmospheric Pressure and Solar Radiation','#FFC621',true,true),
	 (6,'2019-04-17 02:08:43.943+02','2020-05-23 00:44:03.598+02','Hydro-Met','Weather stations measuring elements supporting hydrological service, such as water levels of rivers/sea and water quality','black',true,true);