/* ---------------------------------------------------- */
/*  Generated by Enterprise Architect Version 15.2 		*/
/*  Created On : 04-May-2022 21:43:56 				*/
/*  DBMS       : PostgreSQL 						*/
/* ---------------------------------------------------- */

/* Drop Tables */

DROP TABLE IF EXISTS "FacilitySetObservingFacility" CASCADE
;

/* Create Tables */

CREATE TABLE "FacilitySetObservingFacility"
(
	facility varchar NULL,
	"facilitySet" varchar NULL
)
;

/* Create Foreign Key Constraints */

ALTER TABLE "FacilitySetObservingFacility" ADD CONSTRAINT "FK_FacilitySetObservingFacility_facility"
	FOREIGN KEY (facility) REFERENCES "Observingfacility" ("ObservingfacilityID") ON DELETE No Action ON UPDATE No Action
;

ALTER TABLE "FacilitySetObservingFacility" ADD CONSTRAINT "FK_FacilitySetObservingFacility_facilitySet"
	FOREIGN KEY ("facilitySet") REFERENCES "Facilityset" ("FacilitysetID") ON DELETE No Action ON UPDATE No Action
;