/* ---------------------------------------------------- */
/*  Generated by Enterprise Architect Version 15.2 		*/
/*  Created On : 04-May-2022 21:43:56 				*/
/*  DBMS       : PostgreSQL 						*/
/* ---------------------------------------------------- */

/* Drop Tables */

DROP TABLE IF EXISTS "Facilityset" CASCADE
;

/* Create Tables */

CREATE TABLE "Facilityset"
(
	"FacilitysetID" varchar NOT NULL
)
;

/* Create Primary Keys, Indexes, Uniques, Checks */

ALTER TABLE "Facilityset" ADD CONSTRAINT "PK_Facilityset"
	PRIMARY KEY ("FacilitysetID")
;

/* Create Table Comments, Sequences for Autonumber Columns */

COMMENT ON TABLE "Facilityset"
	IS 'A set of associated ObservingFacilities. Association (grouping) criteria can vary and maybe program/network specific. Examples: In GAW, some Global stations consist of several distinct observing facilities; The NASA A-Train may be considered a FacilitySet comprised of several individual satellites.'
;