/* ---------------------------------------------------- */
/*  Generated by Enterprise Architect Version 15.2 		*/
/*  Created On : 04-May-2022 21:43:56 				*/
/*  DBMS       : PostgreSQL 						*/
/* ---------------------------------------------------- */

/* Drop Tables */

DROP TABLE IF EXISTS "Metadata-record" CASCADE
;

/* Create Tables */

CREATE TABLE "Metadata-record"
(
	"Metadata-record" varchar NULL,
	"Metadata-recordID" varchar NOT NULL
)
;

/* Create Primary Keys, Indexes, Uniques, Checks */

ALTER TABLE "Metadata-record" ADD CONSTRAINT "PK_Metadata-record"
	PRIMARY KEY ("Metadata-recordID")
;