/* ---------------------------------------------------- */
/*  Generated by Enterprise Architect Version 15.2 		*/
/*  Created On : 04-May-2022 21:43:56 				*/
/*  DBMS       : PostgreSQL 						*/
/* ---------------------------------------------------- */

/* Drop Tables */

DROP TABLE IF EXISTS "Level-of-data" CASCADE
;

/* Create Tables */

CREATE TABLE "Level-of-data"
(
	"Level-of-dataID" varchar NOT NULL
)
;

/* Create Primary Keys, Indexes, Uniques, Checks */

ALTER TABLE "Level-of-data" ADD CONSTRAINT "PK_Level-of-data"
	PRIMARY KEY ("Level-of-dataID")
;

/* Create Table Comments, Sequences for Autonumber Columns */

COMMENT ON TABLE "Level-of-data"
	IS 'The value for levelOfData, if supplied, shall be taken from the code table published online at http://codes.wmo.int/common/wmdr/LevelOfData.


This codelist is also described in the WIGOS Metadata Standard, Chapter VII.'
;