/* ---------------------------------------------------- */
/*  Generated by Enterprise Architect Version 15.2 		*/
/*  Created On : 04-May-2022 21:43:56 				*/
/*  DBMS       : PostgreSQL 						*/
/* ---------------------------------------------------- */

/* Drop Tables */

DROP TABLE IF EXISTS "Instrument-operating-status" CASCADE
;

/* Create Tables */

CREATE TABLE "Instrument-operating-status"
(
	"Instrument-operating-statusID" varchar NOT NULL
)
;

/* Create Primary Keys, Indexes, Uniques, Checks */

ALTER TABLE "Instrument-operating-status" ADD CONSTRAINT "PK_Instrument-operating-status"
	PRIMARY KEY ("Instrument-operating-statusID")
;

/* Create Table Comments, Sequences for Autonumber Columns */

COMMENT ON TABLE "Instrument-operating-status"
	IS 'The value for instrumentOperatingStatus shall be taken from the code table published online at http://codes.wmo.int/common/wmdr/InstrumentOperatingStatus.


This codelist is also described in the WIGOS Metadata Standard, Chapter VII.'
;