INSERT INTO public.wx_station (id,created_at,updated_at,"name",alias_name,begin_date,end_date,longitude,latitude,elevation,code,wmo,wigos,is_active,is_automatic,organization,observer,watershed,z,datum,"zone",ground_water_province,river_code,river_course,catchment_area_station,river_origin,easting,northing,river_outlet,river_length,local_land_use,soil_type,site_description,land_surface_elevation,screen_length,top_casing_land_surface,depth_midpoint,screen_size,casing_type,casing_diameter,existing_gauges,flow_direction_at_station,flow_direction_above_station,flow_direction_below_station,bank_full_stage,bridge_level,access_point,temporary_benchmark,mean_sea_level,data_type,frequency_observation,historic_events,other_information,hydrology_station_type,is_surface,station_details,remarks,region,utc_offset_minutes,alternative_names,wmo_station_plataform,operation_status,communication_type_id,data_source_id,profile_id,wmo_program_id,wmo_region_id,wmo_station_type_id,relocation_date,network,reference_station_id,country_id) VALUES
	 (108,'2015-01-21 18:01:29+01','2022-07-08 17:38:16.894374+02','PGIA','PGIA CR1000','2014-10-01 02:00:00+02',NULL,-88.3127,17.5348,5.0,'9958303',NULL,NULL,true,true,NULL,NULL,'Belize River',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,false,NULL,'Belize','Belize',-360,NULL,NULL,true,4,1,4,NULL,NULL,NULL,NULL,NULL,NULL,18),
	 (14,'2015-01-21 18:01:29+01','2022-07-08 17:38:16.912349+02','Phillip Goldson Int''l Airport','Phillip Goldson Int''l Airport','1960-01-01 01:00:00+01',NULL,-88.3128,17.5349,5.0,'8858301',78583,NULL,true,false,NULL,NULL,'Belize River',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,true,NULL,'Belize','Belize',-360,NULL,NULL,true,5,1,2,NULL,NULL,NULL,NULL,NULL,NULL,18)
