/* ---------------------------------------------------- */
/*  Generated by Enterprise Architect Version 15.2 		*/
/*  Created On : 04-May-2022 21:43:56 				*/
/*  DBMS       : PostgreSQL 						*/
/* ---------------------------------------------------- */

/* Drop Tables */

DROP TABLE IF EXISTS "Observation-feature-of-interest" CASCADE
;

/* Create Tables */

CREATE TABLE "Observation-feature-of-interest"
(
	"Observation-feature-of-interestID" varchar NOT NULL
)
;

/* Create Primary Keys, Indexes, Uniques, Checks */

ALTER TABLE "Observation-feature-of-interest" ADD CONSTRAINT "PK_Observation-feature-of-interest"
	PRIMARY KEY ("Observation-feature-of-interestID")
;

/* Create Table Comments, Sequences for Autonumber Columns */

COMMENT ON TABLE "Observation-feature-of-interest"
	IS 'XML encodings of OM_Observation in WIGOS shall use O&M Spatial Sampling Features to describe the om:featureOfInterest as a feature with geometry describing the geometric location or range of the observations.'
;