/* ---------------------------------------------------- */
/*  Generated by Enterprise Architect Version 15.2 		*/
/*  Created On : 04-May-2022 21:43:57 				*/
/*  DBMS       : PostgreSQL 						*/
/* ---------------------------------------------------- */

/* Drop Tables */

DROP TABLE IF EXISTS "Polarizationtype" CASCADE
;

/* Create Tables */

CREATE TABLE "Polarizationtype"
(
	"PolarizationtypeID" varchar NOT NULL
)
;

/* Create Primary Keys, Indexes, Uniques, Checks */

ALTER TABLE "Polarizationtype" ADD CONSTRAINT "PK_Polarizationtype"
	PRIMARY KEY ("PolarizationtypeID")
;

/* Create Table Comments, Sequences for Autonumber Columns */

COMMENT ON TABLE "Polarizationtype"
	IS '5-03 Instrument specifications. This is a proxy for several more specific elements, her used for FeatureType "Frequencies". Polarization type (LHCP, RHCP, linear, LHCD&RHCP, single, dual)'
;