/* ---------------------------------------------------- */
/*  Generated by Enterprise Architect Version 15.2 		*/
/*  Created On : 04-May-2022 21:43:56 				*/
/*  DBMS       : PostgreSQL 						*/
/* ---------------------------------------------------- */

/* Drop Tables */

DROP TABLE IF EXISTS "Equipment-log-entries" CASCADE
;

/* Create Tables */

CREATE TABLE "Equipment-log-entries"
(
	"Equipment-log-entriesID" varchar NOT NULL
)
;

/* Create Primary Keys, Indexes, Uniques, Checks */

ALTER TABLE "Equipment-log-entries" ADD CONSTRAINT "PK_Equipment-log-entries"
	PRIMARY KEY ("Equipment-log-entriesID")
;

/* Create Table Comments, Sequences for Autonumber Columns */

COMMENT ON TABLE "Equipment-log-entries"
	IS 'Log entries in a EquipmentLog shall describe control checks or maintenance of the Equipment and shall conform to the XML forms for ControlCheckReport or MaintenanceReport in the WMDR XML Schema.'
;