/* ---------------------------------------------------- */
/*  Generated by Enterprise Architect Version 15.2 		*/
/*  Created On : 04-May-2022 21:43:57 				*/
/*  DBMS       : PostgreSQL 						*/
/* ---------------------------------------------------- */

/* Drop Tables */

DROP TABLE IF EXISTS "Observing-facility" CASCADE
;

/* Create Tables */

CREATE TABLE "Observing-facility"
(
	"Observing-facility" varchar NULL,
	"Observing-facilityID" varchar NOT NULL
)
;

/* Create Primary Keys, Indexes, Uniques, Checks */

ALTER TABLE "Observing-facility" ADD CONSTRAINT "PK_Observing-facility"
	PRIMARY KEY ("Observing-facilityID")
;