/* ---------------------------------------------------- */
/*  Generated by Enterprise Architect Version 15.2 		*/
/*  Created On : 04-May-2022 21:43:58 				*/
/*  DBMS       : PostgreSQL 						*/
/* ---------------------------------------------------- */

/* Drop Tables */

DROP TABLE IF EXISTS "Transmissionmodetype" CASCADE
;

/* Create Tables */

CREATE TABLE "Transmissionmodetype"
(
	"TransmissionmodetypeID" varchar NOT NULL
)
;

/* Create Primary Keys, Indexes, Uniques, Checks */

ALTER TABLE "Transmissionmodetype" ADD CONSTRAINT "PK_Transmissionmodetype"
	PRIMARY KEY ("TransmissionmodetypeID")
;

/* Create Table Comments, Sequences for Autonumber Columns */

COMMENT ON TABLE "Transmissionmodetype"
	IS '5-03 Instrument specifications. This is a proxy for several more specific elements, her used for Type "TransmissionModeType". TransmissionModeType uses values (pulsed, continuous-wave)'
;