Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    EAST_GRID_REF, NORTH_GRID_REF, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, 
    DEPLOYMENT_REMARK, LAT_WGS84, LON_WGS84)
 Values
   (2544, 838, '5592', 'DCNN', 94, 
    'T', 1, TO_DATE('01/01/2000', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'), 'OS', 
    484600, 166400, 51.38983, -0.784, 74, 
    'RELOAD OF DEPLOYMENT DATA FROM MIRACLES 2003 BY R BEVAN', 51.39034, -0.78553);
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    EAST_GRID_REF, NORTH_GRID_REF, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, 
    DEPLOYMENT_REMARK, LAT_WGS84, LON_WGS84)
 Values
   (2545, 838, '5592', 'DCNN', 61, 
    'T', 3, TO_DATE('01/01/2000', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'), 'OS', 
    484600, 166400, 51.38983, -0.784, 74, 
    'RELOAD OF DEPLOYMENT DATA FROM MIRACLES 2003 BY R BEVAN', 51.39034, -0.78553);
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    EAST_GRID_REF, NORTH_GRID_REF, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, 
    DEPLOYMENT_REMARK, LAT_WGS84, LON_WGS84)
 Values
   (2515, 838, '5592', 'DCNN', 6, 
    'T', 5, TO_DATE('18/04/1995', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'), 'OS', 
    484600, 166400, 51.38983, -0.784, 74, 
    'BEGIN DATE SET TO SAMOS INSTALLATION DATE', 51.39034, -0.78553);
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    EAST_GRID_REF, NORTH_GRID_REF, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, 
    DEPLOYMENT_REMARK, LAT_WGS84, LON_WGS84)
 Values
   (2526, 838, '5592', 'DCNN', 2, 
    'T', 6, TO_DATE('18/04/1995', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'), 'OS', 
    484600, 166400, 51.38983, -0.784, 74, 
    'BEGIN DATE SET TO SAMOS INSTALLATION DATE', 51.39034, -0.78553);
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    EAST_GRID_REF, NORTH_GRID_REF, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, 
    DEPLOYMENT_REMARK, LAT_WGS84, LON_WGS84)
 Values
   (2540, 838, '5592', 'DCNN', 103, 
    'T', 11, TO_DATE('01/01/2000', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'), 'OS', 
    484600, 166400, 51.38983, -0.784, 74, 
    'RELOAD OF DEPLOYMENT DATA FROM MIRACLES 2003 BY R BEVAN', 51.39034, -0.78553);
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    EAST_GRID_REF, NORTH_GRID_REF, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, 
    DEPLOYMENT_REMARK, LAT_WGS84, LON_WGS84)
 Values
   (2520, 838, '5592', 'DCNN', 6, 
    'T', 17, TO_DATE('18/04/1995', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'), 'OS', 
    484600, 166400, 51.38983, -0.784, 74, 
    'BEGIN DATE SET TO SAMOS INSTALLATION DATE', 51.39034, -0.78553);
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    EAST_GRID_REF, NORTH_GRID_REF, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, 
    DEPLOYMENT_REMARK, LAT_WGS84, LON_WGS84)
 Values
   (2531, 838, '5592', 'DCNN', 5, 
    'T', 18, TO_DATE('18/04/1995', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'), 'OS', 
    484600, 166400, 51.38983, -0.784, 74, 
    'BEGIN DATE SET TO SAMOS INSTALLATION DATE', 51.39034, -0.78553);
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    EAST_GRID_REF, NORTH_GRID_REF, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, 
    DEPLOYMENT_REMARK, LAT_WGS84, LON_WGS84)
 Values
   (2519, 838, '5592', 'DCNN', 6, 
    'T', 23, TO_DATE('18/04/1995', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'), 'OS', 
    484600, 166400, 51.38983, -0.784, 74, 
    'BEGIN DATE SET TO SAMOS INSTALLATION DATE', 51.39034, -0.78553);
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    EAST_GRID_REF, NORTH_GRID_REF, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, 
    DEPLOYMENT_REMARK, LAT_WGS84, LON_WGS84)
 Values
   (2530, 838, '5592', 'DCNN', 5, 
    'T', 24, TO_DATE('18/04/1995', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'), 'OS', 
    484600, 166400, 51.38983, -0.784, 74, 
    'BEGIN DATE SET TO SAMOS INSTALLATION DATE', 51.39034, -0.78553);
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    EAST_GRID_REF, NORTH_GRID_REF, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, 
    DEPLOYMENT_REMARK, LAT_WGS84, LON_WGS84)
 Values
   (2542, 838, '5592', 'DCNN', 102, 
    'T', 33, TO_DATE('01/01/2000', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'), 'OS', 
    484600, 166400, 51.38983, -0.784, 74, 
    'RELOAD OF DEPLOYMENT DATA FROM MIRACLES 2003 BY R BEVAN', 51.39034, -0.78553);
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    EAST_GRID_REF, NORTH_GRID_REF, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, 
    DEPLOYMENT_REMARK, LAT_WGS84, LON_WGS84)
 Values
   (2517, 838, '5592', 'DCNN', 6, 
    'T', 37, TO_DATE('18/04/1995', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'), 'OS', 
    484600, 166400, 51.38983, -0.784, 74, 
    'BEGIN DATE SET TO SAMOS INSTALLATION DATE', 51.39034, -0.78553);
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    EAST_GRID_REF, NORTH_GRID_REF, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, 
    DEPLOYMENT_REMARK, LAT_WGS84, LON_WGS84)
 Values
   (2528, 838, '5592', 'DCNN', 4, 
    'T', 38, TO_DATE('18/04/1995', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'), 'OS', 
    484600, 166400, 51.38983, -0.784, 74, 
    'BEGIN DATE SET TO SAMOS INSTALLATION DATE', 51.39034, -0.78553);
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    EAST_GRID_REF, NORTH_GRID_REF, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, 
    DEPLOYMENT_REMARK, LAT_WGS84, LON_WGS84)
 Values
   (2518, 838, '5592', 'DCNN', 6, 
    'T', 39, TO_DATE('18/04/1995', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'), 'OS', 
    484600, 166400, 51.38983, -0.784, 74, 
    'BEGIN DATE SET TO SAMOS INSTALLATION DATE', 51.39034, -0.78553);
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    EAST_GRID_REF, NORTH_GRID_REF, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, 
    DEPLOYMENT_REMARK, LAT_WGS84, LON_WGS84)
 Values
   (2529, 838, '5592', 'DCNN', 5, 
    'T', 40, TO_DATE('18/04/1995', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'), 'OS', 
    484600, 166400, 51.38983, -0.784, 74, 
    'BEGIN DATE SET TO SAMOS INSTALLATION DATE', 51.39034, -0.78553);
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    EAST_GRID_REF, NORTH_GRID_REF, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, 
    DEPLOYMENT_REMARK, LAT_WGS84, LON_WGS84)
 Values
   (28848, 838, '272736', 'RAIN', 97, 
    'T', 43, TO_DATE('01/12/1991', 'DD/MM/YYYY'), TO_DATE('31/12/1992', 'DD/MM/YYYY'), 'OS', 
    484600, 166400, 51.38983, -0.784, 74, 
    'OLD RAIN GAUGE DATA LOADED BY R BEVAN 17/6/2003. ALL WADRAIN SITES ASSUMED TO BE 127MM GAUGE', 51.39034, -0.78553);
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    EAST_GRID_REF, NORTH_GRID_REF, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, 
    DEPLOYMENT_REMARK, LAT_WGS84, LON_WGS84)
 Values
   (28847, 838, '272734', 'RAIN', 97, 
    'T', 43, TO_DATE('01/01/1995', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'), 'OS', 
    484600, 166400, 51.38983, -0.784, 74, 
    'OLD RAIN GAUGE DATA LOADED BY R BEVAN 17/6/2003. ALL WADRAIN SITES ASSUMED TO BE 127MM GAUGE', 51.39034, -0.78553);
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    EAST_GRID_REF, NORTH_GRID_REF, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, 
    DEPLOYMENT_REMARK, LAT_WGS84, LON_WGS84)
 Values
   (2538, 838, '272737', 'RAIN', 50, 
    'T', 43, TO_DATE('01/01/2000', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'), 'OS', 
    484600, 166400, 51.38983, -0.784, 74, 
    'RELOAD OF DEPLOYMENT DATA FROM MIRACLES 2003 BY R BEVAN', 51.39034, -0.78553);
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    EAST_GRID_REF, NORTH_GRID_REF, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, 
    DEPLOYMENT_REMARK, LAT_WGS84, LON_WGS84)
 Values
   (2539, 838, '272737', 'RAIN', 96, 
    'T', 43, TO_DATE('01/01/2000', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'), 'OS', 
    484600, 166400, 51.38983, -0.784, 74, 
    'RELOAD OF DEPLOYMENT DATA FROM MIRACLES 2003 BY R BEVAN', 51.39034, -0.78553);
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    EAST_GRID_REF, NORTH_GRID_REF, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, 
    DEPLOYMENT_REMARK, LAT_WGS84, LON_WGS84)
 Values
   (2537, 838, '272737', 'RAIN', 97, 
    'T', 43, TO_DATE('01/01/2000', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'), 'OS', 
    484600, 166400, 51.38983, -0.784, 74, 
    'RELOAD OF DEPLOYMENT DATA FROM MIRACLES 2003 BY R BEVAN', 51.39034, -0.78553);
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    EAST_GRID_REF, NORTH_GRID_REF, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, 
    DEPLOYMENT_REMARK, LAT_WGS84, LON_WGS84)
 Values
   (34478, 838, '272735', 'RAIN', 96, 
    'T', 44, TO_DATE('01/01/1978', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'), 'OS', 
    484600, 166400, 51.38983, -0.784, 74, 
    'OLD RAIN GAUGE DATA LOADED BY R BEVAN 17/6/2003. ALL SSER SITES ASSUMED TO BE TBR GAUGE', 51.39034, -0.78553);
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    EAST_GRID_REF, NORTH_GRID_REF, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, 
    DEPLOYMENT_REMARK, LAT_WGS84, LON_WGS84)
 Values
   (2525, 838, '5592', 'DCNN', 6, 
    'T', 55, TO_DATE('01/01/2000', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'), 'OS', 
    484600, 166400, 51.38983, -0.784, 74, 
    'RELOAD OF DEPLOYMENT DATA FROM MIRACLES 2003 BY R BEVAN', 51.39034, -0.78553);
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    EAST_GRID_REF, NORTH_GRID_REF, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, 
    DEPLOYMENT_REMARK, LAT_WGS84, LON_WGS84)
 Values
   (2536, 838, '5592', 'DCNN', 2, 
    'T', 55, TO_DATE('01/01/2000', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'), 'OS', 
    484600, 166400, 51.38983, -0.784, 74, 
    'RELOAD OF DEPLOYMENT DATA FROM MIRACLES 2003 BY R BEVAN', 51.39034, -0.78553);
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    EAST_GRID_REF, NORTH_GRID_REF, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, 
    DEPLOYMENT_REMARK, LAT_WGS84, LON_WGS84)
 Values
   (2535, 838, '5592', 'DCNN', 2, 
    'T', 57, TO_DATE('01/01/2000', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'), 'OS', 
    484600, 166400, 51.38983, -0.784, 74, 
    'RELOAD OF DEPLOYMENT DATA FROM MIRACLES 2003 BY R BEVAN', 51.39034, -0.78553);
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    EAST_GRID_REF, NORTH_GRID_REF, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, 
    DEPLOYMENT_REMARK, LAT_WGS84, LON_WGS84)
 Values
   (2524, 838, '5592', 'DCNN', 6, 
    'T', 57, TO_DATE('01/01/2000', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'), 'OS', 
    484600, 166400, 51.38983, -0.784, 74, 
    'RELOAD OF DEPLOYMENT DATA FROM MIRACLES 2003 BY R BEVAN', 51.39034, -0.78553);
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    EAST_GRID_REF, NORTH_GRID_REF, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, 
    DEPLOYMENT_REMARK, LAT_WGS84, LON_WGS84)
 Values
   (2534, 838, '5592', 'DCNN', 2, 
    'T', 59, TO_DATE('01/01/2000', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'), 'OS', 
    484600, 166400, 51.38983, -0.784, 74, 
    'RELOAD OF DEPLOYMENT DATA FROM MIRACLES 2003 BY R BEVAN', 51.39034, -0.78553);
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    EAST_GRID_REF, NORTH_GRID_REF, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, 
    DEPLOYMENT_REMARK, LAT_WGS84, LON_WGS84)
 Values
   (2523, 838, '5592', 'DCNN', 6, 
    'T', 59, TO_DATE('01/01/2000', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'), 'OS', 
    484600, 166400, 51.38983, -0.784, 74, 
    'RELOAD OF DEPLOYMENT DATA FROM MIRACLES 2003 BY R BEVAN', 51.39034, -0.78553);
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    EAST_GRID_REF, NORTH_GRID_REF, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, 
    DEPLOYMENT_REMARK, LAT_WGS84, LON_WGS84)
 Values
   (2522, 838, '5592', 'DCNN', 6, 
    'T', 61, TO_DATE('01/01/2000', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'), 'OS', 
    484600, 166400, 51.38983, -0.784, 74, 
    'RELOAD OF DEPLOYMENT DATA FROM MIRACLES 2003 BY R BEVAN', 51.39034, -0.78553);
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    EAST_GRID_REF, NORTH_GRID_REF, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, 
    DEPLOYMENT_REMARK, LAT_WGS84, LON_WGS84)
 Values
   (2533, 838, '5592', 'DCNN', 3, 
    'T', 61, TO_DATE('01/01/2000', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'), 'OS', 
    484600, 166400, 51.38983, -0.784, 74, 
    'RELOAD OF DEPLOYMENT DATA FROM MIRACLES 2003 BY R BEVAN', 51.39034, -0.78553);
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    EAST_GRID_REF, NORTH_GRID_REF, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, 
    DEPLOYMENT_REMARK, LAT_WGS84, LON_WGS84)
 Values
   (2521, 838, '5592', 'DCNN', 6, 
    'T', 63, TO_DATE('01/01/2000', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'), 'OS', 
    484600, 166400, 51.38983, -0.784, 74, 
    'RELOAD OF DEPLOYMENT DATA FROM MIRACLES 2003 BY R BEVAN', 51.39034, -0.78553);
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    EAST_GRID_REF, NORTH_GRID_REF, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, 
    DEPLOYMENT_REMARK, LAT_WGS84, LON_WGS84)
 Values
   (2532, 838, '5592', 'DCNN', 3, 
    'T', 63, TO_DATE('01/01/2000', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'), 'OS', 
    484600, 166400, 51.38983, -0.784, 74, 
    'RELOAD OF DEPLOYMENT DATA FROM MIRACLES 2003 BY R BEVAN', 51.39034, -0.78553);
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    EAST_GRID_REF, NORTH_GRID_REF, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, 
    DEPLOYMENT_REMARK, LAT_WGS84, LON_WGS84)
 Values
   (2541, 838, '5592', 'DCNN', 95, 
    'T', 67, TO_DATE('01/01/2000', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'), 'OS', 
    484600, 166400, 51.38983, -0.784, 74, 
    'RELOAD OF DEPLOYMENT DATA FROM MIRACLES 2003 BY R BEVAN', 51.39034, -0.78553);
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    EAST_GRID_REF, NORTH_GRID_REF, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, 
    DEPLOYMENT_REMARK, LAT_WGS84, LON_WGS84)
 Values
   (537, 838, '5592', 'DCNN', 104, 
    'T', 67, TO_DATE('07/01/2001', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'), 'OS', 
    484600, 166400, 51.38983, -0.784, 74, 
    'DEPLOYMENT DERIVED FROM OBSERVATIONAL DATA HELD IN MIDAS; EQUIPMENT_TYPE ASSUMED; BEGIN DATE SET TO EARLIEST DATA IN MIDAS FOR OPEN CAPABILITY. GILL MACKINNON', 51.39034, -0.78553);
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    EAST_GRID_REF, NORTH_GRID_REF, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, 
    DEPLOYMENT_REMARK, LAT_WGS84, LON_WGS84)
 Values
   (2543, 838, '5592', 'DCNN', 62, 
    'T', 71, TO_DATE('01/01/2000', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'), 'OS', 
    484600, 166400, 51.38983, -0.784, 74, 
    'RELOAD OF DEPLOYMENT DATA FROM MIRACLES 2003 BY R BEVAN', 51.39034, -0.78553);
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    EAST_GRID_REF, NORTH_GRID_REF, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, 
    DEPLOYMENT_REMARK, LAT_WGS84, LON_WGS84)
 Values
   (2516, 838, '5592', 'DCNN', 6, 
    'T', 75, TO_DATE('18/04/1995', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'), 'OS', 
    484600, 166400, 51.38983, -0.784, 74, 
    'BEGIN DATE SET TO SAMOS INSTALLATION DATE', 51.39034, -0.78553);
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    EAST_GRID_REF, NORTH_GRID_REF, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, 
    DEPLOYMENT_REMARK, LAT_WGS84, LON_WGS84)
 Values
   (2527, 838, '5592', 'DCNN', 2, 
    'T', 76, TO_DATE('18/04/1995', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'), 'OS', 
    484600, 166400, 51.38983, -0.784, 74, 
    'BEGIN DATE SET TO SAMOS INSTALLATION DATE', 51.39034, -0.78553);
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    EAST_GRID_REF, NORTH_GRID_REF, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, 
    DEPLOYMENT_REMARK, LAT_WGS84, LON_WGS84)
 Values
   (10549, 838, '559101', 'WIND', 27, 
    'T', 77, TO_DATE('01/12/1991', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'), 'OS', 
    484750, 166200, 51.38801, -0.78189, 83, 
    ' OBSTRUCTION RECORDS 24/06/1995', 51.38852, -0.78342);
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    EAST_GRID_REF, NORTH_GRID_REF, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, 
    DEPLOYMENT_REMARK, LAT_WGS84, LON_WGS84)
 Values
   (10550, 838, '559101', 'WIND', 19, 
    'T', 79, TO_DATE('01/12/1991', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'), 'OS', 
    484750, 166200, 51.38801, -0.78189, 83, 
    ' OBSTRUCTION RECORDS 24/06/1995', 51.38852, -0.78342);
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    EAST_GRID_REF, NORTH_GRID_REF, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, 
    LAT_WGS84, LON_WGS84)
 Values
   (10551, 838, '559101', 'WIND', 19, 
    'T', 81, TO_DATE('01/12/1991', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'), 'OS', 
    484750, 166200, 51.38801, -0.78189, 83, 
    51.38852, -0.78342);
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    EAST_GRID_REF, NORTH_GRID_REF, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, 
    LAT_WGS84, LON_WGS84)
 Values
   (10548, 838, '559101', 'WIND', 27, 
    'T', 85, TO_DATE('01/12/1991', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'), 'OS', 
    484750, 166200, 51.38801, -0.78189, 83, 
    51.38852, -0.78342);
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    EAST_GRID_REF, NORTH_GRID_REF, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, 
    DEPLOYMENT_REMARK, LAT_WGS84, LON_WGS84)
 Values
   (22338, 838, '559201', 'WIND', 106, 
    'F', 97, TO_DATE('01/01/1965', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'), 'OS', 
    484600, 166400, 51.38983, -0.784, 74, 
    'DEPLOYMENT RECORD FOR INSPECTION_ITEM QUESTIONS ABOUT THE SITE', 51.39034, -0.78553);
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, DEPLOYMENT_REMARK, IPR_OWNER)
 Values
   (5210, 1605, '9885', 'DCNN', 93, 
    'T', 1, TO_DATE('01/01/2000', 'DD/MM/YYYY'), TO_DATE('18/03/2014', 'DD/MM/YYYY'), 'XX', 
    -15.933, -5.667, 435, 'RELOAD OF DEPLOYMENT DATA FROM MIRACLES 2003 BY R BEVAN', 'MET-OFFICE');
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, DEPLOYMENT_REMARK, IPR_OWNER)
 Values
   (76771, 1605, '9885', 'DCNN', 127, 
    'T', 1, TO_DATE('18/03/2014', 'DD/MM/YYYY'), TO_DATE('31/12/3999', 'DD/MM/YYYY'), 'XX', 
    -15.933, -5.667, 435, 'CONFIRMED INSTALLATION DATE', 'MET-OFFICE');
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, DEPLOYMENT_REMARK, IPR_OWNER)
 Values
   (5203, 1605, '9885', 'DCNN', 2, 
    'T', 5, TO_DATE('05/10/1992', 'DD/MM/YYYY'), TO_DATE('18/03/2014', 'DD/MM/YYYY'), 'XX', 
    -15.933, -5.667, 435, 'BEGIN DATE SET TO SAMOS INSTALLATION DATE', 'MET-OFFICE');
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, DEPLOYMENT_REMARK, IPR_OWNER)
 Values
   (76763, 1605, '9885', 'DCNN', 6, 
    'T', 5, TO_DATE('18/03/2014', 'DD/MM/YYYY'), TO_DATE('05/09/2017 10:06:00 AM', 'DD/MM/YYYY HH:MI:SS AM'), 'XX', 
    -15.933, -5.667, 435, 'CONFIRMED INSTALLATION DATE (MMS UPDATE)', 'MET-OFFICE');
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_ID, 
    EQUIPMENT_TYPE_ID, MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, 
    GRID_REF_TYPE, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, DEPLOYMENT_REMARK, 
    IPR_OWNER)
 Values
   (105234, 1605, '9885', 'DCNN', 12838, 
    6, 'T', 5, TO_DATE('05/09/2017 10:06:00 AM', 'DD/MM/YYYY HH:MI:SS AM'), TO_DATE('31/12/3999', 'DD/MM/YYYY'), 
    'XX', -15.933, -5.667, 435, 'MMS INSTALLATION', 
    'MET-OFFICE');
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_ID, 
    EQUIPMENT_TYPE_ID, MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, 
    GRID_REF_TYPE, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, DEPLOYMENT_REMARK, 
    IPR_OWNER)
 Values
   (112615, 1605, '9885', 'DCNN', 7265, 
    6, 'T', 6, TO_DATE('22/08/2018 10:24:00 AM', 'DD/MM/YYYY HH:MI:SS AM'), TO_DATE('28/08/2018 1:08:00 PM', 'DD/MM/YYYY HH:MI:SS AM'), 
    'XX', -15.933, -5.667, 435, 'MMS INSTALLATION (MMS UPDATE)', 
    'MET-OFFICE');
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_ID, 
    EQUIPMENT_TYPE_ID, MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, 
    GRID_REF_TYPE, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, DEPLOYMENT_REMARK, 
    IPR_OWNER)
 Values
   (122063, 1605, '9885', 'DCNN', 15120, 
    111, 'T', 9, TO_DATE('06/05/2020 8:57:00 AM', 'DD/MM/YYYY HH:MI:SS AM'), TO_DATE('31/12/3999', 'DD/MM/YYYY'), 
    'XX', -15.9422, -5.6676, 435, 'MMS INSTALLATION', 
    'MET-OFFICE');
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, DEPLOYMENT_REMARK, IPR_OWNER)
 Values
   (76770, 1605, '9885', 'DCNN', 111, 
    'T', 11, TO_DATE('18/03/2014', 'DD/MM/YYYY'), TO_DATE('17/08/2015 9:04:00 AM', 'DD/MM/YYYY HH:MI:SS AM'), 'XX', 
    -15.933, -5.667, 435, 'CONFIRMED INSTALLATION DATE (MMS UPDATE)', 'MET-OFFICE');
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_ID, 
    EQUIPMENT_TYPE_ID, MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, 
    GRID_REF_TYPE, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, DEPLOYMENT_REMARK, 
    IPR_OWNER)
 Values
   (83674, 1605, '9885', 'DCNN', 7887, 
    111, 'T', 11, TO_DATE('17/08/2015 9:04:00 AM', 'DD/MM/YYYY HH:MI:SS AM'), TO_DATE('06/05/2020 8:57:00 AM', 'DD/MM/YYYY HH:MI:SS AM'), 
    'XX', -15.933, -5.667, 435, 'MMS INSTALLATION (MMS UPDATE)', 
    'MET-OFFICE');
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_ID, 
    EQUIPMENT_TYPE_ID, MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, 
    GRID_REF_TYPE, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, DEPLOYMENT_REMARK, 
    IPR_OWNER)
 Values
   (122062, 1605, '9885', 'DCNN', 15120, 
    111, 'T', 11, TO_DATE('06/05/2020 8:57:00 AM', 'DD/MM/YYYY HH:MI:SS AM'), TO_DATE('31/12/3999', 'DD/MM/YYYY'), 
    'XX', -15.9422, -5.6676, 435, 'MMS INSTALLATION', 
    'MET-OFFICE');
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, DEPLOYMENT_REMARK, IPR_OWNER)
 Values
   (44946, 1605, '9885', 'DCNN', 6, 
    'T', 17, TO_DATE('12/12/2002', 'DD/MM/YYYY'), TO_DATE('18/03/2014', 'DD/MM/YYYY'), 'XX', 
    -15.933, -5.667, 435, 'DEPLOYMENT DERIVED FROM OBSERVATIONAL DATA HELD IN MIDAS; EQUIPMENT_TYPE ASSUMED; BEGIN DATE SET TO SAMOS INSTALLATION DATE', 'MET-OFFICE');
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, DEPLOYMENT_REMARK, IPR_OWNER)
 Values
   (76765, 1605, '9885', 'DCNN', 6, 
    'T', 17, TO_DATE('18/03/2014', 'DD/MM/YYYY'), TO_DATE('31/12/3999', 'DD/MM/YYYY'), 'XX', 
    -15.933, -5.667, 435, 'CONFIRMED INSTALLATION DATE', 'MET-OFFICE');
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, DEPLOYMENT_REMARK, IPR_OWNER)
 Values
   (44950, 1605, '9885', 'DCNN', 6, 
    'T', 23, TO_DATE('01/12/2001', 'DD/MM/YYYY'), TO_DATE('18/03/2014', 'DD/MM/YYYY'), 'XX', 
    -15.933, -5.667, 435, 'DEPLOYMENT DERIVED FROM OBSERVATIONAL DATA HELD IN MIDAS; EQUIPMENT_TYPE ASSUMED; BEGIN DATE SET TO SAMOS INSTALLATION DATE', 'MET-OFFICE');
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, DEPLOYMENT_REMARK, IPR_OWNER)
 Values
   (76766, 1605, '9885', 'DCNN', 6, 
    'T', 23, TO_DATE('18/03/2014', 'DD/MM/YYYY'), TO_DATE('31/12/3999', 'DD/MM/YYYY'), 'XX', 
    -15.933, -5.667, 435, 'CONFIRMED INSTALLATION DATE', 'MET-OFFICE');
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, DEPLOYMENT_REMARK, IPR_OWNER)
 Values
   (5205, 1605, '9885', 'DCNN', 4, 
    'T', 37, TO_DATE('01/12/2001', 'DD/MM/YYYY'), TO_DATE('18/03/2014', 'DD/MM/YYYY'), 'XX', 
    -15.933, -5.667, 435, 'RELOAD OF DEPLOYMENT DATA FROM MIRACLES 2003 BY R BEVAN: EQUIP_ID maybe 6?, FROM DATA', 'MET-OFFICE');
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, DEPLOYMENT_REMARK, IPR_OWNER)
 Values
   (76767, 1605, '9885', 'DCNN', 6, 
    'T', 37, TO_DATE('18/03/2014', 'DD/MM/YYYY'), TO_DATE('31/12/3999', 'DD/MM/YYYY'), 'XX', 
    -15.933, -5.667, 435, 'CONFIRMED INSTALLATION DATE', 'MET-OFFICE');
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, DEPLOYMENT_REMARK, IPR_OWNER)
 Values
   (5206, 1605, '9885', 'DCNN', 5, 
    'T', 39, TO_DATE('01/12/2001', 'DD/MM/YYYY'), TO_DATE('18/03/2014', 'DD/MM/YYYY'), 'XX', 
    -15.933, -5.667, 435, 'RELOAD OF DEPLOYMENT DATA FROM MIRACLES 2003 BY R BEVAN: EQUIP_ID maybe 6?, FROM DATA', 'MET-OFFICE');
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, DEPLOYMENT_REMARK, IPR_OWNER)
 Values
   (76768, 1605, '9885', 'DCNN', 6, 
    'T', 39, TO_DATE('18/03/2014', 'DD/MM/YYYY'), TO_DATE('31/12/3999', 'DD/MM/YYYY'), 'XX', 
    -15.933, -5.667, 435, 'CONFIRMED INSTALLATION DATE', 'MET-OFFICE');
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, DEPLOYMENT_REMARK, IPR_OWNER)
 Values
   (5208, 1605, '999813', 'RAIN', 96, 
    'T', 43, TO_DATE('01/12/2001', 'DD/MM/YYYY'), TO_DATE('18/03/2014', 'DD/MM/YYYY'), 'XX', 
    -15.933, -5.667, 435, 'DEPLOYMENT DERIVED FROM OBSERVATIONAL DATA HELD IN MIDAS; EQUIPMENT_TYPE ASSUMED; BEGIN DATE SET TO EARLIEST DATA IN MIDAS FOR OPEN CAPABILITY. GILL MACKINNON', 'MET-OFFICE');
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, DEPLOYMENT_REMARK, IPR_OWNER)
 Values
   (76762, 1605, '999813', 'RAIN', 39, 
    'T', 43, TO_DATE('18/03/2014', 'DD/MM/YYYY'), TO_DATE('31/12/3999', 'DD/MM/YYYY'), 'XX', 
    -15.933, -5.667, 435, 'CONFIRMED INSTALLATION DATE', 'MET-OFFICE');
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, DEPLOYMENT_REMARK, IPR_OWNER)
 Values
   (76769, 1605, '9885', 'DCNN', 11, 
    'T', 50, TO_DATE('18/03/2014', 'DD/MM/YYYY'), TO_DATE('14/02/2018 2:25:00 PM', 'DD/MM/YYYY HH:MI:SS AM'), 'XX', 
    -15.933, -5.667, 435, 'CONFIRMED INSTALLATION DATE', 'MET-OFFICE');
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_ID, 
    EQUIPMENT_TYPE_ID, MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, 
    GRID_REF_TYPE, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, DEPLOYMENT_REMARK, 
    IPR_OWNER)
 Values
   (109288, 1605, '9885', 'DCNN', 11271, 
    249, 'T', 50, TO_DATE('14/02/2018 2:25:00 PM', 'DD/MM/YYYY HH:MI:SS AM'), TO_DATE('20/02/2018 4:18:00 PM', 'DD/MM/YYYY HH:MI:SS AM'), 
    'XX', -15.933, -5.667, 435, 'MMS INSTALLATION (MMS UPDATE)', 
    'MET-OFFICE');
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_ID, 
    EQUIPMENT_TYPE_ID, MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, 
    GRID_REF_TYPE, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, DEPLOYMENT_REMARK, 
    IPR_OWNER)
 Values
   (109342, 1605, '9885', 'DCNN', 9874, 
    249, 'T', 50, TO_DATE('20/02/2018 4:18:00 PM', 'DD/MM/YYYY HH:MI:SS AM'), TO_DATE('31/12/3999', 'DD/MM/YYYY'), 
    'XX', -15.933, -5.667, 435, 'MMS INSTALLATION', 
    'MET-OFFICE');
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, DEPLOYMENT_REMARK, IPR_OWNER)
 Values
   (5209, 1605, '9885', 'DCNN', 95, 
    'T', 67, TO_DATE('01/01/2000', 'DD/MM/YYYY'), TO_DATE('18/03/2014', 'DD/MM/YYYY'), 'XX', 
    -15.933, -5.667, 435, 'RELOAD OF DEPLOYMENT DATA FROM MIRACLES 2003 BY R BEVAN', 'MET-OFFICE');
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, DEPLOYMENT_REMARK, IPR_OWNER)
 Values
   (5204, 1605, '9885', 'DCNN', 2, 
    'T', 75, TO_DATE('05/10/1992', 'DD/MM/YYYY'), TO_DATE('18/03/2014', 'DD/MM/YYYY'), 'XX', 
    -15.933, -5.667, 435, 'BEGIN DATE SET TO SAMOS INSTALLATION DATE', 'MET-OFFICE');
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, DEPLOYMENT_REMARK, IPR_OWNER)
 Values
   (76764, 1605, '9885', 'DCNN', 6, 
    'T', 75, TO_DATE('18/03/2014', 'DD/MM/YYYY'), TO_DATE('05/09/2017 10:06:00 AM', 'DD/MM/YYYY HH:MI:SS AM'), 'XX', 
    -15.933, -5.667, 435, 'CONFIRMED INSTALLATION DATE (MMS UPDATE)', 'MET-OFFICE');
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_ID, 
    EQUIPMENT_TYPE_ID, MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, 
    GRID_REF_TYPE, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, DEPLOYMENT_REMARK, 
    IPR_OWNER)
 Values
   (105233, 1605, '9885', 'DCNN', 7265, 
    6, 'T', 75, TO_DATE('05/09/2017 10:06:00 AM', 'DD/MM/YYYY HH:MI:SS AM'), TO_DATE('22/08/2018 10:24:00 AM', 'DD/MM/YYYY HH:MI:SS AM'), 
    'XX', -15.933, -5.667, 435, 'MMS INSTALLATION (MMS UPDATE)', 
    'MET-OFFICE');
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_ID, 
    EQUIPMENT_TYPE_ID, MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, 
    GRID_REF_TYPE, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, DEPLOYMENT_REMARK, 
    IPR_OWNER)
 Values
   (112695, 1605, '9885', 'DCNN', 7265, 
    6, 'T', 75, TO_DATE('28/08/2018 1:08:00 PM', 'DD/MM/YYYY HH:MI:SS AM'), TO_DATE('06/05/2020 8:57:00 AM', 'DD/MM/YYYY HH:MI:SS AM'), 
    'XX', -15.933, -5.667, 435, 'MMS INSTALLATION (MMS UPDATE)', 
    'MET-OFFICE');
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_ID, 
    EQUIPMENT_TYPE_ID, MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, 
    GRID_REF_TYPE, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, DEPLOYMENT_REMARK, 
    IPR_OWNER)
 Values
   (122064, 1605, '9885', 'DCNN', 15121, 
    6, 'T', 75, TO_DATE('06/05/2020 8:57:00 AM', 'DD/MM/YYYY HH:MI:SS AM'), TO_DATE('31/12/3999', 'DD/MM/YYYY'), 
    'XX', -15.933, -5.667, 435, 'MMS INSTALLATION', 
    'MET-OFFICE');
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, DEPLOYMENT_REMARK, IPR_OWNER)
 Values
   (45238, 1605, '988501', 'WIND', 110, 
    'T', 77, TO_DATE('01/12/2001', 'DD/MM/YYYY'), TO_DATE('18/03/2014', 'DD/MM/YYYY'), 'XX', 
    -15.933, -5.667, 441, 'DEPLOYMENT DERIVED FROM OBSERVATIONAL DATA HELD IN MIDAS; EQUIPMENT_TYPE ASSUMED; BEGIN DATE SET TO EARLIEST DATA IN MIDAS FOR OPEN CAPABILITY. GILL MACKINNON', 'MET-OFFICE');
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, DEPLOYMENT_REMARK, IPR_OWNER)
 Values
   (77193, 1605, '988501', 'WIND', 110, 
    'T', 77, TO_DATE('18/03/2014', 'DD/MM/YYYY'), TO_DATE('25/07/2017 12:33:00 PM', 'DD/MM/YYYY HH:MI:SS AM'), 'XX', 
    -15.933, -5.667, 445, 'CONFIRMED INSTALLATION DATE (MMS UPDATE)', 'MET-OFFICE');
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_ID, 
    EQUIPMENT_TYPE_ID, MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, 
    GRID_REF_TYPE, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, DEPLOYMENT_REMARK, 
    IPR_OWNER)
 Values
   (104204, 1605, '988501', 'WIND', 12742, 
    110, 'T', 77, TO_DATE('25/07/2017 12:33:00 PM', 'DD/MM/YYYY HH:MI:SS AM'), TO_DATE('31/12/3999', 'DD/MM/YYYY'), 
    'XX', -15.933, -5.667, 445, 'MMS INSTALLATION (MMS UPDATE)', 
    'MET-OFFICE');
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, DEPLOYMENT_REMARK, IPR_OWNER)
 Values
   (5211, 1605, '988501', 'WIND', 19, 
    'T', 79, TO_DATE('01/01/2000', 'DD/MM/YYYY'), TO_DATE('01/12/2001', 'DD/MM/YYYY'), 'XX', 
    -15.933, -5.667, 441, 'RELOAD OF DEPLOYMENT DATA FROM MIRACLES 2003 BY R BEVAN: BGN_DATE maybe 01/12/2001: EQUIP_ID maybe 21?, FROM DATA', 'MET-OFFICE');
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, DEPLOYMENT_REMARK, IPR_OWNER)
 Values
   (76772, 1605, '988501', 'WIND', 21, 
    'T', 79, TO_DATE('01/12/2001', 'DD/MM/YYYY'), TO_DATE('18/03/2014', 'DD/MM/YYYY'), 'XX', 
    -15.933, -5.667, 441, 'CONFIRMED INSTALLATION DATE', 'MET-OFFICE');
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, DEPLOYMENT_REMARK, IPR_OWNER)
 Values
   (77195, 1605, '988501', 'WIND', 21, 
    'T', 79, TO_DATE('18/03/2014', 'DD/MM/YYYY'), TO_DATE('30/10/2016 12:06:00 AM', 'DD/MM/YYYY HH:MI:SS AM'), 'XX', 
    -15.933, -5.667, 445, 'CONFIRMED INSTALLATION DATE (MMS UPDATE)', 'MET-OFFICE');
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_ID, 
    EQUIPMENT_TYPE_ID, MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, 
    GRID_REF_TYPE, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, DEPLOYMENT_REMARK, 
    IPR_OWNER)
 Values
   (99600, 1605, '988501', 'WIND', 11919, 
    21, 'T', 79, TO_DATE('30/10/2016 12:06:00 AM', 'DD/MM/YYYY HH:MI:SS AM'), TO_DATE('08/11/2018 8:48:00 AM', 'DD/MM/YYYY HH:MI:SS AM'), 
    'XX', -15.933, -5.667, 445, 'MMS INSTALLATION (MMS UPDATE) (MMS UPDATE)', 
    'MET-OFFICE');
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_ID, 
    EQUIPMENT_TYPE_ID, MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, 
    GRID_REF_TYPE, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, DEPLOYMENT_REMARK, 
    IPR_OWNER)
 Values
   (113872, 1605, '988501', 'WIND', 9574, 
    21, 'T', 79, TO_DATE('08/11/2018 8:48:00 AM', 'DD/MM/YYYY HH:MI:SS AM'), TO_DATE('31/12/3999', 'DD/MM/YYYY'), 
    'XX', -15.933, -5.667, 445, 'MMS INSTALLATION', 
    'MET-OFFICE');
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, DEPLOYMENT_REMARK, IPR_OWNER)
 Values
   (45641, 1605, '988501', 'WIND', 21, 
    'T', 81, TO_DATE('01/12/2001', 'DD/MM/YYYY'), TO_DATE('18/03/2014', 'DD/MM/YYYY'), 'XX', 
    -15.933, -5.667, 441, 'DEPLOYMENT DERIVED FROM OBSERVATIONAL DATA HELD IN MIDAS; EQUIPMENT_TYPE ASSUMED; BEGIN DATE SET TO EARLIEST DATA IN MIDAS FOR OPEN CAPABILITY. GILL MACKINNON', 'MET-OFFICE');
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, DEPLOYMENT_REMARK, IPR_OWNER)
 Values
   (77196, 1605, '988501', 'WIND', 21, 
    'T', 81, TO_DATE('18/03/2014', 'DD/MM/YYYY'), TO_DATE('30/10/2016 12:06:00 AM', 'DD/MM/YYYY HH:MI:SS AM'), 'XX', 
    -15.933, -5.667, 445, 'CONFIRMED INSTALLATION DATE (MMS UPDATE)', 'MET-OFFICE');
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_ID, 
    EQUIPMENT_TYPE_ID, MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, 
    GRID_REF_TYPE, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, DEPLOYMENT_REMARK, 
    IPR_OWNER)
 Values
   (99601, 1605, '988501', 'WIND', 11919, 
    21, 'T', 81, TO_DATE('30/10/2016 12:06:00 AM', 'DD/MM/YYYY HH:MI:SS AM'), TO_DATE('08/11/2018 8:48:00 AM', 'DD/MM/YYYY HH:MI:SS AM'), 
    'XX', -15.933, -5.667, 445, 'MMS INSTALLATION (MMS UPDATE) (MMS UPDATE)', 
    'MET-OFFICE');
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_ID, 
    EQUIPMENT_TYPE_ID, MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, 
    GRID_REF_TYPE, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, DEPLOYMENT_REMARK, 
    IPR_OWNER)
 Values
   (113871, 1605, '988501', 'WIND', 9574, 
    21, 'T', 81, TO_DATE('08/11/2018 8:48:00 AM', 'DD/MM/YYYY HH:MI:SS AM'), TO_DATE('31/12/3999', 'DD/MM/YYYY'), 
    'XX', -15.933, -5.667, 445, 'MMS INSTALLATION', 
    'MET-OFFICE');
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, DEPLOYMENT_REMARK, IPR_OWNER)
 Values
   (45715, 1605, '988501', 'WIND', 101, 
    'T', 83, TO_DATE('01/12/2001', 'DD/MM/YYYY'), TO_DATE('18/03/2014', 'DD/MM/YYYY'), 'XX', 
    -15.933, -5.667, 435, 'DEPLOYMENT DERIVED FROM OBSERVATIONAL DATA HELD IN MIDAS; EQUIPMENT_TYPE ASSUMED; BEGIN DATE SET TO EARLIEST DATA IN MIDAS FOR OPEN CAPABILITY. GILL MACKINNON', 'MET-OFFICE');
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, DEPLOYMENT_REMARK, IPR_OWNER)
 Values
   (45387, 1605, '988501', 'WIND', 110, 
    'T', 85, TO_DATE('01/12/2001', 'DD/MM/YYYY'), TO_DATE('18/03/2014', 'DD/MM/YYYY'), 'XX', 
    -15.933, -5.667, 441, 'DEPLOYMENT DERIVED FROM OBSERVATIONAL DATA HELD IN MIDAS; EQUIPMENT_TYPE ASSUMED; BEGIN DATE SET TO EARLIEST DATA IN MIDAS FOR OPEN CAPABILITY. GILL MACKINNON', 'MET-OFFICE');
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, DEPLOYMENT_REMARK, IPR_OWNER)
 Values
   (77194, 1605, '988501', 'WIND', 110, 
    'T', 85, TO_DATE('18/03/2014', 'DD/MM/YYYY'), TO_DATE('25/07/2017 12:33:00 PM', 'DD/MM/YYYY HH:MI:SS AM'), 'XX', 
    -15.933, -5.667, 445, 'CONFIRMED INSTALLATION DATE (MMS UPDATE)', 'MET-OFFICE');
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_ID, 
    EQUIPMENT_TYPE_ID, MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, 
    GRID_REF_TYPE, HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, DEPLOYMENT_REMARK, 
    IPR_OWNER)
 Values
   (104205, 1605, '988501', 'WIND', 12742, 
    110, 'T', 85, TO_DATE('25/07/2017 12:33:00 PM', 'DD/MM/YYYY HH:MI:SS AM'), TO_DATE('31/12/3999', 'DD/MM/YYYY'), 
    'XX', -15.933, -5.667, 445, 'MMS INSTALLATION (MMS UPDATE)', 
    'MET-OFFICE');
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, DEPLOYMENT_REMARK, IPR_OWNER)
 Values
   (75980, 1605, '988501', 'WIND', 251, 
    'T', 88, TO_DATE('01/02/2008', 'DD/MM/YYYY'), TO_DATE('18/03/2014', 'DD/MM/YYYY'), 'XX', 
    -15.933, -5.667, 435, 'ESTIMATED INSTALLATION DATE', 'MET-OFFICE');
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, DEPLOYMENT_REMARK, IPR_OWNER)
 Values
   (77197, 1605, '988501', 'WIND', 250, 
    'T', 88, TO_DATE('18/03/2014', 'DD/MM/YYYY'), TO_DATE('31/12/3999', 'DD/MM/YYYY'), 'XX', 
    -15.933, -5.667, 435, 'CONFIRMED INSTALLATION DATE', 'MET-OFFICE');
Insert into DEPLOYMENT
   (DEPLOYMENT_ID, SRC_ID, ID, ID_TYPE, EQUIPMENT_TYPE_ID, 
    MET_OFFICE_EQPT_FLAG, MET_ROLE_ID, DEPL_BGN_DATE, DEPL_END_DATE, GRID_REF_TYPE, 
    HIGH_PRCN_LAT, HIGH_PRCN_LON, ELEVATION, DEPLOYMENT_REMARK, IPR_OWNER)
 Values
   (14746, 1605, '9885', 'DCNN', 106, 
    'F', 97, TO_DATE('01/01/2000', 'DD/MM/YYYY'), TO_DATE('31/12/3999', 'DD/MM/YYYY'), 'XX', 
    -15.933, -5.667, 435, 'DEPLOYMENT RECORD FOR INSPECTION_ITEM RECORDS WITH NO MET_ROLE_ID', 'MET-OFFICE');
COMMIT;
Insert into DEPLOYMENT_DETAIL
   (DEPL_ATTR_ID, DEPLOYMENT_ID, DEPL_ATTR_BGN_DATE, DEPL_DTL_VAL, DEPL_ATTR_END_DATE)
 Values
   (4, 2537, TO_DATE('01/01/2000', 'DD/MM/YYYY'), 300, TO_DATE('30/06/2003', 'DD/MM/YYYY'));
Insert into DEPLOYMENT_DETAIL
   (DEPL_ATTR_ID, DEPLOYMENT_ID, DEPL_ATTR_BGN_DATE, DEPL_DTL_VAL, DEPL_ATTR_END_DATE)
 Values
   (4, 28847, TO_DATE('01/01/1995', 'DD/MM/YYYY'), 300, TO_DATE('30/06/2003', 'DD/MM/YYYY'));
Insert into DEPLOYMENT_DETAIL
   (DEPL_ATTR_ID, DEPLOYMENT_ID, DEPL_ATTR_BGN_DATE, DEPL_DTL_VAL, DEPL_ATTR_END_DATE)
 Values
   (4, 28848, TO_DATE('01/12/1991', 'DD/MM/YYYY'), 300, TO_DATE('31/12/1992', 'DD/MM/YYYY'));
Insert into DEPLOYMENT_DETAIL
   (DEPL_ATTR_ID, DEPLOYMENT_ID, DEPL_ATTR_BGN_DATE, DEPL_DTL_VAL, DEPL_ATTR_END_DATE)
 Values
   (10, 2523, TO_DATE('01/01/2000', 'DD/MM/YYYY'), 30, TO_DATE('30/06/2003', 'DD/MM/YYYY'));
Insert into DEPLOYMENT_DETAIL
   (DEPL_ATTR_ID, DEPLOYMENT_ID, DEPL_ATTR_BGN_DATE, DEPL_DTL_VAL, DEPL_ATTR_END_DATE)
 Values
   (10, 2534, TO_DATE('01/01/2000', 'DD/MM/YYYY'), 30, TO_DATE('30/06/2003', 'DD/MM/YYYY'));
Insert into DEPLOYMENT_DETAIL
   (DEPL_ATTR_ID, DEPLOYMENT_ID, DEPL_ATTR_BGN_DATE, DEPL_DTL_VAL, DEPL_ATTR_END_DATE)
 Values
   (7, 113872, TO_DATE('08/11/2018 8:48:00 AM', 'DD/MM/YYYY HH:MI:SS AM'), 435, TO_DATE('31/12/3999', 'DD/MM/YYYY'));
Insert into DEPLOYMENT_DETAIL
   (DEPL_ATTR_ID, DEPLOYMENT_ID, DEPL_ATTR_BGN_DATE, DEPL_DTL_VAL, DEPL_ATTR_END_DATE)
 Values
   (7, 5211, TO_DATE('01/01/2000', 'DD/MM/YYYY'), 435, TO_DATE('01/12/2001', 'DD/MM/YYYY'));
Insert into DEPLOYMENT_DETAIL
   (DEPL_ATTR_ID, DEPLOYMENT_ID, DEPL_ATTR_BGN_DATE, DEPL_DTL_VAL, DEPL_ATTR_END_DATE)
 Values
   (11, 2524, TO_DATE('01/01/2000', 'DD/MM/YYYY'), 50, TO_DATE('30/06/2003', 'DD/MM/YYYY'));
Insert into DEPLOYMENT_DETAIL
   (DEPL_ATTR_ID, DEPLOYMENT_ID, DEPL_ATTR_BGN_DATE, DEPL_DTL_VAL, DEPL_ATTR_END_DATE)
 Values
   (11, 2535, TO_DATE('01/01/2000', 'DD/MM/YYYY'), 50, TO_DATE('30/06/2003', 'DD/MM/YYYY'));
Insert into DEPLOYMENT_DETAIL
   (DEPL_ATTR_ID, DEPLOYMENT_ID, DEPL_ATTR_BGN_DATE, DEPL_DTL_VAL, DEPL_ATTR_END_DATE)
 Values
   (12, 2525, TO_DATE('01/01/2000', 'DD/MM/YYYY'), 100, TO_DATE('30/06/2003', 'DD/MM/YYYY'));
Insert into DEPLOYMENT_DETAIL
   (DEPL_ATTR_ID, DEPLOYMENT_ID, DEPL_ATTR_BGN_DATE, DEPL_DTL_VAL, DEPL_ATTR_END_DATE)
 Values
   (12, 2536, TO_DATE('01/01/2000', 'DD/MM/YYYY'), 100, TO_DATE('30/06/2003', 'DD/MM/YYYY'));
Insert into DEPLOYMENT_DETAIL
   (DEPL_ATTR_ID, DEPLOYMENT_ID, DEPL_ATTR_BGN_DATE, DEPL_DTL_VAL, DEPL_ATTR_END_DATE)
 Values
   (7, 77195, TO_DATE('18/03/2014', 'DD/MM/YYYY'), 435, TO_DATE('30/10/2016 12:06:00 AM', 'DD/MM/YYYY HH:MI:SS AM'));
Insert into DEPLOYMENT_DETAIL
   (DEPL_ATTR_ID, DEPLOYMENT_ID, DEPL_ATTR_BGN_DATE, DEPL_DTL_VAL, DEPL_ATTR_END_DATE)
 Values
   (7, 99600, TO_DATE('30/10/2016 12:06:00 AM', 'DD/MM/YYYY HH:MI:SS AM'), 435, TO_DATE('08/11/2018 8:48:00 AM', 'DD/MM/YYYY HH:MI:SS AM'));
Insert into DEPLOYMENT_DETAIL
   (DEPL_ATTR_ID, DEPLOYMENT_ID, DEPL_ATTR_BGN_DATE, DEPL_DTL_VAL, DEPL_ATTR_END_DATE)
 Values
   (5, 10550, TO_DATE('01/12/1991', 'DD/MM/YYYY'), 10, TO_DATE('30/06/2003', 'DD/MM/YYYY'));
Insert into DEPLOYMENT_DETAIL
   (DEPL_ATTR_ID, DEPLOYMENT_ID, DEPL_ATTR_BGN_DATE, DEPL_DTL_VAL, DEPL_ATTR_END_DATE)
 Values
   (7, 10550, TO_DATE('01/12/1991', 'DD/MM/YYYY'), 83, TO_DATE('30/06/2003', 'DD/MM/YYYY'));
Insert into DEPLOYMENT_DETAIL
   (DEPL_ATTR_ID, DEPLOYMENT_ID, DEPL_ATTR_BGN_DATE, DEPL_DTL_VAL, DEPL_ATTR_END_DATE)
 Values
   (9, 10550, TO_DATE('01/12/1991', 'DD/MM/YYYY'), 10, TO_DATE('30/06/2003', 'DD/MM/YYYY'));
Insert into DEPLOYMENT_DETAIL
   (DEPL_ATTR_ID, DEPLOYMENT_ID, DEPL_ATTR_BGN_DATE, DEPL_DTL_VAL, DEPL_ATTR_END_DATE)
 Values
   (6, 10549, TO_DATE('01/12/1991', 'DD/MM/YYYY'), 10, TO_DATE('30/06/2003', 'DD/MM/YYYY'));
Insert into DEPLOYMENT_DETAIL
   (DEPL_ATTR_ID, DEPLOYMENT_ID, DEPL_ATTR_BGN_DATE, DEPL_DTL_VAL, DEPL_ATTR_END_DATE)
 Values
   (7, 76772, TO_DATE('01/12/2001', 'DD/MM/YYYY'), 435, TO_DATE('18/03/2014', 'DD/MM/YYYY'));
COMMIT;
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (273798, 140, 13795, 88.18);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (273799, 141, 13795, 92.12);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (273800, 142, 13795, 99.96);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (273801, 143, 13795, 111.63);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (273802, 144, 13795, 115.49);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (273803, 145, 13795, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (273804, 146, 13795, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (273805, 147, 13795, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (273806, 148, 13795, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (273807, 149, 13795, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (273808, 150, 13795, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (273809, 151, 13795, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (273810, 152, 13795, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (273811, 153, 13795, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (273812, 154, 13795, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (273813, 155, 13795, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (273814, 156, 13795, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (273815, 157, 13795, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (273816, 158, 13795, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (273817, 159, 13795, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (154758, 140, 7843, 88.21);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (154759, 141, 7843, 92.16);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (154760, 142, 7843, 100.02);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (154761, 143, 7843, 111.72);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (154762, 144, 7843, 115.59);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (154763, 145, 7843, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (154764, 146, 7843, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (154765, 147, 7843, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (154766, 148, 7843, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (154767, 149, 7843, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (154768, 150, 7843, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (154769, 151, 7843, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (154770, 152, 7843, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (154771, 153, 7843, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (154772, 154, 7843, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (154773, 155, 7843, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (154774, 156, 7843, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (154775, 157, 7843, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (154776, 158, 7843, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (154777, 159, 7843, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (98041, 60, 5007, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (98042, 61, 5007, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (98043, 62, 5007, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (98044, 63, 5007, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (98045, 64, 5007, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (98046, 65, 5007, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (98047, 66, 5007, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (98048, 67, 5007, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (98049, 68, 5007, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (98050, 69, 5007, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (98051, 70, 5007, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (98052, 71, 5007, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (98053, 72, 5007, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (98054, 73, 5007, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (98055, 74, 5007, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (98056, 75, 5007, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (98057, 76, 5007, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (98058, 77, 5007, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (98059, 78, 5007, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (98060, 79, 5007, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (219538, 60, 11082, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (219539, 61, 11082, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (219540, 62, 11082, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (219541, 63, 11082, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (219542, 64, 11082, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (219543, 65, 11082, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (219544, 66, 11082, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (219545, 67, 11082, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (219546, 68, 11082, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (219547, 69, 11082, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (219548, 70, 11082, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (219549, 71, 11082, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (219550, 72, 11082, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (219551, 73, 11082, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (219552, 74, 11082, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (219553, 75, 11082, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (219554, 76, 11082, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (219555, 77, 11082, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (219556, 78, 11082, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (219557, 79, 11082, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (58481, 60, 3029, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (58482, 61, 3029, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (58483, 62, 3029, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (58484, 63, 3029, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (58485, 64, 3029, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (58486, 65, 3029, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (58487, 66, 3029, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (58488, 67, 3029, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (58489, 68, 3029, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (58490, 69, 3029, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (58491, 70, 3029, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (58492, 71, 3029, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (58493, 72, 3029, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (58494, 73, 3029, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (58495, 74, 3029, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (58496, 75, 3029, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (58497, 76, 3029, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (58498, 77, 3029, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (58499, 78, 3029, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (58500, 79, 3029, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (128418, 60, 6526, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (128419, 61, 6526, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (128420, 62, 6526, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (128421, 63, 6526, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (128422, 64, 6526, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (128423, 65, 6526, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (128424, 66, 6526, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (128425, 67, 6526, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (128426, 68, 6526, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (128427, 69, 6526, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (128428, 70, 6526, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (128429, 71, 6526, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (128430, 72, 6526, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (128431, 73, 6526, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (128432, 74, 6526, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (128433, 75, 6526, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (128434, 76, 6526, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (128435, 77, 6526, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (128436, 78, 6526, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (128437, 79, 6526, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (13021, 220, 756, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (13022, 221, 756, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (13023, 222, 756, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (13024, 223, 756, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (13025, 224, 756, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (13026, 225, 756, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (13027, 226, 756, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (13028, 227, 756, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (13029, 228, 756, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (13030, 229, 756, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (13031, 230, 756, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (13032, 231, 756, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (13033, 232, 756, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (13034, 233, 756, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (13035, 234, 756, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (13036, 235, 756, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (13037, 236, 756, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (13038, 237, 756, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (13039, 238, 756, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (13040, 239, 756, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (273778, 220, 13794, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (273779, 221, 13794, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (273780, 222, 13794, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (273781, 223, 13794, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (273782, 224, 13794, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (273783, 225, 13794, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (273784, 226, 13794, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (273785, 227, 13794, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (273786, 228, 13794, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (273787, 229, 13794, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (273788, 230, 13794, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (273789, 231, 13794, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (273790, 232, 13794, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (273791, 233, 13794, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (273792, 234, 13794, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (273793, 235, 13794, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (273794, 236, 13794, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (273795, 237, 13794, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (273796, 238, 13794, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (273797, 239, 13794, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (127998, 140, 6505, 88.19);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (127999, 141, 6505, 92.14);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (128000, 142, 6505, 99.99);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (128001, 143, 6505, 111.68);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (128002, 144, 6505, 115.56);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (128003, 145, 6505, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (128004, 146, 6505, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (128005, 147, 6505, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (128006, 148, 6505, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (128007, 149, 6505, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (128008, 150, 6505, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (128009, 151, 6505, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (128010, 152, 6505, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (128011, 153, 6505, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (128012, 154, 6505, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (128013, 155, 6505, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (128014, 156, 6505, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (128015, 157, 6505, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (128016, 158, 6505, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (128017, 159, 6505, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (144138, 60, 7312, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (144139, 61, 7312, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (144140, 62, 7312, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (144141, 63, 7312, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (144142, 64, 7312, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (144143, 65, 7312, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (144144, 66, 7312, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (144145, 67, 7312, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (144146, 68, 7312, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (144147, 69, 7312, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (144148, 70, 7312, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (144149, 71, 7312, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (144150, 72, 7312, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (144151, 73, 7312, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (144152, 74, 7312, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (144153, 75, 7312, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (144154, 76, 7312, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (144155, 77, 7312, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (144156, 78, 7312, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (144157, 79, 7312, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (223698, 60, 11290, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (223699, 61, 11290, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (223700, 62, 11290, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (223701, 63, 11290, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (223702, 64, 11290, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (223703, 65, 11290, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (223704, 66, 11290, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (223705, 67, 11290, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (223706, 68, 11290, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (223707, 69, 11290, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (223708, 70, 11290, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (223709, 71, 11290, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (223710, 72, 11290, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (223711, 73, 11290, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (223712, 74, 11290, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (223713, 75, 11290, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (223714, 76, 11290, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (223715, 77, 11290, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (223716, 78, 11290, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (223717, 79, 11290, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (113638, 100, 5787, 48);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (113639, 101, 5787, 100);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (113640, 102, 5787, 200);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (113641, 103, 5787, 300);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (113642, 104, 5787, 400);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (113643, 105, 5787, 500);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (113644, 106, 5787, 600);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (113645, 107, 5787, 700);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (113646, 108, 5787, 800);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (113647, 109, 5787, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (113648, 110, 5787, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (113649, 111, 5787, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (113650, 112, 5787, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (113651, 113, 5787, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (113652, 114, 5787, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (113653, 115, 5787, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (113654, 116, 5787, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (113655, 117, 5787, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (113656, 118, 5787, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (113657, 119, 5787, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (50081, 100, 2609, 48);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (50082, 101, 2609, 100);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (50083, 102, 2609, 200);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (50084, 103, 2609, 300);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (50085, 104, 2609, 400);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (50086, 105, 2609, 500);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (50087, 106, 2609, 600);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (50088, 107, 2609, 700);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (50089, 108, 2609, 800);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (50090, 109, 2609, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (50091, 110, 2609, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (50092, 111, 2609, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (50093, 112, 2609, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (50094, 113, 2609, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (50095, 114, 2609, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (50096, 115, 2609, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (50097, 116, 2609, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (50098, 117, 2609, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (50099, 118, 2609, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (50100, 119, 2609, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (219558, 60, 11083, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (219559, 61, 11083, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (219560, 62, 11083, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (219561, 63, 11083, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (219562, 64, 11083, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (219563, 65, 11083, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (219564, 66, 11083, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (219565, 67, 11083, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (219566, 68, 11083, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (219567, 69, 11083, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (219568, 70, 11083, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (219569, 71, 11083, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (219570, 72, 11083, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (219571, 73, 11083, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (219572, 74, 11083, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (219573, 75, 11083, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (219574, 76, 11083, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (219575, 77, 11083, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (219576, 78, 11083, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (219577, 79, 11083, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (117778, 100, 5994, 47.02);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (117779, 101, 5994, 97.14);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (117780, 102, 5994, 200.66);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (117781, 103, 5994, 304.95);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (117782, 104, 5994, 408.63);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (117783, 105, 5994, 514.22);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (117784, 106, 5994, 618.32);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (117785, 107, 5994, 722.97);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (117786, 108, 5994, 827.44);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (117787, 109, 5994, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (117788, 110, 5994, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (117789, 111, 5994, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (117790, 112, 5994, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (117791, 113, 5994, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (117792, 114, 5994, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (117793, 115, 5994, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (117794, 116, 5994, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (117795, 117, 5994, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (117796, 118, 5994, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (117797, 119, 5994, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (150818, 80, 7646, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (150819, 81, 7646, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (150820, 82, 7646, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (150821, 83, 7646, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (150822, 84, 7646, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (150823, 85, 7646, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (150824, 86, 7646, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (150825, 87, 7646, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (150826, 88, 7646, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (150827, 89, 7646, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (150828, 90, 7646, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (150829, 91, 7646, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (150830, 92, 7646, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (150831, 93, 7646, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (150832, 94, 7646, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (150833, 95, 7646, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (150834, 96, 7646, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (150835, 97, 7646, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (150836, 98, 7646, 0);
Insert into EQPT_CALIB_COEFF
   (CALIB_COEFF_MSRT_ID, EQPT_TYPE_CALIB_COEFF_ID, EQPT_CALIB_ID, CALIB_COEFF_VAL)
 Values
   (150837, 99, 7646, 0);
COMMIT;
Insert into EQUIPMENT
   (EQUIPMENT_ID, EQUIPMENT_TYPE_ID, MANUFACTURER_NAME, MANUFACTURER_SN_TXT, MET_REF_TXT, 
    EQPT_LAST_UPDATED_DATE)
 Values
   (7265, 6, 'UNKNOWN', '46062/28', 'CC0277', 
    TO_DATE('18/01/2017 9:04:49 AM', 'DD/MM/YYYY HH:MI:SS AM'));
Insert into EQUIPMENT
   (EQUIPMENT_ID, EQUIPMENT_TYPE_ID, MANUFACTURER_NAME, MANUFACTURER_SN_TXT, MET_REF_TXT, 
    EQPT_LAST_UPDATED_DATE)
 Values
   (7887, 111, 'UNKNOWN', 'CT25K-', 'DUMMY53', 
    TO_DATE('19/08/2015 8:25:45 AM', 'DD/MM/YYYY HH:MI:SS AM'));
Insert into EQUIPMENT
   (EQUIPMENT_ID, EQUIPMENT_TYPE_ID, MANUFACTURER_NAME, MANUFACTURER_SN_TXT, MET_REF_TXT, 
    EQPT_LAST_UPDATED_DATE)
 Values
   (9574, 21, 'UNKNOWN', '14434/EZB7', 'SM074636', 
    TO_DATE('18/01/2017 9:04:50 AM', 'DD/MM/YYYY HH:MI:SS AM'));
Insert into EQUIPMENT
   (EQUIPMENT_ID, EQUIPMENT_TYPE_ID, MANUFACTURER_NAME, MANUFACTURER_SN_TXT, MET_REF_TXT, 
    EQPT_LAST_UPDATED_DATE)
 Values
   (9874, 249, 'UNKNOWN', 'L5320317', 'SM004492', 
    TO_DATE('18/01/2017 9:04:49 AM', 'DD/MM/YYYY HH:MI:SS AM'));
Insert into EQUIPMENT
   (EQUIPMENT_ID, EQUIPMENT_TYPE_ID, MANUFACTURER_NAME, MANUFACTURER_SN_TXT, MET_REF_TXT, 
    EQPT_LAST_UPDATED_DATE)
 Values
   (11271, 249, 'UNKNOWN', 'R0930877', 'SM096638-RHT', 
    TO_DATE('21/05/2019 11:09:55 AM', 'DD/MM/YYYY HH:MI:SS AM'));
Insert into EQUIPMENT
   (EQUIPMENT_ID, EQUIPMENT_TYPE_ID, MANUFACTURER_NAME, MANUFACTURER_SN_TXT, MET_REF_TXT, 
    EQPT_LAST_UPDATED_DATE)
 Values
   (11919, 21, 'UNKNOWN', '6444/B8CV', 'DD0499', 
    TO_DATE('31/10/2016 8:33:03 AM', 'DD/MM/YYYY HH:MI:SS AM'));
Insert into EQUIPMENT
   (EQUIPMENT_ID, EQUIPMENT_TYPE_ID, MANUFACTURER_NAME, MANUFACTURER_SN_TXT, MET_REF_TXT, 
    EQPT_LAST_UPDATED_DATE)
 Values
   (12742, 110, 'UNKNOWN', '9830/C830', 'DD1919', 
    TO_DATE('26/07/2017 7:47:25 AM', 'DD/MM/YYYY HH:MI:SS AM'));
Insert into EQUIPMENT
   (EQUIPMENT_ID, EQUIPMENT_TYPE_ID, MANUFACTURER_NAME, MANUFACTURER_SN_TXT, MET_REF_TXT, 
    EQPT_LAST_UPDATED_DATE)
 Values
   (12838, 6, 'UNKNOWN', '3049', 'EE0231', 
    TO_DATE('19/09/2017 2:28:08 PM', 'DD/MM/YYYY HH:MI:SS AM'));
Insert into EQUIPMENT
   (EQUIPMENT_ID, EQUIPMENT_TYPE_ID, MANUFACTURER_NAME, MANUFACTURER_SN_TXT, MET_REF_TXT, 
    EQPT_LAST_UPDATED_DATE)
 Values
   (15120, 111, 'UNKNOWN', 'X28104', 'LCBRV019', 
    TO_DATE('13/05/2020 8:19:13 AM', 'DD/MM/YYYY HH:MI:SS AM'));
Insert into EQUIPMENT
   (EQUIPMENT_ID, EQUIPMENT_TYPE_ID, MANUFACTURER_NAME, MANUFACTURER_SN_TXT, MET_REF_TXT, 
    EQPT_LAST_UPDATED_DATE)
 Values
   (15121, 6, 'UNKNOWN', '73207-46', 'TA5015', 
    TO_DATE('13/05/2020 8:19:14 AM', 'DD/MM/YYYY HH:MI:SS AM'));
COMMIT;
Insert into EQUIPMENT_CALIBRATION
   (EQPT_CALIB_ID, EQUIPMENT_ID, EQPT_CALIB_DATE, CALIB_MTHD_CODE, EQPT_CALIB_NEXT_DUE_DATE, 
    EQPT_CALIB_RMRK)
 Values
   (6505, 7265, TO_DATE('11/01/2017', 'DD/MM/YYYY'), '1', TO_DATE('10/01/2025', 'DD/MM/YYYY'), 
    ' Calibrated on  0000 11/01/2017 by Tony Wadham - Calibration Manager');
Insert into EQUIPMENT_CALIBRATION
   (EQPT_CALIB_ID, EQUIPMENT_ID, EQPT_CALIB_DATE, CALIB_MTHD_CODE, EQPT_CALIB_NEXT_DUE_DATE, 
    EQPT_CALIB_RMRK)
 Values
   (756, 7887, TO_DATE('07/08/2013 11:07:00 AM', 'DD/MM/YYYY HH:MI:SS AM'), '1', TO_DATE('07/08/2014 11:07:00 AM', 'DD/MM/YYYY HH:MI:SS AM'), 
    ' Calibrated on  1107 07/08/2013 by Jonathan Tamlyn - Land Networks Specialist');
Insert into EQUIPMENT_CALIBRATION
   (EQPT_CALIB_ID, EQUIPMENT_ID, EQPT_CALIB_DATE, CALIB_MTHD_CODE, EQPT_CALIB_NEXT_DUE_DATE, 
    EQPT_CALIB_RMRK)
 Values
   (5787, 9574, TO_DATE('16/08/2016 4:00:00 PM', 'DD/MM/YYYY HH:MI:SS AM'), '1', TO_DATE('15/08/2021 4:00:00 PM', 'DD/MM/YYYY HH:MI:SS AM'), 
    ' Calibrated on  1600 16/08/2016 by Neil Mander - QA Lab & Stores Manager');
Insert into EQUIPMENT_CALIBRATION
   (EQPT_CALIB_ID, EQUIPMENT_ID, EQPT_CALIB_DATE, CALIB_MTHD_CODE, EQPT_CALIB_NEXT_DUE_DATE, 
    EQPT_CALIB_RMRK)
 Values
   (2609, 9574, TO_DATE('19/07/2013 4:00:00 PM', 'DD/MM/YYYY HH:MI:SS AM'), '1', TO_DATE('18/07/2018 4:00:00 PM', 'DD/MM/YYYY HH:MI:SS AM'), 
    ' Calibrated on  1600 19/07/2013 by Lerwick RTM - Peter Kerr');
Insert into EQUIPMENT_CALIBRATION
   (EQPT_CALIB_ID, EQUIPMENT_ID, EQPT_CALIB_DATE, CALIB_MTHD_CODE, EQPT_CALIB_NEXT_DUE_DATE, 
    EQPT_CALIB_RMRK)
 Values
   (3029, 9874, TO_DATE('30/12/2015 11:00:00 AM', 'DD/MM/YYYY HH:MI:SS AM'), '1', TO_DATE('29/12/2016 11:00:00 AM', 'DD/MM/YYYY HH:MI:SS AM'), 
    ' Calibrated on  1100 30/12/2015 by QA Lab');
Insert into EQUIPMENT_CALIBRATION
   (EQPT_CALIB_ID, EQUIPMENT_ID, EQPT_CALIB_DATE, CALIB_MTHD_CODE, EQPT_CALIB_NEXT_DUE_DATE, 
    EQPT_CALIB_RMRK)
 Values
   (6526, 9874, TO_DATE('12/01/2017 11:00:00 AM', 'DD/MM/YYYY HH:MI:SS AM'), '1', TO_DATE('11/07/2018 11:00:00 AM', 'DD/MM/YYYY HH:MI:SS AM'), 
    ' Calibrated on  1100 12/01/2017 by Calibration Lab Analyst');
Insert into EQUIPMENT_CALIBRATION
   (EQPT_CALIB_ID, EQUIPMENT_ID, EQPT_CALIB_DATE, CALIB_MTHD_CODE, EQPT_CALIB_NEXT_DUE_DATE, 
    EQPT_CALIB_RMRK)
 Values
   (5007, 11271, TO_DATE('20/07/2016 8:18:00 AM', 'DD/MM/YYYY HH:MI:SS AM'), '1', TO_DATE('19/01/2018 8:18:00 AM', 'DD/MM/YYYY HH:MI:SS AM'), 
    ' Calibrated on  0818 20/07/2016 by John Shields - Service Engineer');
Insert into EQUIPMENT_CALIBRATION
   (EQPT_CALIB_ID, EQUIPMENT_ID, EQPT_CALIB_DATE, CALIB_MTHD_CODE, EQPT_CALIB_NEXT_DUE_DATE, 
    EQPT_CALIB_RMRK)
 Values
   (7312, 11271, TO_DATE('26/04/2017 2:07:00 PM', 'DD/MM/YYYY HH:MI:SS AM'), '1', TO_DATE('26/04/2018 2:07:00 PM', 'DD/MM/YYYY HH:MI:SS AM'), 
    ' Calibrated on  1407 26/04/2017 by Peter Kirk - Land networks Coordinator');
Insert into EQUIPMENT_CALIBRATION
   (EQPT_CALIB_ID, EQUIPMENT_ID, EQPT_CALIB_DATE, CALIB_MTHD_CODE, EQPT_CALIB_NEXT_DUE_DATE, 
    EQPT_CALIB_RMRK)
 Values
   (11290, 11271, TO_DATE('01/01/1970 8:05:00 AM', 'DD/MM/YYYY HH:MI:SS AM'), '1', TO_DATE('01/01/1971 8:05:00 AM', 'DD/MM/YYYY HH:MI:SS AM'), 
    ' Calibrated on  0805 01/01/1970 by QA Laboratory Manager');
Insert into EQUIPMENT_CALIBRATION
   (EQPT_CALIB_ID, EQUIPMENT_ID, EQPT_CALIB_DATE, CALIB_MTHD_CODE, EQPT_CALIB_NEXT_DUE_DATE, 
    EQPT_CALIB_RMRK)
 Values
   (11082, 11271, TO_DATE('16/04/2019 8:05:00 AM', 'DD/MM/YYYY HH:MI:SS AM'), '1', TO_DATE('15/04/2021 8:05:00 AM', 'DD/MM/YYYY HH:MI:SS AM'), 
    ' Calibrated on  0805 16/04/2019 by Observation Meteorological Technician');
Insert into EQUIPMENT_CALIBRATION
   (EQPT_CALIB_ID, EQUIPMENT_ID, EQPT_CALIB_DATE, CALIB_MTHD_CODE, EQPT_CALIB_NEXT_DUE_DATE, 
    EQPT_CALIB_RMRK)
 Values
   (11083, 11271, TO_DATE('16/04/2019 8:05:00 AM', 'DD/MM/YYYY HH:MI:SS AM'), '1', TO_DATE('15/04/2020 8:05:00 AM', 'DD/MM/YYYY HH:MI:SS AM'), 
    ' Calibrated on  0805 16/04/2019 by Observation Meteorological Technician');
Insert into EQUIPMENT_CALIBRATION
   (EQPT_CALIB_ID, EQUIPMENT_ID, EQPT_CALIB_DATE, CALIB_MTHD_CODE, EQPT_CALIB_NEXT_DUE_DATE, 
    EQPT_CALIB_RMRK)
 Values
   (5994, 11919, TO_DATE('22/10/2013', 'DD/MM/YYYY'), '1', TO_DATE('21/10/2018', 'DD/MM/YYYY'), 
    ' Calibrated on  0000 22/10/2013 by Lerwick RTM - Billy Hamilton');
Insert into EQUIPMENT_CALIBRATION
   (EQPT_CALIB_ID, EQUIPMENT_ID, EQPT_CALIB_DATE, CALIB_MTHD_CODE, EQPT_CALIB_NEXT_DUE_DATE, 
    EQPT_CALIB_RMRK)
 Values
   (7646, 12742, TO_DATE('03/10/2013', 'DD/MM/YYYY'), '1', TO_DATE('02/10/2018', 'DD/MM/YYYY'), 
    ' Calibrated on  0000 03/10/2013 by Peter Kirk - Land networks Coordinator');
Insert into EQUIPMENT_CALIBRATION
   (EQPT_CALIB_ID, EQUIPMENT_ID, EQPT_CALIB_DATE, CALIB_MTHD_CODE, EQPT_CALIB_NEXT_DUE_DATE, 
    EQPT_CALIB_RMRK)
 Values
   (7843, 12838, TO_DATE('03/10/2013', 'DD/MM/YYYY'), '1', TO_DATE('02/10/2021', 'DD/MM/YYYY'), 
    ' Calibrated on  0000 03/10/2013 by Peter Kirk - Land networks Coordinator');
Insert into EQUIPMENT_CALIBRATION
   (EQPT_CALIB_ID, EQUIPMENT_ID, EQPT_CALIB_DATE, CALIB_MTHD_CODE, EQPT_CALIB_NEXT_DUE_DATE, 
    EQPT_CALIB_RMRK)
 Values
   (13794, 15120, TO_DATE('01/01/1971', 'DD/MM/YYYY'), '1', TO_DATE('01/01/1971', 'DD/MM/YYYY'), 
    ' Calibrated on  0000 01/01/1971 by Land Networks Data Analyst');
Insert into EQUIPMENT_CALIBRATION
   (EQPT_CALIB_ID, EQUIPMENT_ID, EQPT_CALIB_DATE, CALIB_MTHD_CODE, EQPT_CALIB_NEXT_DUE_DATE, 
    EQPT_CALIB_RMRK)
 Values
   (13795, 15121, TO_DATE('03/10/2013 1:54:00 PM', 'DD/MM/YYYY HH:MI:SS AM'), '1', TO_DATE('02/10/2021 1:54:00 PM', 'DD/MM/YYYY HH:MI:SS AM'), 
    ' Calibrated on  1354 03/10/2013 by Land Networks Data Analyst');
COMMIT;
Insert into INSPECTION
   (INSPECTION_ID, SRC_ID, INSPECTION_DATE, INSPECTORS_NAME, INSPECTION_REMARK)
 Values
   (3233, 838, TO_DATE('24/06/1995', 'DD/MM/YYYY'), 'MET OFFICER', 'WIND EXPOSURE ASSESSMENT');
Insert into INSPECTION
   (INSPECTION_ID, SRC_ID, INSPECTION_DATE, INSPECTORS_NAME, REVIEW_DATE)
 Values
   (454, 838, TO_DATE('06/05/1987', 'DD/MM/YYYY'), 'UNKNOWN', TO_DATE('06/05/1990', 'DD/MM/YYYY'));
Insert into INSPECTION
   (INSPECTION_ID, SRC_ID, INSPECTION_DATE, INSPECTORS_NAME, REVIEW_DATE)
 Values
   (455, 838, TO_DATE('23/03/1999', 'DD/MM/YYYY'), 'UNKNOWN', TO_DATE('23/03/2002', 'DD/MM/YYYY'));
COMMIT;
Insert into OBSERVING_SYSTEM_INSTALLATION
   (OB_SYS_INTL_ID, OB_SYS_VRSN_ID, SRC_ID, OB_SYS_INTL_BGN_DATE, OB_SYS_INTL_END_DATE)
 Values
   (631, 23, 838, TO_DATE('01/01/1978', 'DD/MM/YYYY'), TO_DATE('30/04/1986', 'DD/MM/YYYY'));
Insert into OBSERVING_SYSTEM_INSTALLATION
   (OB_SYS_INTL_ID, OB_SYS_VRSN_ID, SRC_ID, OB_SYS_INTL_BGN_DATE, OB_SYS_INTL_END_DATE)
 Values
   (632, 23, 838, TO_DATE('01/01/1971', 'DD/MM/YYYY'), TO_DATE('30/09/1974', 'DD/MM/YYYY'));
Insert into OBSERVING_SYSTEM_INSTALLATION
   (OB_SYS_INTL_ID, OB_SYS_VRSN_ID, SRC_ID, OB_SYS_INTL_BGN_DATE, OB_SYS_INTL_END_DATE)
 Values
   (563, 22, 838, TO_DATE('01/05/1986', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'));
Insert into OBSERVING_SYSTEM_INSTALLATION
   (OB_SYS_INTL_ID, OB_SYS_VRSN_ID, SRC_ID, OB_SYS_INTL_BGN_DATE, OB_SYS_INTL_END_DATE)
 Values
   (771, 5, 838, TO_DATE('20/11/1987', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'));
Insert into OBSERVING_SYSTEM_INSTALLATION
   (OB_SYS_INTL_ID, OB_SYS_VRSN_ID, SRC_ID, OB_SYS_INTL_BGN_DATE, OB_SYS_INTL_END_DATE)
 Values
   (73, 4, 838, TO_DATE('18/04/1995', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'));
Insert into OBSERVING_SYSTEM_INSTALLATION
   (OB_SYS_INTL_ID, OB_SYS_VRSN_ID, SRC_ID, OB_SYS_INTL_BGN_DATE, OB_SYS_INTL_END_DATE)
 Values
   (370, 15, 838, TO_DATE('01/02/1965', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'));
Insert into OBSERVING_SYSTEM_INSTALLATION
   (OB_SYS_INTL_ID, OB_SYS_VRSN_ID, SRC_ID, OB_SYS_INTL_BGN_DATE, OB_SYS_INTL_END_DATE)
 Values
   (46, 2, 1605, TO_DATE('05/10/1992', 'DD/MM/YYYY'), TO_DATE('18/03/2014', 'DD/MM/YYYY'));
Insert into OBSERVING_SYSTEM_INSTALLATION
   (OB_SYS_INTL_ID, OB_SYS_VRSN_ID, SRC_ID, OB_SYS_INTL_BGN_DATE, OB_SYS_INTL_END_DATE)
 Values
   (7432, 31, 1605, TO_DATE('18/03/2014', 'DD/MM/YYYY'), TO_DATE('31/12/3999', 'DD/MM/YYYY'));
COMMIT;
Insert into REPORTING_SCHEDULE
   (REPORT_SCHEDULE_ID, ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, 
    RPT_SCHD_BGN_DATE, RPT_SCHD_END_DATE, YEAR_DATE_BGN, YEAR_DATE_END, WEEK_DAY_BGN, 
    WEEK_DAY_END, TIME_OF_DAY_BGN, TIME_OF_DAY_END, REPORTING_INTERVAL, REPORTING_METHOD, 
    PUBLIC_HOLIDAY_FLAG)
 Values
   (1752, '03763', 'WMO', 'HCM', TO_DATE('01/04/1993', 'DD/MM/YYYY'), 
    TO_DATE('01/04/1993', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'), '01/01', '31/12', 1, 
    7, 0, 2300, 60, 'AUTOMATIC', 
    'T');
Insert into REPORTING_SCHEDULE
   (REPORT_SCHEDULE_ID, ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, 
    RPT_SCHD_BGN_DATE, RPT_SCHD_END_DATE, YEAR_DATE_BGN, YEAR_DATE_END, WEEK_DAY_BGN, 
    WEEK_DAY_END, TIME_OF_DAY_BGN, TIME_OF_DAY_END, REPORTING_INTERVAL, REPORTING_METHOD, 
    PUBLIC_HOLIDAY_FLAG)
 Values
   (1753, '03763', 'WMO', 'NCM', TO_DATE('01/01/1982', 'DD/MM/YYYY'), 
    TO_DATE('01/01/1982', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'), '01/01', '31/12', 1, 
    7, 900, 2100, 720, 'AUTOMATIC', 
    'T');
Insert into REPORTING_SCHEDULE
   (REPORT_SCHEDULE_ID, ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, 
    RPT_SCHD_BGN_DATE, RPT_SCHD_END_DATE, YEAR_DATE_BGN, YEAR_DATE_END, WEEK_DAY_BGN, 
    WEEK_DAY_END, TIME_OF_DAY_BGN, TIME_OF_DAY_END, REPORTING_INTERVAL, REPORTING_METHOD, 
    PUBLIC_HOLIDAY_FLAG)
 Values
   (1754, '03763', 'WMO', 'SREW', TO_DATE('01/01/1994', 'DD/MM/YYYY'), 
    TO_DATE('01/01/1994', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'), '01/01', '31/12', 1, 
    7, 0, 2300, 60, 'AUTOMATIC', 
    'T');
Insert into REPORTING_SCHEDULE
   (REPORT_SCHEDULE_ID, ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, 
    RPT_SCHD_BGN_DATE, RPT_SCHD_END_DATE, YEAR_DATE_BGN, YEAR_DATE_END, WEEK_DAY_BGN, 
    WEEK_DAY_END, TIME_OF_DAY_BGN, TIME_OF_DAY_END, REPORTING_INTERVAL, REPORTING_METHOD, 
    PUBLIC_HOLIDAY_FLAG)
 Values
   (1755, '03763', 'WMO', 'SYNOP', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 
    TO_DATE('01/01/1972', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'), '01/01', '31/12', 1, 
    7, 0, 2300, 60, 'AUTOMATIC', 
    'T');
Insert into REPORTING_SCHEDULE
   (REPORT_SCHEDULE_ID, ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, 
    RPT_SCHD_BGN_DATE, RPT_SCHD_END_DATE, YEAR_DATE_BGN, YEAR_DATE_END, WEEK_DAY_BGN, 
    WEEK_DAY_END, TIME_OF_DAY_BGN, TIME_OF_DAY_END, REPORTING_INTERVAL, REPORTING_METHOD, 
    PUBLIC_HOLIDAY_FLAG)
 Values
   (1751, '03764', 'WMO', 'SYNOP', TO_DATE('01/01/1988', 'DD/MM/YYYY'), 
    TO_DATE('01/01/1988', 'DD/MM/YYYY'), TO_DATE('31/12/1992', 'DD/MM/YYYY'), '01/01', '31/12', 1, 
    7, 0, 2300, 60, 'MANUAL', 
    'T');
Insert into REPORTING_SCHEDULE
   (REPORT_SCHEDULE_ID, ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, 
    RPT_SCHD_BGN_DATE, RPT_SCHD_END_DATE, YEAR_DATE_BGN, YEAR_DATE_END, WEEK_DAY_BGN, 
    WEEK_DAY_END, TIME_OF_DAY_BGN, TIME_OF_DAY_END, REPORTING_INTERVAL, REPORTING_METHOD, 
    PUBLIC_HOLIDAY_FLAG)
 Values
   (1743, '272734', 'RAIN', 'NCM', TO_DATE('01/01/1971', 'DD/MM/YYYY'), 
    TO_DATE('01/01/1971', 'DD/MM/YYYY'), TO_DATE('31/03/1992', 'DD/MM/YYYY'), '01/01', '31/12', 1, 
    7, 900, 2100, 720, 'MANUAL', 
    'T');
Insert into REPORTING_SCHEDULE
   (REPORT_SCHEDULE_ID, ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, 
    RPT_SCHD_BGN_DATE, RPT_SCHD_END_DATE, YEAR_DATE_BGN, YEAR_DATE_END, WEEK_DAY_BGN, 
    WEEK_DAY_END, TIME_OF_DAY_BGN, TIME_OF_DAY_END, REPORTING_INTERVAL, REPORTING_METHOD, 
    PUBLIC_HOLIDAY_FLAG)
 Values
   (1744, '272734', 'RAIN', 'SREW', TO_DATE('01/01/1987', 'DD/MM/YYYY'), 
    TO_DATE('01/01/1987', 'DD/MM/YYYY'), TO_DATE('31/12/1987', 'DD/MM/YYYY'), '01/01', '31/12', 1, 
    7, 0, 2300, 60, 'MANUAL', 
    'T');
Insert into REPORTING_SCHEDULE
   (REPORT_SCHEDULE_ID, ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, 
    RPT_SCHD_BGN_DATE, RPT_SCHD_END_DATE, YEAR_DATE_BGN, YEAR_DATE_END, WEEK_DAY_BGN, 
    WEEK_DAY_END, TIME_OF_DAY_BGN, TIME_OF_DAY_END, REPORTING_INTERVAL, REPORTING_METHOD, 
    PUBLIC_HOLIDAY_FLAG)
 Values
   (1745, '272734', 'RAIN', 'SREW', TO_DATE('01/01/1988', 'DD/MM/YYYY'), 
    TO_DATE('01/01/1988', 'DD/MM/YYYY'), TO_DATE('31/12/1991', 'DD/MM/YYYY'), '01/01', '31/12', 1, 
    7, 0, 2300, 60, 'MANUAL', 
    'T');
Insert into REPORTING_SCHEDULE
   (REPORT_SCHEDULE_ID, ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, 
    RPT_SCHD_BGN_DATE, RPT_SCHD_END_DATE, YEAR_DATE_BGN, YEAR_DATE_END, WEEK_DAY_BGN, 
    WEEK_DAY_END, TIME_OF_DAY_BGN, TIME_OF_DAY_END, REPORTING_INTERVAL, REPORTING_METHOD, 
    PUBLIC_HOLIDAY_FLAG)
 Values
   (2479, '272734', 'RAIN', 'WADRAIN', TO_DATE('01/01/1995', 'DD/MM/YYYY'), 
    TO_DATE('01/01/1995', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'), '01/01', '31/12', 1, 
    7, 900, 900, 0, 'MANUAL', 
    'T');
Insert into REPORTING_SCHEDULE
   (REPORT_SCHEDULE_ID, ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, 
    RPT_SCHD_BGN_DATE, RPT_SCHD_END_DATE, YEAR_DATE_BGN, YEAR_DATE_END, WEEK_DAY_BGN, 
    WEEK_DAY_END, TIME_OF_DAY_BGN, TIME_OF_DAY_END, REPORTING_INTERVAL, REPORTING_METHOD, 
    PUBLIC_HOLIDAY_FLAG)
 Values
   (6577, '272734', 'RAIN', 'WAHRAIN', TO_DATE('01/01/1980', 'DD/MM/YYYY'), 
    TO_DATE('01/01/1980', 'DD/MM/YYYY'), TO_DATE('31/12/1987', 'DD/MM/YYYY'), '01/01', '31/12', 1, 
    7, 0, 2300, 60, 'MANUAL', 
    'T');
Insert into REPORTING_SCHEDULE
   (REPORT_SCHEDULE_ID, ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, 
    RPT_SCHD_BGN_DATE, RPT_SCHD_END_DATE, YEAR_DATE_BGN, YEAR_DATE_END, WEEK_DAY_BGN, 
    WEEK_DAY_END, TIME_OF_DAY_BGN, TIME_OF_DAY_END, REPORTING_INTERVAL, REPORTING_METHOD, 
    PUBLIC_HOLIDAY_FLAG)
 Values
   (6576, '272735', 'RAIN', 'SSER', TO_DATE('01/01/1978', 'DD/MM/YYYY'), 
    TO_DATE('01/01/1978', 'DD/MM/YYYY'), TO_DATE('31/12/1992', 'DD/MM/YYYY'), '01/01', '31/12', 1, 
    7, 0, 2300, 60, 'AUTOMATIC', 
    'T');
Insert into REPORTING_SCHEDULE
   (REPORT_SCHEDULE_ID, ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, 
    RPT_SCHD_BGN_DATE, RPT_SCHD_END_DATE, YEAR_DATE_BGN, YEAR_DATE_END, WEEK_DAY_BGN, 
    WEEK_DAY_END, TIME_OF_DAY_BGN, TIME_OF_DAY_END, REPORTING_INTERVAL, REPORTING_METHOD, 
    PUBLIC_HOLIDAY_FLAG)
 Values
   (6575, '272735', 'RAIN', 'SSER', TO_DATE('01/01/1993', 'DD/MM/YYYY'), 
    TO_DATE('01/01/1993', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'), '01/01', '31/12', 1, 
    7, 0, 2300, 60, 'AUTOMATIC', 
    'T');
Insert into REPORTING_SCHEDULE
   (REPORT_SCHEDULE_ID, ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, 
    RPT_SCHD_BGN_DATE, RPT_SCHD_END_DATE, YEAR_DATE_BGN, YEAR_DATE_END, WEEK_DAY_BGN, 
    WEEK_DAY_END, TIME_OF_DAY_BGN, TIME_OF_DAY_END, REPORTING_INTERVAL, REPORTING_METHOD, 
    PUBLIC_HOLIDAY_FLAG)
 Values
   (1746, '272736', 'RAIN', 'SREW', TO_DATE('01/12/1989', 'DD/MM/YYYY'), 
    TO_DATE('01/12/1989', 'DD/MM/YYYY'), TO_DATE('31/12/1991', 'DD/MM/YYYY'), '01/01', '31/12', 1, 
    7, 0, 2300, 60, 'MANUAL', 
    'T');
Insert into REPORTING_SCHEDULE
   (REPORT_SCHEDULE_ID, ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, 
    RPT_SCHD_BGN_DATE, RPT_SCHD_END_DATE, YEAR_DATE_BGN, YEAR_DATE_END, WEEK_DAY_BGN, 
    WEEK_DAY_END, TIME_OF_DAY_BGN, TIME_OF_DAY_END, REPORTING_INTERVAL, REPORTING_METHOD, 
    PUBLIC_HOLIDAY_FLAG)
 Values
   (8857, '272736', 'RAIN', 'WADRAIN', TO_DATE('01/12/1991', 'DD/MM/YYYY'), 
    TO_DATE('01/12/1991', 'DD/MM/YYYY'), TO_DATE('31/12/1992', 'DD/MM/YYYY'), '01/01', '31/12', 1, 
    7, 900, 900, 0, 'MANUAL', 
    'T');
Insert into REPORTING_SCHEDULE
   (REPORT_SCHEDULE_ID, ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, 
    RPT_SCHD_BGN_DATE, RPT_SCHD_END_DATE, YEAR_DATE_BGN, YEAR_DATE_END, WEEK_DAY_BGN, 
    WEEK_DAY_END, TIME_OF_DAY_BGN, TIME_OF_DAY_END, REPORTING_INTERVAL, REPORTING_METHOD, 
    PUBLIC_HOLIDAY_FLAG)
 Values
   (1747, '272737', 'RAIN', 'NCM', TO_DATE('01/04/1992', 'DD/MM/YYYY'), 
    TO_DATE('01/04/1992', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'), '01/01', '31/12', 1, 
    7, 900, 2100, 720, 'AUTOMATIC', 
    'T');
Insert into REPORTING_SCHEDULE
   (REPORT_SCHEDULE_ID, ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, 
    RPT_SCHD_BGN_DATE, RPT_SCHD_END_DATE, YEAR_DATE_BGN, YEAR_DATE_END, WEEK_DAY_BGN, 
    WEEK_DAY_END, TIME_OF_DAY_BGN, TIME_OF_DAY_END, REPORTING_INTERVAL, REPORTING_METHOD, 
    PUBLIC_HOLIDAY_FLAG)
 Values
   (1748, '272737', 'RAIN', 'SREW', TO_DATE('01/01/1996', 'DD/MM/YYYY'), 
    TO_DATE('01/01/1996', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'), '01/01', '31/12', 1, 
    7, 0, 2300, 60, 'AUTOMATIC', 
    'T');
Insert into REPORTING_SCHEDULE
   (REPORT_SCHEDULE_ID, ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, 
    RPT_SCHD_BGN_DATE, RPT_SCHD_END_DATE, YEAR_DATE_BGN, YEAR_DATE_END, WEEK_DAY_BGN, 
    WEEK_DAY_END, TIME_OF_DAY_BGN, TIME_OF_DAY_END, REPORTING_INTERVAL, REPORTING_METHOD, 
    PUBLIC_HOLIDAY_FLAG)
 Values
   (1739, '5591', 'DCNN', 'NCM', TO_DATE('01/12/1991', 'DD/MM/YYYY'), 
    TO_DATE('01/12/1991', 'DD/MM/YYYY'), TO_DATE('31/12/1992', 'DD/MM/YYYY'), '01/01', '31/12', 1, 
    7, 900, 2100, 720, 'MANUAL', 
    'T');
Insert into REPORTING_SCHEDULE
   (REPORT_SCHEDULE_ID, ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, 
    RPT_SCHD_BGN_DATE, RPT_SCHD_END_DATE, YEAR_DATE_BGN, YEAR_DATE_END, WEEK_DAY_BGN, 
    WEEK_DAY_END, TIME_OF_DAY_BGN, TIME_OF_DAY_END, REPORTING_INTERVAL, REPORTING_METHOD, 
    PUBLIC_HOLIDAY_FLAG)
 Values
   (1749, '559101', 'WIND', 'HCM', TO_DATE('01/12/1991', 'DD/MM/YYYY'), 
    TO_DATE('01/12/1991', 'DD/MM/YYYY'), TO_DATE('31/12/1992', 'DD/MM/YYYY'), '01/01', '31/12', 1, 
    7, 0, 2300, 60, 'MANUAL', 
    'T');
Insert into REPORTING_SCHEDULE
   (REPORT_SCHEDULE_ID, ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, 
    RPT_SCHD_BGN_DATE, RPT_SCHD_END_DATE, YEAR_DATE_BGN, YEAR_DATE_END, WEEK_DAY_BGN, 
    WEEK_DAY_END, TIME_OF_DAY_BGN, TIME_OF_DAY_END, REPORTING_INTERVAL, REPORTING_METHOD, 
    PUBLIC_HOLIDAY_FLAG)
 Values
   (6571, '5592', 'DCNN', 'DRADR35', TO_DATE('01/01/1995', 'DD/MM/YYYY'), 
    TO_DATE('01/01/1995', 'DD/MM/YYYY'), TO_DATE('31/12/1996', 'DD/MM/YYYY'), '01/01', '31/12', 1, 
    7, 900, 900, 0, 'MANUAL', 
    'T');
Insert into REPORTING_SCHEDULE
   (REPORT_SCHEDULE_ID, ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, 
    RPT_SCHD_BGN_DATE, RPT_SCHD_END_DATE, YEAR_DATE_BGN, YEAR_DATE_END, WEEK_DAY_BGN, 
    WEEK_DAY_END, TIME_OF_DAY_BGN, TIME_OF_DAY_END, REPORTING_INTERVAL, REPORTING_METHOD, 
    PUBLIC_HOLIDAY_FLAG)
 Values
   (1740, '5592', 'DCNN', 'HCM', TO_DATE('01/07/1994', 'DD/MM/YYYY'), 
    TO_DATE('01/07/1994', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'), '01/01', '31/12', 1, 
    7, 0, 2300, 60, 'AUTOMATIC', 
    'T');
Insert into REPORTING_SCHEDULE
   (REPORT_SCHEDULE_ID, ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, 
    RPT_SCHD_BGN_DATE, RPT_SCHD_END_DATE, YEAR_DATE_BGN, YEAR_DATE_END, WEEK_DAY_BGN, 
    WEEK_DAY_END, TIME_OF_DAY_BGN, TIME_OF_DAY_END, REPORTING_INTERVAL, REPORTING_METHOD, 
    PUBLIC_HOLIDAY_FLAG)
 Values
   (6574, '5592', 'DCNN', 'MODLERAD', TO_DATE('01/02/1965', 'DD/MM/YYYY'), 
    TO_DATE('01/02/1965', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'), '01/01', '31/12', 1, 
    7, 0, 2300, 60, 'MANUAL', 
    'T');
Insert into REPORTING_SCHEDULE
   (REPORT_SCHEDULE_ID, ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, 
    RPT_SCHD_BGN_DATE, RPT_SCHD_END_DATE, YEAR_DATE_BGN, YEAR_DATE_END, WEEK_DAY_BGN, 
    WEEK_DAY_END, TIME_OF_DAY_BGN, TIME_OF_DAY_END, REPORTING_INTERVAL, REPORTING_METHOD, 
    PUBLIC_HOLIDAY_FLAG)
 Values
   (1741, '5592', 'DCNN', 'NCM', TO_DATE('01/01/1971', 'DD/MM/YYYY'), 
    TO_DATE('01/01/1971', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'), '01/01', '31/12', 1, 
    7, 900, 2100, 720, 'AUTOMATIC', 
    'T');
Insert into REPORTING_SCHEDULE
   (REPORT_SCHEDULE_ID, ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, 
    RPT_SCHD_BGN_DATE, RPT_SCHD_END_DATE, YEAR_DATE_BGN, YEAR_DATE_END, WEEK_DAY_BGN, 
    WEEK_DAY_END, TIME_OF_DAY_BGN, TIME_OF_DAY_END, REPORTING_INTERVAL, REPORTING_METHOD, 
    PUBLIC_HOLIDAY_FLAG)
 Values
   (1742, '5592', 'DCNN', 'SYNOP', TO_DATE('01/01/2001', 'DD/MM/YYYY'), 
    TO_DATE('01/01/2001', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'), '01/01', '31/12', 1, 
    7, 0, 2300, 60, 'AUTOMATIC', 
    'T');
Insert into REPORTING_SCHEDULE
   (REPORT_SCHEDULE_ID, ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, 
    RPT_SCHD_BGN_DATE, RPT_SCHD_END_DATE, YEAR_DATE_BGN, YEAR_DATE_END, WEEK_DAY_BGN, 
    WEEK_DAY_END, TIME_OF_DAY_BGN, TIME_OF_DAY_END, REPORTING_INTERVAL, REPORTING_METHOD, 
    PUBLIC_HOLIDAY_FLAG)
 Values
   (1750, '559201', 'WIND', 'HCM', TO_DATE('01/04/1993', 'DD/MM/YYYY'), 
    TO_DATE('01/04/1993', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'), '01/01', '31/12', 1, 
    7, 0, 2300, 60, 'AUTOMATIC', 
    'T');
Insert into REPORTING_SCHEDULE
   (REPORT_SCHEDULE_ID, ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, 
    RPT_SCHD_BGN_DATE, RPT_SCHD_END_DATE, YEAR_DATE_BGN, YEAR_DATE_END, WEEK_DAY_BGN, 
    WEEK_DAY_END, TIME_OF_DAY_BGN, TIME_OF_DAY_END, REPORTING_INTERVAL, REPORTING_METHOD, 
    PUBLIC_HOLIDAY_FLAG, RPT_SCHD_RMRK)
 Values
   (6573, '559201', 'WIND', 'HWND6910', TO_DATE('01/04/1993', 'DD/MM/YYYY'), 
    TO_DATE('01/04/1993', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'), '01/01', '31/12', 1, 
    7, 0, 2300, 60, 'MANUAL', 
    'T', 'ONLY REPORTS WHEN AUTOMATIC SYSTEM UNAVAILABLE');
Insert into REPORTING_SCHEDULE
   (REPORT_SCHEDULE_ID, ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, 
    RPT_SCHD_BGN_DATE, RPT_SCHD_END_DATE, YEAR_DATE_BGN, YEAR_DATE_END, WEEK_DAY_BGN, 
    WEEK_DAY_END, TIME_OF_DAY_BGN, TIME_OF_DAY_END, REPORTING_INTERVAL, REPORTING_METHOD, 
    PUBLIC_HOLIDAY_FLAG)
 Values
   (7834, '61901', 'WMO', 'NCM', TO_DATE('01/01/1962', 'DD/MM/YYYY'), 
    TO_DATE('01/01/1962', 'DD/MM/YYYY'), TO_DATE('31/08/1976', 'DD/MM/YYYY'), '01/01', '31/12', 1, 
    7, 900, 2100, 720, 'MANUAL', 
    'T');
Insert into REPORTING_SCHEDULE
   (REPORT_SCHEDULE_ID, ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, 
    RPT_SCHD_BGN_DATE, RPT_SCHD_END_DATE, YEAR_DATE_BGN, YEAR_DATE_END, WEEK_DAY_BGN, 
    WEEK_DAY_END, TIME_OF_DAY_BGN, TIME_OF_DAY_END, REPORTING_INTERVAL, REPORTING_METHOD, 
    PUBLIC_HOLIDAY_FLAG)
 Values
   (2175, '61901', 'WMO', 'NCM', TO_DATE('01/09/1976', 'DD/MM/YYYY'), 
    TO_DATE('01/09/1976', 'DD/MM/YYYY'), TO_DATE('30/04/1990', 'DD/MM/YYYY'), '01/01', '31/12', 1, 
    7, 900, 2100, 720, 'MANUAL', 
    'T');
Insert into REPORTING_SCHEDULE
   (REPORT_SCHEDULE_ID, ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, 
    RPT_SCHD_BGN_DATE, RPT_SCHD_END_DATE, YEAR_DATE_BGN, YEAR_DATE_END, WEEK_DAY_BGN, 
    WEEK_DAY_END, TIME_OF_DAY_BGN, TIME_OF_DAY_END, REPORTING_INTERVAL, REPORTING_METHOD, 
    PUBLIC_HOLIDAY_FLAG)
 Values
   (2176, '61901', 'WMO', 'SYNOP', TO_DATE('01/09/1976', 'DD/MM/YYYY'), 
    TO_DATE('01/09/1976', 'DD/MM/YYYY'), TO_DATE('31/12/3999', 'DD/MM/YYYY'), '01/01', '31/12', 1, 
    7, 0, 2300, 60, 'AUTOMATIC', 
    'T');
Insert into REPORTING_SCHEDULE
   (REPORT_SCHEDULE_ID, ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, 
    RPT_SCHD_BGN_DATE, RPT_SCHD_END_DATE, YEAR_DATE_BGN, YEAR_DATE_END, WEEK_DAY_BGN, 
    WEEK_DAY_END, TIME_OF_DAY_BGN, TIME_OF_DAY_END, REPORTING_INTERVAL, REPORTING_METHOD, 
    PUBLIC_HOLIDAY_FLAG)
 Values
   (7714, '9884', 'DCNN', 'NCM', TO_DATE('01/01/1962', 'DD/MM/YYYY'), 
    TO_DATE('01/01/1962', 'DD/MM/YYYY'), TO_DATE('31/08/1976', 'DD/MM/YYYY'), '01/01', '31/12', 1, 
    7, 900, 2100, 720, 'MANUAL', 
    'T');
Insert into REPORTING_SCHEDULE
   (REPORT_SCHEDULE_ID, ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, 
    RPT_SCHD_BGN_DATE, RPT_SCHD_END_DATE, YEAR_DATE_BGN, YEAR_DATE_END, WEEK_DAY_BGN, 
    WEEK_DAY_END, TIME_OF_DAY_BGN, TIME_OF_DAY_END, REPORTING_INTERVAL, REPORTING_METHOD, 
    PUBLIC_HOLIDAY_FLAG, RPT_SCHD_RMRK)
 Values
   (6959, '9885', 'DCNN', 'HSUN3445', TO_DATE('01/01/1994', 'DD/MM/YYYY'), 
    TO_DATE('01/01/1994', 'DD/MM/YYYY'), TO_DATE('31/12/2004', 'DD/MM/YYYY'), '01/01', '31/12', 1, 
    7, 0, 2300, 60, 'MANUAL', 
    'T', 'OBSERVATIONS MADE DURING DAYLIGHT HOURS');
Insert into REPORTING_SCHEDULE
   (REPORT_SCHEDULE_ID, ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, 
    RPT_SCHD_BGN_DATE, RPT_SCHD_END_DATE, YEAR_DATE_BGN, YEAR_DATE_END, WEEK_DAY_BGN, 
    WEEK_DAY_END, TIME_OF_DAY_BGN, TIME_OF_DAY_END, REPORTING_INTERVAL, REPORTING_METHOD, 
    PUBLIC_HOLIDAY_FLAG)
 Values
   (2174, '9885', 'DCNN', 'NCM', TO_DATE('01/09/1976', 'DD/MM/YYYY'), 
    TO_DATE('01/09/1976', 'DD/MM/YYYY'), TO_DATE('30/04/1990', 'DD/MM/YYYY'), '01/01', '31/12', 1, 
    7, 900, 2100, 720, 'MANUAL', 
    'T');
Insert into REPORTING_SCHEDULE
   (REPORT_SCHEDULE_ID, ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, 
    RPT_SCHD_BGN_DATE, RPT_SCHD_END_DATE, YEAR_DATE_BGN, YEAR_DATE_END, WEEK_DAY_BGN, 
    WEEK_DAY_END, TIME_OF_DAY_BGN, TIME_OF_DAY_END, REPORTING_INTERVAL, REPORTING_METHOD, 
    PUBLIC_HOLIDAY_FLAG)
 Values
   (225, '988501', 'WIND', 'HCM', TO_DATE('01/11/2001', 'DD/MM/YYYY'), 
    TO_DATE('01/11/2001', 'DD/MM/YYYY'), TO_DATE('31/12/3999', 'DD/MM/YYYY'), '01/01', '31/12', 1, 
    7, 0, 2300, 60, 'AUTOMATIC', 
    'T');
Insert into REPORTING_SCHEDULE
   (REPORT_SCHEDULE_ID, ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, 
    RPT_SCHD_BGN_DATE, RPT_SCHD_END_DATE, YEAR_DATE_BGN, YEAR_DATE_END, WEEK_DAY_BGN, 
    WEEK_DAY_END, TIME_OF_DAY_BGN, TIME_OF_DAY_END, REPORTING_INTERVAL, REPORTING_METHOD, 
    PUBLIC_HOLIDAY_FLAG)
 Values
   (20490, '999813', 'RAIN', 'NCM', TO_DATE('01/11/2001', 'DD/MM/YYYY'), 
    TO_DATE('01/11/2001', 'DD/MM/YYYY'), TO_DATE('31/12/3999', 'DD/MM/YYYY'), '01/01', '31/12', 1, 
    7, 900, 2100, 720, 'AUTOMATIC', 
    'T');
Insert into REPORTING_SCHEDULE
   (REPORT_SCHEDULE_ID, ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, 
    RPT_SCHD_BGN_DATE, RPT_SCHD_END_DATE, YEAR_DATE_BGN, YEAR_DATE_END, WEEK_DAY_BGN, 
    WEEK_DAY_END, TIME_OF_DAY_BGN, TIME_OF_DAY_END, REPORTING_INTERVAL, REPORTING_METHOD, 
    PUBLIC_HOLIDAY_FLAG)
 Values
   (20491, '999813', 'RAIN', 'SREW', TO_DATE('01/11/2001', 'DD/MM/YYYY'), 
    TO_DATE('01/11/2001', 'DD/MM/YYYY'), TO_DATE('31/12/3999', 'DD/MM/YYYY'), '01/01', '31/12', 1, 
    7, 0, 2300, 60, 'AUTOMATIC', 
    'T');
COMMIT;
Insert into SOURCE
   (SRC_ID, SRC_NAME, HIGH_PRCN_LAT, HIGH_PRCN_LON, LOC_GEOG_AREA_ID, 
    REC_ST_IND, SRC_BGN_DATE, SRC_TYPE, GRID_REF_TYPE, SRC_END_DATE, 
    ELEVATION, WMO_REGION_CODE, ZONE_TIME, DRAINAGE_STREAM_ID, SRC_UPD_DATE, 
    SRC_GUID)
 Values
   (1605, 'BOTTOMS WOOD, ST HELENA', -15.9422, -5.6676, 'SHEL', 
    1001, TO_DATE('01/01/1958', 'DD/MM/YYYY'), 'SFC UA', 'XX', TO_DATE('31/12/3999', 'DD/MM/YYYY'), 
    435, '1', 0, '1866', TO_DATE('04/11/2019 4:03:40 PM', 'DD/MM/YYYY HH:MI:SS AM'), 
    '7FF58BDA2BA2405794906F74843099A6');
Insert into SOURCE
   (SRC_ID, SRC_NAME, HIGH_PRCN_LAT, HIGH_PRCN_LON, LOC_GEOG_AREA_ID, 
    REC_ST_IND, SRC_BGN_DATE, SRC_TYPE, GRID_REF_TYPE, EAST_GRID_REF, 
    NORTH_GRID_REF, HYDR_AREA_ID, POST_CODE, SRC_END_DATE, ELEVATION, 
    WMO_REGION_CODE, PARENT_SRC_ID, ZONE_TIME, DRAINAGE_STREAM_ID, SRC_UPD_DATE, 
    MTCE_CTRE_CODE, PLACE_ID, LAT_WGS84, LON_WGS84, SRC_GUID)
 Values
   (838, 'BRACKNELL, BEAUFORT PARK', 51.38983, -0.784, 'BRK', 
    1001, TO_DATE('01/01/1965', 'DD/MM/YYYY'), 'SFC', 'OS', 484600, 
    166400, 392, 'RG11 3', TO_DATE('30/06/2003', 'DD/MM/YYYY'), 74, 
    '6', 811, 0, '1239', TO_DATE('29/01/2014 10:07:14 AM', 'DD/MM/YYYY HH:MI:SS AM'), 
    'CRAW', 801, 51.39034, -0.78553, 'B98EDC41481248F38DF573661A00A10F');
Insert into SOURCE
   (SRC_ID, SRC_NAME, HIGH_PRCN_LAT, HIGH_PRCN_LON, LOC_GEOG_AREA_ID, 
    REC_ST_IND, SRC_BGN_DATE, SRC_TYPE, GRID_REF_TYPE, SRC_END_DATE, 
    ELEVATION, WMO_REGION_CODE, ZONE_TIME, SRC_UPD_DATE, SRC_GUID)
 Values
   (1604, 'HUTTS GATE, ST HELENA', -15.95, -5.667, 'SHEL', 
    1001, TO_DATE('01/01/1925', 'DD/MM/YYYY'), 'SFC', 'XX', TO_DATE('31/12/1976', 'DD/MM/YYYY'), 
    627, '1', 0, TO_DATE('29/01/2014 10:07:15 AM', 'DD/MM/YYYY HH:MI:SS AM'), '537673F419C44B6884415361B2257FFE');
COMMIT;
Insert into SRC_CAPABILITY
   (ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, SRC_ID, 
    REC_ST_IND, PRIME_CAPABILITY_FLAG, SRC_CAP_END_DATE, FIRST_ONLINE_OB_YR)
 Values
   ('272734', 'RAIN', 'CLMSN', TO_DATE('01/01/1961', 'DD/MM/YYYY'), 838, 
    1001, 'F', TO_DATE('31/12/1990', 'DD/MM/YYYY'), 1990);
Insert into SRC_CAPABILITY
   (ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, SRC_ID, 
    REC_ST_IND, PRIME_CAPABILITY_FLAG, SRC_CAP_END_DATE, FIRST_ONLINE_OB_YR)
 Values
   ('272735', 'RAIN', 'CLMSN', TO_DATE('01/01/1961', 'DD/MM/YYYY'), 838, 
    1001, 'F', TO_DATE('31/12/1990', 'DD/MM/YYYY'), 1990);
Insert into SRC_CAPABILITY
   (ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, SRC_ID, 
    REC_ST_IND, PRIME_CAPABILITY_FLAG, SRC_CAP_END_DATE, FIRST_ONLINE_OB_YR)
 Values
   ('5592', 'DCNN', 'CLMSN', TO_DATE('01/01/1961', 'DD/MM/YYYY'), 838, 
    1001, 'F', TO_DATE('31/12/1990', 'DD/MM/YYYY'), 1990);
Insert into SRC_CAPABILITY
   (ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, SRC_ID, 
    REC_ST_IND, PRIME_CAPABILITY_FLAG, SRC_CAP_END_DATE, FIRST_ONLINE_OB_YR, RCPT_METHOD_NAME)
 Values
   ('5592', 'DCNN', 'DRADR35', TO_DATE('01/01/1995', 'DD/MM/YYYY'), 838, 
    1001, 'T', TO_DATE('31/12/1996', 'DD/MM/YYYY'), 1996, 'ID XREF 1');
Insert into SRC_CAPABILITY
   (ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, SRC_ID, 
    REC_ST_IND, PRIME_CAPABILITY_FLAG, SRC_CAP_END_DATE, FIRST_ONLINE_OB_YR, RCPT_METHOD_NAME)
 Values
   ('559201', 'WIND', 'HWND6910', TO_DATE('01/04/1993', 'DD/MM/YYYY'), 838, 
    1001, 'F', TO_DATE('30/06/2003', 'DD/MM/YYYY'), 1996, 'ID XREF 1');
Insert into SRC_CAPABILITY
   (ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, SRC_ID, 
    REC_ST_IND, PRIME_CAPABILITY_FLAG, SRC_CAP_END_DATE, FIRST_ONLINE_OB_YR, RCPT_METHOD_NAME)
 Values
   ('5592', 'DCNN', 'MODLERAD', TO_DATE('01/02/1965', 'DD/MM/YYYY'), 838, 
    1001, 'T', TO_DATE('30/06/2003', 'DD/MM/YYYY'), 1997, 'ID XREF 1');
Insert into SRC_CAPABILITY
   (ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, SRC_ID, 
    REC_ST_IND, PRIME_CAPABILITY_FLAG, SRC_CAP_END_DATE, FIRST_ONLINE_OB_YR, RCPT_METHOD_NAME, 
    COMM_MTHD_ID)
 Values
   ('272737', 'RAIN', 'NCM', TO_DATE('01/04/1992', 'DD/MM/YYYY'), 838, 
    1001, 'T', TO_DATE('30/06/2003', 'DD/MM/YYYY'), 1996, 'ID XREF 1', 
    114);
Insert into SRC_CAPABILITY
   (ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, SRC_ID, 
    REC_ST_IND, PRIME_CAPABILITY_FLAG, SRC_CAP_END_DATE, FIRST_ONLINE_OB_YR, RCPT_METHOD_NAME, 
    COMM_MTHD_ID)
 Values
   ('5591', 'DCNN', 'NCM', TO_DATE('01/12/1991', 'DD/MM/YYYY'), 838, 
    1001, 'F', TO_DATE('31/12/1992', 'DD/MM/YYYY'), 1992, 'ID XREF 2', 
    114);
Insert into SRC_CAPABILITY
   (ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, SRC_ID, 
    REC_ST_IND, PRIME_CAPABILITY_FLAG, SRC_CAP_END_DATE, FIRST_ONLINE_OB_YR, RCPT_METHOD_NAME, 
    COMM_MTHD_ID)
 Values
   ('5592', 'DCNN', 'NCM', TO_DATE('01/01/1971', 'DD/MM/YYYY'), 838, 
    1001, 'T', TO_DATE('30/06/2003', 'DD/MM/YYYY'), 1996, 'ID XREF 1', 
    114);
Insert into SRC_CAPABILITY
   (ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, SRC_ID, 
    REC_ST_IND, PRIME_CAPABILITY_FLAG, SRC_CAP_END_DATE, RCPT_METHOD_NAME, COMM_MTHD_ID)
 Values
   ('03763', 'WMO', 'NCM', TO_DATE('01/01/1982', 'DD/MM/YYYY'), 838, 
    1001, 'F', TO_DATE('30/06/2003', 'DD/MM/YYYY'), 'ID XREF 1', 114);
Insert into SRC_CAPABILITY
   (ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, SRC_ID, 
    REC_ST_IND, PRIME_CAPABILITY_FLAG, SRC_CAP_END_DATE, FIRST_ONLINE_OB_YR, RCPT_METHOD_NAME, 
    COMM_MTHD_ID)
 Values
   ('272734', 'RAIN', 'NCM', TO_DATE('01/01/1971', 'DD/MM/YYYY'), 838, 
    1001, 'T', TO_DATE('31/03/1992', 'DD/MM/YYYY'), 1996, 'ID XREF 1', 
    114);
Insert into SRC_CAPABILITY
   (ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, SRC_ID, 
    REC_ST_IND, PRIME_CAPABILITY_FLAG, SRC_CAP_END_DATE, FIRST_ONLINE_OB_YR, RCPT_METHOD_NAME, 
    COMM_MTHD_ID)
 Values
   ('272737', 'RAIN', 'SREW', TO_DATE('01/01/1996', 'DD/MM/YYYY'), 838, 
    1001, 'F', TO_DATE('30/06/2003', 'DD/MM/YYYY'), 1996, 'ID XREF 1', 
    114);
Insert into SRC_CAPABILITY
   (ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, SRC_ID, 
    REC_ST_IND, PRIME_CAPABILITY_FLAG, SRC_CAP_END_DATE, RCPT_METHOD_NAME, COMM_MTHD_ID)
 Values
   ('03763', 'WMO', 'SREW', TO_DATE('01/01/1994', 'DD/MM/YYYY'), 838, 
    1001, 'F', TO_DATE('30/06/2003', 'DD/MM/YYYY'), 'ID XREF 1', 114);
Insert into SRC_CAPABILITY
   (ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, SRC_ID, 
    REC_ST_IND, PRIME_CAPABILITY_FLAG, SRC_CAP_END_DATE, FIRST_ONLINE_OB_YR, RCPT_METHOD_NAME, 
    COMM_MTHD_ID)
 Values
   ('272736', 'RAIN', 'SREW', TO_DATE('01/12/1989', 'DD/MM/YYYY'), 838, 
    1001, 'F', TO_DATE('31/12/1991', 'DD/MM/YYYY'), 1991, 'ID XREF 2', 
    114);
Insert into SRC_CAPABILITY
   (ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, SRC_ID, 
    REC_ST_IND, PRIME_CAPABILITY_FLAG, SRC_CAP_END_DATE, FIRST_ONLINE_OB_YR, RCPT_METHOD_NAME, 
    COMM_MTHD_ID)
 Values
   ('272734', 'RAIN', 'SREW', TO_DATE('01/01/1988', 'DD/MM/YYYY'), 838, 
    1001, 'T', TO_DATE('31/12/1991', 'DD/MM/YYYY'), 1991, 'ID XREF 1', 
    114);
Insert into SRC_CAPABILITY
   (ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, SRC_ID, 
    REC_ST_IND, PRIME_CAPABILITY_FLAG, SRC_CAP_END_DATE, FIRST_ONLINE_OB_YR, RCPT_METHOD_NAME, 
    COMM_MTHD_ID)
 Values
   ('272734', 'RAIN', 'SREW', TO_DATE('01/01/1987', 'DD/MM/YYYY'), 838, 
    1001, 'F', TO_DATE('31/12/1987', 'DD/MM/YYYY'), 1987, 'ID XREF 1', 
    114);
Insert into SRC_CAPABILITY
   (ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, SRC_ID, 
    REC_ST_IND, PRIME_CAPABILITY_FLAG, SRC_CAP_END_DATE, FIRST_ONLINE_OB_YR, RCPT_METHOD_NAME)
 Values
   ('272735', 'RAIN', 'SSER', TO_DATE('01/01/1993', 'DD/MM/YYYY'), 838, 
    1001, 'T', TO_DATE('31/05/2001', 'DD/MM/YYYY'), 1996, 'ID XREF 1');
Insert into SRC_CAPABILITY
   (ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, SRC_ID, 
    REC_ST_IND, PRIME_CAPABILITY_FLAG, SRC_CAP_END_DATE, FIRST_ONLINE_OB_YR, RCPT_METHOD_NAME)
 Values
   ('272735', 'RAIN', 'SSER', TO_DATE('01/01/1978', 'DD/MM/YYYY'), 838, 
    1001, 'F', TO_DATE('31/12/1992', 'DD/MM/YYYY'), 1996, 'ID XREF 1');
Insert into SRC_CAPABILITY
   (ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, SRC_ID, 
    REC_ST_IND, PRIME_CAPABILITY_FLAG, SRC_CAP_END_DATE, FIRST_ONLINE_OB_YR, RCPT_METHOD_NAME, 
    COMM_MTHD_ID)
 Values
   ('03764', 'WMO', 'SYNOP', TO_DATE('01/01/1988', 'DD/MM/YYYY'), 838, 
    1001, 'F', TO_DATE('31/12/1992', 'DD/MM/YYYY'), 1992, 'ID XREF 2', 
    114);
Insert into SRC_CAPABILITY
   (ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, SRC_ID, 
    REC_ST_IND, PRIME_CAPABILITY_FLAG, SRC_CAP_END_DATE, FIRST_ONLINE_OB_YR, RCPT_METHOD_NAME, 
    COMM_MTHD_ID)
 Values
   ('03763', 'WMO', 'SYNOP', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 838, 
    1001, 'T', TO_DATE('30/06/2003', 'DD/MM/YYYY'), 1996, 'ID XREF 1', 
    114);
Insert into SRC_CAPABILITY
   (ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, SRC_ID, 
    REC_ST_IND, PRIME_CAPABILITY_FLAG, SRC_CAP_END_DATE, FIRST_ONLINE_OB_YR, RCPT_METHOD_NAME)
 Values
   ('272734', 'RAIN', 'WADRAIN', TO_DATE('01/01/1995', 'DD/MM/YYYY'), 838, 
    1001, 'F', TO_DATE('30/06/2003', 'DD/MM/YYYY'), 1996, 'ID XREF 1');
Insert into SRC_CAPABILITY
   (ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, SRC_ID, 
    REC_ST_IND, PRIME_CAPABILITY_FLAG, SRC_CAP_END_DATE, FIRST_ONLINE_OB_YR, RCPT_METHOD_NAME)
 Values
   ('272736', 'RAIN', 'WADRAIN', TO_DATE('01/12/1991', 'DD/MM/YYYY'), 838, 
    1001, 'F', TO_DATE('31/12/1992', 'DD/MM/YYYY'), 1992, 'ID XREF 2');
Insert into SRC_CAPABILITY
   (ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, SRC_ID, 
    REC_ST_IND, PRIME_CAPABILITY_FLAG, SRC_CAP_END_DATE, FIRST_ONLINE_OB_YR, RCPT_METHOD_NAME)
 Values
   ('272734', 'RAIN', 'WAHRAIN', TO_DATE('01/01/1980', 'DD/MM/YYYY'), 838, 
    1001, 'T', TO_DATE('31/12/1987', 'DD/MM/YYYY'), 1987, 'ID XREF 1');
Insert into SRC_CAPABILITY
   (ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, SRC_ID, 
    REC_ST_IND, PRIME_CAPABILITY_FLAG, SRC_CAP_END_DATE, FIRST_ONLINE_OB_YR, RCPT_METHOD_NAME, 
    COMM_MTHD_ID)
 Values
   ('559101', 'WIND', 'HCM', TO_DATE('01/12/1991', 'DD/MM/YYYY'), 838, 
    1001, 'T', TO_DATE('31/12/1992', 'DD/MM/YYYY'), 1992, 'ID XREF 2', 
    114);
Insert into SRC_CAPABILITY
   (ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, SRC_ID, 
    REC_ST_IND, PRIME_CAPABILITY_FLAG, SRC_CAP_END_DATE, FIRST_ONLINE_OB_YR, RCPT_METHOD_NAME, 
    COMM_MTHD_ID)
 Values
   ('5592', 'DCNN', 'HCM', TO_DATE('01/07/1994', 'DD/MM/YYYY'), 838, 
    1001, 'T', TO_DATE('30/06/2003', 'DD/MM/YYYY'), 1997, 'ID XREF 1', 
    114);
Insert into SRC_CAPABILITY
   (ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, SRC_ID, 
    REC_ST_IND, PRIME_CAPABILITY_FLAG, SRC_CAP_END_DATE, FIRST_ONLINE_OB_YR, RCPT_METHOD_NAME, 
    COMM_MTHD_ID)
 Values
   ('559201', 'WIND', 'HCM', TO_DATE('01/04/1993', 'DD/MM/YYYY'), 838, 
    1001, 'T', TO_DATE('30/06/2003', 'DD/MM/YYYY'), 1996, 'ID XREF 1', 
    114);
Insert into SRC_CAPABILITY
   (ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, SRC_ID, 
    REC_ST_IND, PRIME_CAPABILITY_FLAG, SRC_CAP_END_DATE, FIRST_ONLINE_OB_YR, RCPT_METHOD_NAME, 
    COMM_MTHD_ID)
 Values
   ('5592', 'DCNN', 'SYNOP', TO_DATE('01/01/2001', 'DD/MM/YYYY'), 838, 
    1001, 'T', TO_DATE('30/06/2003', 'DD/MM/YYYY'), 2001, 'ID XREF 1', 
    114);
Insert into SRC_CAPABILITY
   (ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, SRC_ID, 
    REC_ST_IND, PRIME_CAPABILITY_FLAG, SRC_CAP_END_DATE)
 Values
   ('5592', 'DCNN', 'CARLOS', TO_DATE('01/02/1965', 'DD/MM/YYYY'), 838, 
    1, 'T', TO_DATE('30/06/2003', 'DD/MM/YYYY'));
Insert into SRC_CAPABILITY
   (ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, SRC_ID, 
    REC_ST_IND, PRIME_CAPABILITY_FLAG, SRC_CAP_END_DATE, RCPT_METHOD_NAME, COMM_MTHD_ID)
 Values
   ('03763', 'WMO', 'HCM', TO_DATE('01/04/1993', 'DD/MM/YYYY'), 838, 
    1001, 'F', TO_DATE('30/06/2003', 'DD/MM/YYYY'), 'ID XREF 1', 114);
Insert into SRC_CAPABILITY
   (ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, SRC_ID, 
    REC_ST_IND, PRIME_CAPABILITY_FLAG, SRC_CAP_END_DATE, FIRST_ONLINE_OB_YR, RCPT_METHOD_NAME)
 Values
   ('5592', 'DCNN', 'HSUN3445', TO_DATE('01/01/1981', 'DD/MM/YYYY'), 838, 
    1001, 'T', TO_DATE('30/06/2003', 'DD/MM/YYYY'), 1996, 'ID XREF 1');
Insert into SRC_CAPABILITY
   (ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, SRC_ID, 
    REC_ST_IND, PRIME_CAPABILITY_FLAG, SRC_CAP_END_DATE, FIRST_ONLINE_OB_YR, RCPT_METHOD_NAME, 
    COMM_MTHD_ID)
 Values
   ('9884', 'DCNN', 'NCM', TO_DATE('01/01/1962', 'DD/MM/YYYY'), 1604, 
    1001, 'T', TO_DATE('31/08/1976', 'DD/MM/YYYY'), 1962, 'ID XREF 1', 
    284);
Insert into SRC_CAPABILITY
   (ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, SRC_ID, 
    REC_ST_IND, PRIME_CAPABILITY_FLAG, SRC_CAP_END_DATE, DB_SEGMENT_NAME, RCPT_METHOD_NAME, 
    COMM_MTHD_ID)
 Values
   ('61901', 'WMO', 'SYNOP', TO_DATE('01/01/1976', 'DD/MM/YYYY'), 1604, 
    1001, 'T', TO_DATE('31/08/1976', 'DD/MM/YYYY'), 'WX_HRLY_OB', 'ID XREF 1', 
    284);
Insert into SRC_CAPABILITY
   (ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, SRC_ID, 
    REC_ST_IND, PRIME_CAPABILITY_FLAG, SRC_CAP_END_DATE, RCPT_METHOD_NAME, COMM_MTHD_ID)
 Values
   ('61901', 'WMO', 'NCM', TO_DATE('01/01/1962', 'DD/MM/YYYY'), 1604, 
    1001, 'F', TO_DATE('31/08/1976', 'DD/MM/YYYY'), 'ID XREF 1', 284);
Insert into SRC_CAPABILITY
   (ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, SRC_ID, 
    REC_ST_IND, PRIME_CAPABILITY_FLAG, SRC_CAP_END_DATE)
 Values
   ('988401', 'WIND', 'HWND6910', TO_DATE('01/01/1962', 'DD/MM/YYYY'), 1604, 
    1001, 'T', TO_DATE('30/06/1971', 'DD/MM/YYYY'));
Insert into SRC_CAPABILITY
   (ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, SRC_ID, 
    REC_ST_IND, PRIME_CAPABILITY_FLAG, SRC_CAP_END_DATE)
 Values
   ('61901', 'WMO', 'CLM71-06', TO_DATE('01/01/1892', 'DD/MM/YYYY'), 1605, 
    1001, 'F', TO_DATE('31/10/1994', 'DD/MM/YYYY'));
Insert into SRC_CAPABILITY
   (ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, SRC_ID, 
    REC_ST_IND, PRIME_CAPABILITY_FLAG, SRC_CAP_END_DATE)
 Values
   ('61901', 'WMO', 'CLM71-11', TO_DATE('01/11/1994', 'DD/MM/YYYY'), 1605, 
    1001, 'F', TO_DATE('31/12/3999', 'DD/MM/YYYY'));
Insert into SRC_CAPABILITY
   (ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, SRC_ID, 
    REC_ST_IND, PRIME_CAPABILITY_FLAG, SRC_CAP_END_DATE, RCPT_METHOD_NAME)
 Values
   ('9885', 'DCNN', 'HSUN3445', TO_DATE('01/01/1994', 'DD/MM/YYYY'), 1605, 
    1001, 'T', TO_DATE('31/12/2004', 'DD/MM/YYYY'), 'ID XREF 1');
Insert into SRC_CAPABILITY
   (ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, SRC_ID, 
    REC_ST_IND, PRIME_CAPABILITY_FLAG, SRC_CAP_END_DATE, RCPT_METHOD_NAME, COMM_MTHD_ID)
 Values
   ('9885', 'DCNN', 'NCM', TO_DATE('01/09/1976', 'DD/MM/YYYY'), 1605, 
    1001, 'T', TO_DATE('30/04/1990', 'DD/MM/YYYY'), 'ID XREF 1', 218);
Insert into SRC_CAPABILITY
   (ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, SRC_ID, 
    REC_ST_IND, PRIME_CAPABILITY_FLAG, SRC_CAP_END_DATE, RCPT_METHOD_NAME, COMM_MTHD_ID)
 Values
   ('61901', 'WMO', 'NCM', TO_DATE('01/09/1976', 'DD/MM/YYYY'), 1605, 
    1001, 'F', TO_DATE('30/04/1990', 'DD/MM/YYYY'), 'ID XREF 1', 218);
Insert into SRC_CAPABILITY
   (ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, SRC_ID, 
    REC_ST_IND, PRIME_CAPABILITY_FLAG, SRC_CAP_END_DATE, FIRST_ONLINE_OB_YR, DB_SEGMENT_NAME, 
    RCPT_METHOD_NAME, DATA_RETENTION_PERIOD, COMM_MTHD_ID)
 Values
   ('61901', 'WMO', 'SYNOP', TO_DATE('01/09/1976', 'DD/MM/YYYY'), 1605, 
    1001, 'T', TO_DATE('31/12/3999', 'DD/MM/YYYY'), 1996, 'WX_HRLY_OB', 
    'ID XREF 1', 999, 218);
Insert into SRC_CAPABILITY
   (ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, SRC_ID, 
    REC_ST_IND, PRIME_CAPABILITY_FLAG, SRC_CAP_END_DATE, FIRST_ONLINE_OB_YR, DB_SEGMENT_NAME, 
    DATA_RETENTION_PERIOD)
 Values
   ('61901', 'WMO', 'UAPLT', TO_DATE('29/12/1976', 'DD/MM/YYYY'), 1605, 
    1001, 'F', TO_DATE('09/05/1995', 'DD/MM/YYYY'), 1995, 'UKOVRS.Yyyyy', 
    999);
Insert into SRC_CAPABILITY
   (ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, SRC_ID, 
    REC_ST_IND, PRIME_CAPABILITY_FLAG, SRC_CAP_END_DATE, FIRST_ONLINE_OB_YR, DB_SEGMENT_NAME, 
    DATA_RETENTION_PERIOD)
 Values
   ('61901', 'WMO', 'UATMP', TO_DATE('01/01/1977', 'DD/MM/YYYY'), 1605, 
    1001, 'F', TO_DATE('31/12/3999', 'DD/MM/YYYY'), 2014, 'UKOVRS.Yyyyy', 
    999);
Insert into SRC_CAPABILITY
   (ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, SRC_ID, 
    REC_ST_IND, PRIME_CAPABILITY_FLAG, SRC_CAP_END_DATE)
 Values
   ('61901', 'WMO', 'CLM75TMP', TO_DATE('01/11/1983', 'DD/MM/YYYY'), 1605, 
    1001, 'F', TO_DATE('31/12/3999', 'DD/MM/YYYY'));
Insert into SRC_CAPABILITY
   (ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, SRC_ID, 
    REC_ST_IND, PRIME_CAPABILITY_FLAG, SRC_CAP_END_DATE)
 Values
   ('61901', 'WMO', 'CLM71', TO_DATE('01/01/1961', 'DD/MM/YYYY'), 1605, 
    1001, 'F', TO_DATE('31/12/3999', 'DD/MM/YYYY'));
Insert into SRC_CAPABILITY
   (ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, SRC_ID, 
    REC_ST_IND, PRIME_CAPABILITY_FLAG, SRC_CAP_END_DATE)
 Values
   ('988501', 'WIND', 'HWND6910', TO_DATE('01/01/1977', 'DD/MM/YYYY'), 1605, 
    1001, 'T', TO_DATE('30/09/1992', 'DD/MM/YYYY'));
Insert into SRC_CAPABILITY
   (ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, SRC_ID, 
    REC_ST_IND, PRIME_CAPABILITY_FLAG, SRC_CAP_END_DATE, FIRST_ONLINE_OB_YR, RCPT_METHOD_NAME)
 Values
   ('988501', 'WIND', 'HCM', TO_DATE('01/11/2001', 'DD/MM/YYYY'), 1605, 
    1001, 'T', TO_DATE('31/12/3999', 'DD/MM/YYYY'), 2001, 'ID XREF 1');
Insert into SRC_CAPABILITY
   (ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, SRC_ID, 
    REC_ST_IND, PRIME_CAPABILITY_FLAG, SRC_CAP_END_DATE, FIRST_ONLINE_OB_YR, RCPT_METHOD_NAME)
 Values
   ('61901', 'WMO', 'NCM', TO_DATE('01/11/2001', 'DD/MM/YYYY'), 1605, 
    1001, 'F', TO_DATE('31/12/3999', 'DD/MM/YYYY'), 2001, 'ID XREF 1');
Insert into SRC_CAPABILITY
   (ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, SRC_ID, 
    REC_ST_IND, PRIME_CAPABILITY_FLAG, SRC_CAP_END_DATE, FIRST_ONLINE_OB_YR, RCPT_METHOD_NAME)
 Values
   ('61901', 'WMO', 'SREW', TO_DATE('01/11/2001', 'DD/MM/YYYY'), 1605, 
    1001, 'F', TO_DATE('31/12/3999', 'DD/MM/YYYY'), 2001, 'ID XREF 1');
Insert into SRC_CAPABILITY
   (ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, SRC_ID, 
    REC_ST_IND, PRIME_CAPABILITY_FLAG, SRC_CAP_END_DATE, FIRST_ONLINE_OB_YR, RCPT_METHOD_NAME)
 Values
   ('61901', 'WMO', 'HCM', TO_DATE('01/11/2001', 'DD/MM/YYYY'), 1605, 
    1001, 'T', TO_DATE('31/12/3999', 'DD/MM/YYYY'), 2001, 'ID XREF 1');
Insert into SRC_CAPABILITY
   (ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, SRC_ID, 
    REC_ST_IND, PRIME_CAPABILITY_FLAG, SRC_CAP_END_DATE, FIRST_ONLINE_OB_YR, RCPT_METHOD_NAME)
 Values
   ('999813', 'RAIN', 'NCM', TO_DATE('01/11/2001', 'DD/MM/YYYY'), 1605, 
    1001, 'T', TO_DATE('31/12/3999', 'DD/MM/YYYY'), 2001, 'ID XREF 1');
Insert into SRC_CAPABILITY
   (ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, SRC_ID, 
    REC_ST_IND, PRIME_CAPABILITY_FLAG, SRC_CAP_END_DATE, FIRST_ONLINE_OB_YR, RCPT_METHOD_NAME)
 Values
   ('9885', 'DCNN', 'NCM', TO_DATE('01/11/2001', 'DD/MM/YYYY'), 1605, 
    1001, 'T', TO_DATE('31/12/3999', 'DD/MM/YYYY'), 2001, 'ID XREF 1');
Insert into SRC_CAPABILITY
   (ID, ID_TYPE, MET_DOMAIN_NAME, SRC_CAP_BGN_DATE, SRC_ID, 
    REC_ST_IND, PRIME_CAPABILITY_FLAG, SRC_CAP_END_DATE, FIRST_ONLINE_OB_YR, RCPT_METHOD_NAME)
 Values
   ('999813', 'RAIN', 'SREW', TO_DATE('01/11/2001', 'DD/MM/YYYY'), 1605, 
    1001, 'T', TO_DATE('31/12/3999', 'DD/MM/YYYY'), 2001, 'ID XREF 1');
COMMIT;
Insert into STATION_AUTHORITY_HISTORY
   (AUTHORITY_ID, SRC_ID, STN_AUTH_BGN_DATE, STN_AUTH_END_DATE)
 Values
   (3380, 838, TO_DATE('01/01/1965', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'));
Insert into STATION_AUTHORITY_HISTORY
   (AUTHORITY_ID, SRC_ID, STN_AUTH_BGN_DATE, STN_AUTH_END_DATE)
 Values
   (3380, 1605, TO_DATE('01/01/2000', 'DD/MM/YYYY'), TO_DATE('31/12/3999', 'DD/MM/YYYY'));
COMMIT;
Insert into STATION_GEOGRAPHY
   (SRC_ID, GEOG_UPD_DATE, PR_GEOG_TYPE_CODE, SITE_TYPE_CODE, LAND_USE_TYPE_ID)
 Values
   (838, TO_DATE('24/06/1995', 'DD/MM/YYYY'), 'FLAT', 'CONVENTIONAL', 10);
Insert into STATION_GEOGRAPHY
   (SRC_ID, GEOG_UPD_DATE, PR_GEOG_TYPE_CODE, SITE_TYPE_CODE, LAND_USE_TYPE_ID, 
    GRND_SLPE_UP_DIR, GRADIENT, PRC_MAN_WTHN_10M, PRC_VEG_WTHN_10M, PRC_MAN_WTHN_50M, 
    PRC_VEG_WTHN_50M)
 Values
   (838, TO_DATE('23/03/1999', 'DD/MM/YYYY'), 'FLAT', 'CONVENTIONAL', 51, 
    180, 4, 20, 0, 30, 
    20);
COMMIT;
Insert into STATION_HISTORY
   (SRC_ID, EVENT_DATE, EVENT_TEXT, EVENT_RESULT_TEXT)
 Values
   (838, TO_DATE('16/11/2010', 'DD/MM/YYYY'), 'MIDAS.SOURCE AND METADATA.DEPLOYMENT HIGH_PRC_LAT AND HIGH_PRCN_LON UPDATED', 'PREVIOUS CALCULATION ERRORS HAVE BEEN CORRECTED AND VALUES UPDATED TO 5 DECIMAL PLACE PRECISION');
Insert into STATION_HISTORY
   (SRC_ID, EVENT_DATE, EVENT_TEXT, EVENT_RESULT_TEXT)
 Values
   (1605, TO_DATE('01/01/2004', 'DD/MM/YYYY'), 'REGIONAL NETWORK MANAGER', 'OTHER');
Insert into STATION_HISTORY
   (SRC_ID, EVENT_DATE, EVENT_TEXT, EVENT_RESULT_TEXT)
 Values
   (1605, TO_DATE('18/04/2018', 'DD/MM/YYYY'), 'CHANGE TO THE SERVICE-MAINTENANCE REPORTING SYSTEM', 'LOGS MOVED FROM REMEDY TO THE SERVICENOW SYSTEM');
COMMIT;
Insert into STATION_INVENTORY_STATUS
   (SRC_ID, INVENTORY_CODE, INVT_STS_BGN_DATE, INVT_STS_END_DATE, INVT_STS_RMRK)
 Values
   (1605, 'F', TO_DATE('01/01/1958', 'DD/MM/YYYY'), TO_DATE('31/12/3999', 'DD/MM/YYYY'), 'FINANCIAL RESPONSIBILITY OF MET OFFICE');
COMMIT;
Insert into STATION_OBSERVER
   (OBSERVER_ID, SRC_ID, STN_OBSR_BGN_DATE, STN_OBSR_END_DATE, OBSERVER_ROLE_CODE)
 Values
   (13688, 1605, TO_DATE('01/01/1976', 'DD/MM/YYYY'), TO_DATE('31/12/3999', 'DD/MM/YYYY'), 'PRMY');
COMMIT;
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (41045, '03763', 'WMO', TO_DATE('01/01/1982', 'DD/MM/YYYY'), 'NCM', 
    20062, TO_DATE('26/02/1997', 'DD/MM/YYYY'), TO_DATE('08/09/1998', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459871, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20014, TO_DATE('01/12/1972', 'DD/MM/YYYY'), TO_DATE('29/06/2003', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459884, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20015, TO_DATE('01/12/1972', 'DD/MM/YYYY'), TO_DATE('31/03/1999', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459893, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20016, TO_DATE('01/12/1972', 'DD/MM/YYYY'), TO_DATE('29/06/2003', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459974, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20019, TO_DATE('21/09/1982', 'DD/MM/YYYY'), TO_DATE('20/11/1989', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459975, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20019, TO_DATE('16/12/1989', 'DD/MM/YYYY'), TO_DATE('23/08/1991', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459976, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20019, TO_DATE('21/12/1991', 'DD/MM/YYYY'), TO_DATE('09/05/2001', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459977, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20019, TO_DATE('12/08/2001', 'DD/MM/YYYY'), TO_DATE('27/06/2003', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (362155, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20018, TO_DATE('14/09/1991', 'DD/MM/YYYY'), TO_DATE('26/11/1991', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459740, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    11512, TO_DATE('01/12/1972', 'DD/MM/YYYY'), TO_DATE('29/06/2003', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459798, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20002, TO_DATE('28/01/1981', 'DD/MM/YYYY'), TO_DATE('31/01/1981', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459799, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20002, TO_DATE('30/07/1994', 'DD/MM/YYYY'), TO_DATE('11/12/1994', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (360796, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20003, TO_DATE('01/10/2002', 'DD/MM/YYYY'), TO_DATE('04/11/2002', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (363247, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20512, TO_DATE('03/07/2002', 'DD/MM/YYYY'), TO_DATE('29/06/2003', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459860, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20012, TO_DATE('01/12/1972', 'DD/MM/YYYY'), TO_DATE('01/04/1999', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459864, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20013, TO_DATE('01/12/1972', 'DD/MM/YYYY'), TO_DATE('29/06/2003', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459769, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    12602, TO_DATE('01/12/1972', 'DD/MM/YYYY'), TO_DATE('29/06/2003', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459784, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    14031, TO_DATE('01/01/2001', 'DD/MM/YYYY'), TO_DATE('31/05/2001', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459787, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    14033, TO_DATE('04/01/2001', 'DD/MM/YYYY'), TO_DATE('29/06/2003', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459790, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20001, TO_DATE('01/12/1972', 'DD/MM/YYYY'), TO_DATE('29/06/2003', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459797, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20002, TO_DATE('22/12/1978', 'DD/MM/YYYY'), TO_DATE('23/12/1978', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459906, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20017, TO_DATE('04/12/1972', 'DD/MM/YYYY'), TO_DATE('28/12/1972', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459907, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20017, TO_DATE('14/02/1973', 'DD/MM/YYYY'), TO_DATE('19/11/1973', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459908, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20017, TO_DATE('13/12/1973', 'DD/MM/YYYY'), TO_DATE('20/03/1974', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459909, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20017, TO_DATE('27/04/1974', 'DD/MM/YYYY'), TO_DATE('18/06/1975', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459910, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20017, TO_DATE('17/11/1975', 'DD/MM/YYYY'), TO_DATE('10/01/1976', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (361721, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20017, TO_DATE('12/07/1975', 'DD/MM/YYYY'), TO_DATE('14/10/1975', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (361724, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20017, TO_DATE('10/03/1976', 'DD/MM/YYYY'), TO_DATE('20/06/1976', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (361727, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20017, TO_DATE('27/01/1977', 'DD/MM/YYYY'), TO_DATE('10/09/1977', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (361734, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20017, TO_DATE('21/05/1980', 'DD/MM/YYYY'), TO_DATE('06/02/1981', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (361735, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20017, TO_DATE('02/03/1981', 'DD/MM/YYYY'), TO_DATE('25/03/1981', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459911, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20017, TO_DATE('19/07/1976', 'DD/MM/YYYY'), TO_DATE('03/08/1976', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459715, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    10051, TO_DATE('01/12/1972', 'DD/MM/YYYY'), TO_DATE('29/06/2003', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459723, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    10052, TO_DATE('03/04/2001', 'DD/MM/YYYY'), TO_DATE('29/06/2003', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459726, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    11010, TO_DATE('01/12/1972', 'DD/MM/YYYY'), TO_DATE('29/06/2003', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459912, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20017, TO_DATE('30/08/1976', 'DD/MM/YYYY'), TO_DATE('31/12/1976', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459913, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20017, TO_DATE('02/10/1977', 'DD/MM/YYYY'), TO_DATE('21/11/1977', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459914, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20017, TO_DATE('18/12/1977', 'DD/MM/YYYY'), TO_DATE('13/04/1978', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459915, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20017, TO_DATE('13/05/1978', 'DD/MM/YYYY'), TO_DATE('04/01/1979', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459916, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20017, TO_DATE('29/01/1979', 'DD/MM/YYYY'), TO_DATE('09/02/1979', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459917, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20017, TO_DATE('03/03/1979', 'DD/MM/YYYY'), TO_DATE('04/04/1980', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459918, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20017, TO_DATE('30/04/1981', 'DD/MM/YYYY'), TO_DATE('31/08/1982', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459919, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20017, TO_DATE('21/09/1982', 'DD/MM/YYYY'), TO_DATE('20/11/1989', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459920, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20017, TO_DATE('16/12/1989', 'DD/MM/YYYY'), TO_DATE('23/08/1991', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459921, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20017, TO_DATE('21/12/1991', 'DD/MM/YYYY'), TO_DATE('09/05/2001', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459922, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20017, TO_DATE('12/08/2001', 'DD/MM/YYYY'), TO_DATE('27/06/2003', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459936, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20018, TO_DATE('04/12/1972', 'DD/MM/YYYY'), TO_DATE('28/12/1972', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459937, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20018, TO_DATE('14/02/1973', 'DD/MM/YYYY'), TO_DATE('19/11/1973', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459938, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20018, TO_DATE('13/12/1973', 'DD/MM/YYYY'), TO_DATE('20/03/1974', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459939, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20018, TO_DATE('27/04/1974', 'DD/MM/YYYY'), TO_DATE('18/06/1975', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459940, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20018, TO_DATE('17/11/1975', 'DD/MM/YYYY'), TO_DATE('10/01/1976', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459941, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20018, TO_DATE('19/07/1976', 'DD/MM/YYYY'), TO_DATE('03/08/1976', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459942, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20018, TO_DATE('30/08/1976', 'DD/MM/YYYY'), TO_DATE('31/12/1976', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459943, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20018, TO_DATE('02/10/1977', 'DD/MM/YYYY'), TO_DATE('21/11/1977', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (361739, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20017, TO_DATE('14/09/1991', 'DD/MM/YYYY'), TO_DATE('26/11/1991', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (361741, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20017, TO_DATE('01/06/2001', 'DD/MM/YYYY'), TO_DATE('10/07/2001', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (362137, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20018, TO_DATE('12/07/1975', 'DD/MM/YYYY'), TO_DATE('14/10/1975', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (362140, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20018, TO_DATE('10/03/1976', 'DD/MM/YYYY'), TO_DATE('20/06/1976', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (362143, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20018, TO_DATE('27/01/1977', 'DD/MM/YYYY'), TO_DATE('10/09/1977', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (362150, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20018, TO_DATE('21/05/1980', 'DD/MM/YYYY'), TO_DATE('06/02/1981', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (362151, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20018, TO_DATE('02/03/1981', 'DD/MM/YYYY'), TO_DATE('25/03/1981', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459944, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20018, TO_DATE('18/12/1977', 'DD/MM/YYYY'), TO_DATE('13/04/1978', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459945, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20018, TO_DATE('13/05/1978', 'DD/MM/YYYY'), TO_DATE('04/01/1979', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459946, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20018, TO_DATE('29/01/1979', 'DD/MM/YYYY'), TO_DATE('09/02/1979', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459947, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20018, TO_DATE('03/03/1979', 'DD/MM/YYYY'), TO_DATE('04/04/1980', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459948, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20018, TO_DATE('30/04/1981', 'DD/MM/YYYY'), TO_DATE('31/08/1982', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459949, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20018, TO_DATE('21/09/1982', 'DD/MM/YYYY'), TO_DATE('20/11/1989', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459950, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20018, TO_DATE('16/12/1989', 'DD/MM/YYYY'), TO_DATE('23/08/1991', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459951, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20018, TO_DATE('21/12/1991', 'DD/MM/YYYY'), TO_DATE('30/03/1999', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459961, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20019, TO_DATE('04/12/1972', 'DD/MM/YYYY'), TO_DATE('28/12/1972', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459962, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20019, TO_DATE('14/02/1973', 'DD/MM/YYYY'), TO_DATE('19/11/1973', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459963, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20019, TO_DATE('13/12/1973', 'DD/MM/YYYY'), TO_DATE('20/03/1974', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459964, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20019, TO_DATE('27/04/1974', 'DD/MM/YYYY'), TO_DATE('18/06/1975', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459965, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20019, TO_DATE('17/11/1975', 'DD/MM/YYYY'), TO_DATE('10/01/1976', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459966, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20019, TO_DATE('19/07/1976', 'DD/MM/YYYY'), TO_DATE('03/08/1976', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459967, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20019, TO_DATE('30/08/1976', 'DD/MM/YYYY'), TO_DATE('31/12/1976', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459968, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20019, TO_DATE('02/10/1977', 'DD/MM/YYYY'), TO_DATE('21/11/1977', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459969, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20019, TO_DATE('18/12/1977', 'DD/MM/YYYY'), TO_DATE('13/04/1978', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459970, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20019, TO_DATE('13/05/1978', 'DD/MM/YYYY'), TO_DATE('04/01/1979', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459971, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20019, TO_DATE('29/01/1979', 'DD/MM/YYYY'), TO_DATE('09/02/1979', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459972, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20019, TO_DATE('03/03/1979', 'DD/MM/YYYY'), TO_DATE('04/04/1980', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459973, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20019, TO_DATE('30/04/1981', 'DD/MM/YYYY'), TO_DATE('31/08/1982', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459748, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    12004, TO_DATE('01/12/1972', 'DD/MM/YYYY'), TO_DATE('29/06/2003', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459756, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    12006, TO_DATE('01/12/1972', 'DD/MM/YYYY'), TO_DATE('29/06/2003', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (360730, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20002, TO_DATE('27/11/1982', 'DD/MM/YYYY'), TO_DATE('14/12/1982', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (360732, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20002, TO_DATE('16/02/1995', 'DD/MM/YYYY'), TO_DATE('03/10/1995', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (360733, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20002, TO_DATE('01/11/1995', 'DD/MM/YYYY'), TO_DATE('28/11/1995', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459831, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20003, TO_DATE('01/12/1972', 'DD/MM/YYYY'), TO_DATE('01/04/1999', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459838, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20004, TO_DATE('01/12/1972', 'DD/MM/YYYY'), TO_DATE('01/04/1999', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459843, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20005, TO_DATE('01/01/1982', 'DD/MM/YYYY'), TO_DATE('01/04/1999', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459848, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20010, TO_DATE('01/12/1972', 'DD/MM/YYYY'), TO_DATE('29/06/2003', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459853, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20011, TO_DATE('01/12/1972', 'DD/MM/YYYY'), TO_DATE('29/06/2003', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (360734, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20002, TO_DATE('01/01/1996', 'DD/MM/YYYY'), TO_DATE('26/02/1997', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (362574, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20019, TO_DATE('12/07/1975', 'DD/MM/YYYY'), TO_DATE('14/10/1975', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (362577, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20019, TO_DATE('10/03/1976', 'DD/MM/YYYY'), TO_DATE('20/06/1976', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (460006, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20062, TO_DATE('01/12/1972', 'DD/MM/YYYY'), TO_DATE('09/09/1999', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (362580, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20019, TO_DATE('27/01/1977', 'DD/MM/YYYY'), TO_DATE('10/09/1977', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (362587, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20019, TO_DATE('21/05/1980', 'DD/MM/YYYY'), TO_DATE('06/02/1981', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (362588, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20019, TO_DATE('02/03/1981', 'DD/MM/YYYY'), TO_DATE('25/03/1981', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (362592, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20019, TO_DATE('14/09/1991', 'DD/MM/YYYY'), TO_DATE('26/11/1991', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (362594, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20019, TO_DATE('01/06/2001', 'DD/MM/YYYY'), TO_DATE('10/07/2001', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (460014, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20511, TO_DATE('01/12/1972', 'DD/MM/YYYY'), TO_DATE('01/04/1999', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (460020, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20512, TO_DATE('01/09/1982', 'DD/MM/YYYY'), TO_DATE('01/04/1999', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (460028, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20551, TO_DATE('01/12/1972', 'DD/MM/YYYY'), TO_DATE('01/04/1999', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (460034, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20552, TO_DATE('01/12/1972', 'DD/MM/YYYY'), TO_DATE('01/04/1999', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (460044, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    35226, TO_DATE('01/12/1972', 'DD/MM/YYYY'), TO_DATE('29/06/2003', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (363532, '03763', 'WMO', TO_DATE('01/01/1972', 'DD/MM/YYYY'), 'SYNOP', 
    20553, TO_DATE('01/12/1972', 'DD/MM/YYYY'), TO_DATE('01/04/1999', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (360033, '03764', 'WMO', TO_DATE('01/01/1988', 'DD/MM/YYYY'), 'SYNOP', 
    12602, TO_DATE('17/04/1989', 'DD/MM/YYYY'), TO_DATE('24/05/1989', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (360034, '03764', 'WMO', TO_DATE('01/01/1988', 'DD/MM/YYYY'), 'SYNOP', 
    12602, TO_DATE('26/07/1989', 'DD/MM/YYYY'), TO_DATE('16/11/1992', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (359980, '03764', 'WMO', TO_DATE('01/01/1988', 'DD/MM/YYYY'), 'SYNOP', 
    12006, TO_DATE('17/04/1989', 'DD/MM/YYYY'), TO_DATE('24/05/1989', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (359981, '03764', 'WMO', TO_DATE('01/01/1988', 'DD/MM/YYYY'), 'SYNOP', 
    12006, TO_DATE('26/07/1989', 'DD/MM/YYYY'), TO_DATE('16/11/1992', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (359874, '03764', 'WMO', TO_DATE('01/01/1988', 'DD/MM/YYYY'), 'SYNOP', 
    11512, TO_DATE('17/04/1989', 'DD/MM/YYYY'), TO_DATE('24/05/1989', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (359875, '03764', 'WMO', TO_DATE('01/01/1988', 'DD/MM/YYYY'), 'SYNOP', 
    11512, TO_DATE('26/07/1989', 'DD/MM/YYYY'), TO_DATE('16/11/1992', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (359707, '03764', 'WMO', TO_DATE('01/01/1988', 'DD/MM/YYYY'), 'SYNOP', 
    10051, TO_DATE('17/04/1989', 'DD/MM/YYYY'), TO_DATE('24/05/1989', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (359708, '03764', 'WMO', TO_DATE('01/01/1988', 'DD/MM/YYYY'), 'SYNOP', 
    10051, TO_DATE('26/07/1989', 'DD/MM/YYYY'), TO_DATE('16/11/1992', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459741, '03764', 'WMO', TO_DATE('01/01/1988', 'DD/MM/YYYY'), 'SYNOP', 
    11512, TO_DATE('01/01/1988', 'DD/MM/YYYY'), TO_DATE('11/03/1989', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (363584, '03764', 'WMO', TO_DATE('01/01/1988', 'DD/MM/YYYY'), 'SYNOP', 
    35226, TO_DATE('17/04/1989', 'DD/MM/YYYY'), TO_DATE('24/05/1989', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (363585, '03764', 'WMO', TO_DATE('01/01/1988', 'DD/MM/YYYY'), 'SYNOP', 
    35226, TO_DATE('26/07/1989', 'DD/MM/YYYY'), TO_DATE('16/11/1992', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459770, '03764', 'WMO', TO_DATE('01/01/1988', 'DD/MM/YYYY'), 'SYNOP', 
    12602, TO_DATE('01/01/1988', 'DD/MM/YYYY'), TO_DATE('11/03/1989', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459716, '03764', 'WMO', TO_DATE('01/01/1988', 'DD/MM/YYYY'), 'SYNOP', 
    10051, TO_DATE('01/01/1988', 'DD/MM/YYYY'), TO_DATE('11/03/1989', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459727, '03764', 'WMO', TO_DATE('01/01/1988', 'DD/MM/YYYY'), 'SYNOP', 
    11010, TO_DATE('01/01/1988', 'DD/MM/YYYY'), TO_DATE('11/03/1989', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459749, '03764', 'WMO', TO_DATE('01/01/1988', 'DD/MM/YYYY'), 'SYNOP', 
    12004, TO_DATE('01/01/1988', 'DD/MM/YYYY'), TO_DATE('11/03/1989', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459757, '03764', 'WMO', TO_DATE('01/01/1988', 'DD/MM/YYYY'), 'SYNOP', 
    12006, TO_DATE('01/01/1988', 'DD/MM/YYYY'), TO_DATE('11/03/1989', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (359780, '03764', 'WMO', TO_DATE('01/01/1988', 'DD/MM/YYYY'), 'SYNOP', 
    11010, TO_DATE('17/04/1989', 'DD/MM/YYYY'), TO_DATE('24/05/1989', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (359781, '03764', 'WMO', TO_DATE('01/01/1988', 'DD/MM/YYYY'), 'SYNOP', 
    11010, TO_DATE('26/07/1989', 'DD/MM/YYYY'), TO_DATE('16/11/1992', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (359927, '03764', 'WMO', TO_DATE('01/01/1988', 'DD/MM/YYYY'), 'SYNOP', 
    12004, TO_DATE('17/04/1989', 'DD/MM/YYYY'), TO_DATE('24/05/1989', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (359928, '03764', 'WMO', TO_DATE('01/01/1988', 'DD/MM/YYYY'), 'SYNOP', 
    12004, TO_DATE('26/07/1989', 'DD/MM/YYYY'), TO_DATE('16/11/1992', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459832, '03764', 'WMO', TO_DATE('01/01/1988', 'DD/MM/YYYY'), 'SYNOP', 
    20003, TO_DATE('26/03/1988', 'DD/MM/YYYY'), TO_DATE('27/03/1988', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459839, '03764', 'WMO', TO_DATE('01/01/1988', 'DD/MM/YYYY'), 'SYNOP', 
    20004, TO_DATE('26/03/1988', 'DD/MM/YYYY'), TO_DATE('27/03/1988', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (459844, '03764', 'WMO', TO_DATE('01/01/1988', 'DD/MM/YYYY'), 'SYNOP', 
    20005, TO_DATE('26/03/1988', 'DD/MM/YYYY'), TO_DATE('27/03/1988', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (460007, '03764', 'WMO', TO_DATE('01/01/1988', 'DD/MM/YYYY'), 'SYNOP', 
    20062, TO_DATE('01/11/1991', 'DD/MM/YYYY'), TO_DATE('02/11/1991', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (363050, '03764', 'WMO', TO_DATE('01/01/1988', 'DD/MM/YYYY'), 'SYNOP', 
    20062, TO_DATE('18/03/1992', 'DD/MM/YYYY'), TO_DATE('19/03/1992', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (460045, '03764', 'WMO', TO_DATE('01/01/1988', 'DD/MM/YYYY'), 'SYNOP', 
    35226, TO_DATE('01/01/1988', 'DD/MM/YYYY'), TO_DATE('11/03/1989', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (500419, '272734', 'RAIN', TO_DATE('01/01/1971', 'DD/MM/YYYY'), 'NCM', 
    13525, TO_DATE('03/11/1983', 'DD/MM/YYYY'), TO_DATE('03/05/1988', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (389310, '272734', 'RAIN', TO_DATE('01/01/1971', 'DD/MM/YYYY'), 'NCM', 
    13525, TO_DATE('02/04/1980', 'DD/MM/YYYY'), TO_DATE('06/07/1983', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (389313, '272734', 'RAIN', TO_DATE('01/01/1971', 'DD/MM/YYYY'), 'NCM', 
    13524, TO_DATE('01/04/1980', 'DD/MM/YYYY'), TO_DATE('05/07/1983', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (389316, '272734', 'RAIN', TO_DATE('01/01/1971', 'DD/MM/YYYY'), 'NCM', 
    13023, TO_DATE('02/01/1971', 'DD/MM/YYYY'), TO_DATE('01/04/1980', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (500381, '272734', 'RAIN', TO_DATE('01/01/1971', 'DD/MM/YYYY'), 'NCM', 
    13023, TO_DATE('08/07/1983', 'DD/MM/YYYY'), TO_DATE('01/11/1983', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (500382, '272734', 'RAIN', TO_DATE('01/01/1971', 'DD/MM/YYYY'), 'NCM', 
    13023, TO_DATE('08/11/1987', 'DD/MM/YYYY'), TO_DATE('29/03/1992', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (500398, '272734', 'RAIN', TO_DATE('01/01/1971', 'DD/MM/YYYY'), 'NCM', 
    13524, TO_DATE('02/11/1983', 'DD/MM/YYYY'), TO_DATE('02/05/1988', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (500399, '272734', 'RAIN', TO_DATE('01/01/1971', 'DD/MM/YYYY'), 'NCM', 
    13524, TO_DATE('30/03/1992', 'DD/MM/YYYY'), TO_DATE('31/03/1992', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (500436, '272734', 'RAIN', TO_DATE('01/01/1987', 'DD/MM/YYYY'), 'SREW', 
    35218, TO_DATE('01/01/1987', 'DD/MM/YYYY'), TO_DATE('31/12/1987', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (389553, '272734', 'RAIN', TO_DATE('01/01/1988', 'DD/MM/YYYY'), 'SREW', 
    35218, TO_DATE('01/01/1988', 'DD/MM/YYYY'), TO_DATE('31/12/1991', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (501243, '272734', 'RAIN', TO_DATE('01/01/1995', 'DD/MM/YYYY'), 'WADRAIN', 
    13023, TO_DATE('02/01/1995', 'DD/MM/YYYY'), TO_DATE('01/03/1997', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (501244, '272734', 'RAIN', TO_DATE('01/01/1995', 'DD/MM/YYYY'), 'WADRAIN', 
    13023, TO_DATE('02/10/1997', 'DD/MM/YYYY'), TO_DATE('12/01/1999', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (501245, '272734', 'RAIN', TO_DATE('01/01/1995', 'DD/MM/YYYY'), 'WADRAIN', 
    13023, TO_DATE('18/02/1999', 'DD/MM/YYYY'), TO_DATE('29/10/1999', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (501246, '272734', 'RAIN', TO_DATE('01/01/1995', 'DD/MM/YYYY'), 'WADRAIN', 
    13023, TO_DATE('21/11/1999', 'DD/MM/YYYY'), TO_DATE('02/07/2000', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (501247, '272734', 'RAIN', TO_DATE('01/01/1995', 'DD/MM/YYYY'), 'WADRAIN', 
    13023, TO_DATE('05/08/2000', 'DD/MM/YYYY'), TO_DATE('06/08/2000', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (501248, '272734', 'RAIN', TO_DATE('01/01/1995', 'DD/MM/YYYY'), 'WADRAIN', 
    13023, TO_DATE('03/09/2001', 'DD/MM/YYYY'), TO_DATE('01/10/2002', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (501249, '272734', 'RAIN', TO_DATE('01/01/1995', 'DD/MM/YYYY'), 'WADRAIN', 
    13023, TO_DATE('03/05/2003', 'DD/MM/YYYY'), TO_DATE('01/06/2003', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (501533, '272734', 'RAIN', TO_DATE('01/01/1980', 'DD/MM/YYYY'), 'WAHRAIN', 
    35218, TO_DATE('01/01/1980', 'DD/MM/YYYY'), TO_DATE('01/01/1982', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (390155, '272734', 'RAIN', TO_DATE('01/01/1980', 'DD/MM/YYYY'), 'WAHRAIN', 
    13520, TO_DATE('22/04/1980', 'DD/MM/YYYY'), TO_DATE('31/12/1981', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (390156, '272734', 'RAIN', TO_DATE('01/01/1980', 'DD/MM/YYYY'), 'WAHRAIN', 
    13520, TO_DATE('05/02/1982', 'DD/MM/YYYY'), TO_DATE('08/04/1982', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (390157, '272734', 'RAIN', TO_DATE('01/01/1980', 'DD/MM/YYYY'), 'WAHRAIN', 
    13520, TO_DATE('29/04/1982', 'DD/MM/YYYY'), TO_DATE('09/10/1985', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (390158, '272734', 'RAIN', TO_DATE('01/01/1980', 'DD/MM/YYYY'), 'WAHRAIN', 
    13520, TO_DATE('31/10/1985', 'DD/MM/YYYY'), TO_DATE('15/09/1986', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (390159, '272734', 'RAIN', TO_DATE('01/01/1980', 'DD/MM/YYYY'), 'WAHRAIN', 
    13520, TO_DATE('14/10/1986', 'DD/MM/YYYY'), TO_DATE('31/12/1987', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (501526, '272734', 'RAIN', TO_DATE('01/01/1980', 'DD/MM/YYYY'), 'WAHRAIN', 
    13520, TO_DATE('03/01/1980', 'DD/MM/YYYY'), TO_DATE('01/04/1980', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (390161, '272734', 'RAIN', TO_DATE('01/01/1980', 'DD/MM/YYYY'), 'WAHRAIN', 
    35218, TO_DATE('01/02/1982', 'DD/MM/YYYY'), TO_DATE('31/12/1987', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (500445, '272735', 'RAIN', TO_DATE('01/01/1978', 'DD/MM/YYYY'), 'SSER', 
    13520, TO_DATE('29/01/1980', 'DD/MM/YYYY'), TO_DATE('26/02/1980', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (500446, '272735', 'RAIN', TO_DATE('01/01/1978', 'DD/MM/YYYY'), 'SSER', 
    13520, TO_DATE('09/07/1984', 'DD/MM/YYYY'), TO_DATE('28/10/1984', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (500447, '272735', 'RAIN', TO_DATE('01/01/1978', 'DD/MM/YYYY'), 'SSER', 
    13520, TO_DATE('25/04/1986', 'DD/MM/YYYY'), TO_DATE('28/04/1986', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (500452, '272735', 'RAIN', TO_DATE('01/01/1978', 'DD/MM/YYYY'), 'SSER', 
    35218, TO_DATE('29/01/1980', 'DD/MM/YYYY'), TO_DATE('29/02/1980', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (389671, '272735', 'RAIN', TO_DATE('01/01/1978', 'DD/MM/YYYY'), 'SSER', 
    13520, TO_DATE('22/04/1980', 'DD/MM/YYYY'), TO_DATE('31/07/1980', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (389672, '272735', 'RAIN', TO_DATE('01/01/1978', 'DD/MM/YYYY'), 'SSER', 
    13520, TO_DATE('05/09/1980', 'DD/MM/YYYY'), TO_DATE('14/11/1980', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (389673, '272735', 'RAIN', TO_DATE('01/01/1978', 'DD/MM/YYYY'), 'SSER', 
    13520, TO_DATE('17/12/1980', 'DD/MM/YYYY'), TO_DATE('03/06/1982', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (389674, '272735', 'RAIN', TO_DATE('01/01/1978', 'DD/MM/YYYY'), 'SSER', 
    13520, TO_DATE('02/07/1982', 'DD/MM/YYYY'), TO_DATE('24/02/1983', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (389675, '272735', 'RAIN', TO_DATE('01/01/1978', 'DD/MM/YYYY'), 'SSER', 
    13520, TO_DATE('06/05/1983', 'DD/MM/YYYY'), TO_DATE('24/08/1983', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (389676, '272735', 'RAIN', TO_DATE('01/01/1978', 'DD/MM/YYYY'), 'SSER', 
    13520, TO_DATE('19/10/1983', 'DD/MM/YYYY'), TO_DATE('25/12/1983', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (389677, '272735', 'RAIN', TO_DATE('01/01/1978', 'DD/MM/YYYY'), 'SSER', 
    13520, TO_DATE('01/02/1984', 'DD/MM/YYYY'), TO_DATE('15/05/1984', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (389679, '272735', 'RAIN', TO_DATE('01/01/1978', 'DD/MM/YYYY'), 'SSER', 
    13520, TO_DATE('01/12/1984', 'DD/MM/YYYY'), TO_DATE('31/12/1984', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (389680, '272735', 'RAIN', TO_DATE('01/01/1978', 'DD/MM/YYYY'), 'SSER', 
    13520, TO_DATE('26/01/1985', 'DD/MM/YYYY'), TO_DATE('08/02/1985', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (389681, '272735', 'RAIN', TO_DATE('01/01/1978', 'DD/MM/YYYY'), 'SSER', 
    13520, TO_DATE('14/05/1985', 'DD/MM/YYYY'), TO_DATE('26/06/1985', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (389683, '272735', 'RAIN', TO_DATE('01/01/1978', 'DD/MM/YYYY'), 'SSER', 
    13520, TO_DATE('01/01/1986', 'DD/MM/YYYY'), TO_DATE('19/02/1986', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (389686, '272735', 'RAIN', TO_DATE('01/01/1978', 'DD/MM/YYYY'), 'SSER', 
    13520, TO_DATE('14/10/1986', 'DD/MM/YYYY'), TO_DATE('26/11/1986', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (389688, '272735', 'RAIN', TO_DATE('01/01/1978', 'DD/MM/YYYY'), 'SSER', 
    35218, TO_DATE('19/04/1980', 'DD/MM/YYYY'), TO_DATE('01/08/1980', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (389689, '272735', 'RAIN', TO_DATE('01/01/1978', 'DD/MM/YYYY'), 'SSER', 
    35218, TO_DATE('03/09/1980', 'DD/MM/YYYY'), TO_DATE('15/11/1980', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (389690, '272735', 'RAIN', TO_DATE('01/01/1978', 'DD/MM/YYYY'), 'SSER', 
    35218, TO_DATE('17/12/1980', 'DD/MM/YYYY'), TO_DATE('04/06/1982', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (389691, '272735', 'RAIN', TO_DATE('01/01/1978', 'DD/MM/YYYY'), 'SSER', 
    35218, TO_DATE('02/07/1982', 'DD/MM/YYYY'), TO_DATE('01/03/1983', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (389692, '272735', 'RAIN', TO_DATE('01/01/1978', 'DD/MM/YYYY'), 'SSER', 
    35218, TO_DATE('06/05/1983', 'DD/MM/YYYY'), TO_DATE('01/09/1983', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (389693, '272735', 'RAIN', TO_DATE('01/01/1978', 'DD/MM/YYYY'), 'SSER', 
    35218, TO_DATE('18/10/1983', 'DD/MM/YYYY'), TO_DATE('01/01/1984', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (389694, '272735', 'RAIN', TO_DATE('01/01/1978', 'DD/MM/YYYY'), 'SSER', 
    35218, TO_DATE('01/02/1984', 'DD/MM/YYYY'), TO_DATE('27/05/1984', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (389695, '272735', 'RAIN', TO_DATE('01/01/1978', 'DD/MM/YYYY'), 'SSER', 
    35218, TO_DATE('03/07/1984', 'DD/MM/YYYY'), TO_DATE('01/11/1984', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (389696, '272735', 'RAIN', TO_DATE('01/01/1978', 'DD/MM/YYYY'), 'SSER', 
    35218, TO_DATE('01/12/1984', 'DD/MM/YYYY'), TO_DATE('01/01/1985', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (389697, '272735', 'RAIN', TO_DATE('01/01/1978', 'DD/MM/YYYY'), 'SSER', 
    35218, TO_DATE('26/01/1985', 'DD/MM/YYYY'), TO_DATE('09/02/1985', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (389698, '272735', 'RAIN', TO_DATE('01/01/1978', 'DD/MM/YYYY'), 'SSER', 
    35218, TO_DATE('14/05/1985', 'DD/MM/YYYY'), TO_DATE('28/06/1985', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (389699, '272735', 'RAIN', TO_DATE('01/01/1978', 'DD/MM/YYYY'), 'SSER', 
    35218, TO_DATE('02/11/1985', 'DD/MM/YYYY'), TO_DATE('01/12/1985', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (389700, '272735', 'RAIN', TO_DATE('01/01/1978', 'DD/MM/YYYY'), 'SSER', 
    35218, TO_DATE('01/01/1986', 'DD/MM/YYYY'), TO_DATE('23/02/1986', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (389701, '272735', 'RAIN', TO_DATE('01/01/1978', 'DD/MM/YYYY'), 'SSER', 
    35218, TO_DATE('24/04/1986', 'DD/MM/YYYY'), TO_DATE('30/04/1986', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (389702, '272735', 'RAIN', TO_DATE('01/01/1978', 'DD/MM/YYYY'), 'SSER', 
    35218, TO_DATE('15/09/1986', 'DD/MM/YYYY'), TO_DATE('27/11/1986', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (500444, '272735', 'RAIN', TO_DATE('01/01/1993', 'DD/MM/YYYY'), 'SSER', 
    13520, TO_DATE('01/01/1993', 'DD/MM/YYYY'), TO_DATE('01/12/1996', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (500451, '272735', 'RAIN', TO_DATE('01/01/1993', 'DD/MM/YYYY'), 'SSER', 
    35218, TO_DATE('01/01/1993', 'DD/MM/YYYY'), TO_DATE('10/01/1997', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (389705, '272735', 'RAIN', TO_DATE('01/01/1993', 'DD/MM/YYYY'), 'SSER', 
    35218, TO_DATE('01/03/1997', 'DD/MM/YYYY'), TO_DATE('22/05/2001', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (500433, '272736', 'RAIN', TO_DATE('01/12/1989', 'DD/MM/YYYY'), 'SREW', 
    35218, TO_DATE('06/08/1990', 'DD/MM/YYYY'), TO_DATE('23/08/1990', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (500434, '272736', 'RAIN', TO_DATE('01/12/1989', 'DD/MM/YYYY'), 'SREW', 
    35218, TO_DATE('24/07/1991', 'DD/MM/YYYY'), TO_DATE('25/07/1991', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (500435, '272736', 'RAIN', TO_DATE('01/12/1989', 'DD/MM/YYYY'), 'SREW', 
    35218, TO_DATE('04/11/1991', 'DD/MM/YYYY'), TO_DATE('29/12/1991', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (389555, '272736', 'RAIN', TO_DATE('01/12/1989', 'DD/MM/YYYY'), 'SREW', 
    35218, TO_DATE('29/03/1990', 'DD/MM/YYYY'), TO_DATE('02/04/1990', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (501241, '272736', 'RAIN', TO_DATE('01/12/1991', 'DD/MM/YYYY'), 'WADRAIN', 
    13023, TO_DATE('07/12/1991', 'DD/MM/YYYY'), TO_DATE('01/04/1992', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (501242, '272736', 'RAIN', TO_DATE('01/12/1991', 'DD/MM/YYYY'), 'WADRAIN', 
    13023, TO_DATE('03/05/1992', 'DD/MM/YYYY'), TO_DATE('01/11/1992', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (500417, '272737', 'RAIN', TO_DATE('01/04/1992', 'DD/MM/YYYY'), 'NCM', 
    13525, TO_DATE('02/04/1992', 'DD/MM/YYYY'), TO_DATE('01/10/2002', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (500418, '272737', 'RAIN', TO_DATE('01/04/1992', 'DD/MM/YYYY'), 'NCM', 
    13525, TO_DATE('04/11/2002', 'DD/MM/YYYY'), TO_DATE('29/06/2003', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (500380, '272737', 'RAIN', TO_DATE('01/04/1992', 'DD/MM/YYYY'), 'NCM', 
    13023, TO_DATE('22/05/1993', 'DD/MM/YYYY'), TO_DATE('24/05/1993', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (500396, '272737', 'RAIN', TO_DATE('01/04/1992', 'DD/MM/YYYY'), 'NCM', 
    13524, TO_DATE('01/04/1992', 'DD/MM/YYYY'), TO_DATE('30/09/2002', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (500397, '272737', 'RAIN', TO_DATE('01/04/1992', 'DD/MM/YYYY'), 'NCM', 
    13524, TO_DATE('03/11/2002', 'DD/MM/YYYY'), TO_DATE('28/06/2003', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (500432, '272737', 'RAIN', TO_DATE('01/01/1996', 'DD/MM/YYYY'), 'SREW', 
    35218, TO_DATE('01/11/1996', 'DD/MM/YYYY'), TO_DATE('29/06/2003', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (41013, '5591', 'DCNN', TO_DATE('01/12/1991', 'DD/MM/YYYY'), 'NCM', 
    35212, TO_DATE('01/12/1991', 'DD/MM/YYYY'), TO_DATE('16/11/1992', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (41014, '5591', 'DCNN', TO_DATE('01/12/1991', 'DD/MM/YYYY'), 'NCM', 
    35213, TO_DATE('01/12/1991', 'DD/MM/YYYY'), TO_DATE('16/11/1992', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (41015, '5591', 'DCNN', TO_DATE('01/12/1991', 'DD/MM/YYYY'), 'NCM', 
    13012, TO_DATE('01/12/1991', 'DD/MM/YYYY'), TO_DATE('17/11/1992', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (405966, '5591', 'DCNN', TO_DATE('01/12/1991', 'DD/MM/YYYY'), 'NCM', 
    35195, TO_DATE('01/12/1991', 'DD/MM/YYYY'), TO_DATE('15/11/1992', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (405967, '5591', 'DCNN', TO_DATE('01/12/1991', 'DD/MM/YYYY'), 'NCM', 
    35194, TO_DATE('01/12/1991', 'DD/MM/YYYY'), TO_DATE('15/11/1992', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (542926, '559101', 'WIND', TO_DATE('01/12/1991', 'DD/MM/YYYY'), 'HCM', 
    35199, TO_DATE('01/12/1991', 'DD/MM/YYYY'), TO_DATE('16/11/1992', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (542916, '559101', 'WIND', TO_DATE('01/12/1991', 'DD/MM/YYYY'), 'HCM', 
    11012, TO_DATE('01/12/1991', 'DD/MM/YYYY'), TO_DATE('16/11/1992', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (542918, '559101', 'WIND', TO_DATE('01/12/1991', 'DD/MM/YYYY'), 'HCM', 
    11511, TO_DATE('01/12/1991', 'DD/MM/YYYY'), TO_DATE('16/11/1992', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (542920, '559101', 'WIND', TO_DATE('01/12/1991', 'DD/MM/YYYY'), 'HCM', 
    11521, TO_DATE('01/12/1991', 'DD/MM/YYYY'), TO_DATE('16/11/1992', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (542922, '559101', 'WIND', TO_DATE('01/12/1991', 'DD/MM/YYYY'), 'HCM', 
    11523, TO_DATE('01/12/1991', 'DD/MM/YYYY'), TO_DATE('03/11/1992', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (40981, '5592', 'DCNN', TO_DATE('01/01/1995', 'DD/MM/YYYY'), 'DRADR35', 
    14020, TO_DATE('01/01/1995', 'DD/MM/YYYY'), TO_DATE('30/12/1996', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (40982, '5592', 'DCNN', TO_DATE('01/01/1995', 'DD/MM/YYYY'), 'DRADR35', 
    14022, TO_DATE('01/01/1995', 'DD/MM/YYYY'), TO_DATE('30/12/1996', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (404665, '5592', 'DCNN', TO_DATE('01/07/1994', 'DD/MM/YYYY'), 'HCM', 
    14025, TO_DATE('04/01/2001', 'DD/MM/YYYY'), TO_DATE('30/04/2001', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (404666, '5592', 'DCNN', TO_DATE('01/07/1994', 'DD/MM/YYYY'), 'HCM', 
    14022, TO_DATE('04/01/2001', 'DD/MM/YYYY'), TO_DATE('28/02/2002', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (404667, '5592', 'DCNN', TO_DATE('01/07/1994', 'DD/MM/YYYY'), 'HCM', 
    14022, TO_DATE('01/04/2002', 'DD/MM/YYYY'), TO_DATE('31/03/2003', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (542923, '5592', 'DCNN', TO_DATE('01/07/1994', 'DD/MM/YYYY'), 'HCM', 
    12536, TO_DATE('25/07/1994', 'DD/MM/YYYY'), TO_DATE('29/06/2003', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (542924, '5592', 'DCNN', TO_DATE('01/07/1994', 'DD/MM/YYYY'), 'HCM', 
    14020, TO_DATE('05/01/2001', 'DD/MM/YYYY'), TO_DATE('29/06/2003', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (542927, '5592', 'DCNN', TO_DATE('01/01/1981', 'DD/MM/YYYY'), 'HSUN3445', 
    14031, TO_DATE('01/01/1981', 'DD/MM/YYYY'), TO_DATE('31/12/2000', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (404952, '5592', 'DCNN', TO_DATE('01/01/1981', 'DD/MM/YYYY'), 'HSUN3445', 
    14031, TO_DATE('01/06/2001', 'DD/MM/YYYY'), TO_DATE('30/06/2001', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (542953, '5592', 'DCNN', TO_DATE('01/02/1965', 'DD/MM/YYYY'), 'MODLERAD', 
    14020, TO_DATE('01/02/1965', 'DD/MM/YYYY'), TO_DATE('29/08/2002', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (542955, '5592', 'DCNN', TO_DATE('01/02/1965', 'DD/MM/YYYY'), 'MODLERAD', 
    14022, TO_DATE('01/02/1965', 'DD/MM/YYYY'), TO_DATE('29/08/2002', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (542956, '5592', 'DCNN', TO_DATE('01/02/1965', 'DD/MM/YYYY'), 'MODLERAD', 
    14025, TO_DATE('01/02/1965', 'DD/MM/YYYY'), TO_DATE('29/08/2002', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (405893, '5592', 'DCNN', TO_DATE('01/02/1965', 'DD/MM/YYYY'), 'MODLERAD', 
    14025, TO_DATE('02/10/2002', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (405900, '5592', 'DCNN', TO_DATE('01/02/1965', 'DD/MM/YYYY'), 'MODLERAD', 
    14022, TO_DATE('02/10/2002', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (405916, '5592', 'DCNN', TO_DATE('01/02/1965', 'DD/MM/YYYY'), 'MODLERAD', 
    14020, TO_DATE('02/10/2002', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (405984, '5592', 'DCNN', TO_DATE('01/01/1971', 'DD/MM/YYYY'), 'NCM', 
    12540, TO_DATE('01/01/1971', 'DD/MM/YYYY'), TO_DATE('29/06/2003', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (405985, '5592', 'DCNN', TO_DATE('01/01/1971', 'DD/MM/YYYY'), 'NCM', 
    12538, TO_DATE('01/01/1971', 'DD/MM/YYYY'), TO_DATE('29/06/2003', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (405987, '5592', 'DCNN', TO_DATE('01/01/1971', 'DD/MM/YYYY'), 'NCM', 
    35213, TO_DATE('01/04/1980', 'DD/MM/YYYY'), TO_DATE('06/07/1983', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (405990, '5592', 'DCNN', TO_DATE('01/01/1971', 'DD/MM/YYYY'), 'NCM', 
    35212, TO_DATE('01/04/1980', 'DD/MM/YYYY'), TO_DATE('06/07/1983', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (405993, '5592', 'DCNN', TO_DATE('01/01/1971', 'DD/MM/YYYY'), 'NCM', 
    35195, TO_DATE('01/04/1980', 'DD/MM/YYYY'), TO_DATE('05/07/1983', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (405996, '5592', 'DCNN', TO_DATE('01/01/1971', 'DD/MM/YYYY'), 'NCM', 
    35194, TO_DATE('01/04/1980', 'DD/MM/YYYY'), TO_DATE('05/07/1983', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (406002, '5592', 'DCNN', TO_DATE('01/01/1971', 'DD/MM/YYYY'), 'NCM', 
    12513, TO_DATE('01/01/1971', 'DD/MM/YYYY'), TO_DATE('29/06/2003', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (406003, '5592', 'DCNN', TO_DATE('01/01/1971', 'DD/MM/YYYY'), 'NCM', 
    35224, TO_DATE('01/01/1971', 'DD/MM/YYYY'), TO_DATE('31/03/1980', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (406012, '5592', 'DCNN', TO_DATE('01/01/1971', 'DD/MM/YYYY'), 'NCM', 
    35222, TO_DATE('02/01/1971', 'DD/MM/YYYY'), TO_DATE('01/04/1980', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (406021, '5592', 'DCNN', TO_DATE('01/01/1971', 'DD/MM/YYYY'), 'NCM', 
    12013, TO_DATE('01/01/1971', 'DD/MM/YYYY'), TO_DATE('29/06/2003', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (406022, '5592', 'DCNN', TO_DATE('01/01/1971', 'DD/MM/YYYY'), 'NCM', 
    11601, TO_DATE('01/01/1971', 'DD/MM/YYYY'), TO_DATE('31/12/1982', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (41034, '5592', 'DCNN', TO_DATE('01/01/1971', 'DD/MM/YYYY'), 'NCM', 
    13013, TO_DATE('01/01/1971', 'DD/MM/YYYY'), TO_DATE('09/09/1999', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (41035, '5592', 'DCNN', TO_DATE('01/01/1971', 'DD/MM/YYYY'), 'NCM', 
    13601, TO_DATE('01/01/1971', 'DD/MM/YYYY'), TO_DATE('08/09/1999', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (41036, '5592', 'DCNN', TO_DATE('01/01/1971', 'DD/MM/YYYY'), 'NCM', 
    13602, TO_DATE('01/01/1971', 'DD/MM/YYYY'), TO_DATE('08/09/1999', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (41039, '5592', 'DCNN', TO_DATE('01/01/1971', 'DD/MM/YYYY'), 'NCM', 
    20601, TO_DATE('01/01/1971', 'DD/MM/YYYY'), TO_DATE('08/09/1999', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (542957, '5592', 'DCNN', TO_DATE('01/01/1971', 'DD/MM/YYYY'), 'NCM', 
    11601, TO_DATE('02/04/1983', 'DD/MM/YYYY'), TO_DATE('08/09/1999', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (542958, '5592', 'DCNN', TO_DATE('01/01/1971', 'DD/MM/YYYY'), 'NCM', 
    11601, TO_DATE('02/04/2001', 'DD/MM/YYYY'), TO_DATE('01/08/2001', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (542962, '5592', 'DCNN', TO_DATE('01/01/1971', 'DD/MM/YYYY'), 'NCM', 
    13012, TO_DATE('02/09/1982', 'DD/MM/YYYY'), TO_DATE('26/02/1997', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (405968, '5592', 'DCNN', TO_DATE('01/01/1971', 'DD/MM/YYYY'), 'NCM', 
    12536, TO_DATE('01/01/1995', 'DD/MM/YYYY'), TO_DATE('29/06/2003', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (405969, '5592', 'DCNN', TO_DATE('01/01/1971', 'DD/MM/YYYY'), 'NCM', 
    20562, TO_DATE('01/04/1980', 'DD/MM/YYYY'), TO_DATE('07/12/1981', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (405973, '5592', 'DCNN', TO_DATE('01/01/1971', 'DD/MM/YYYY'), 'NCM', 
    14032, TO_DATE('01/01/1971', 'DD/MM/YYYY'), TO_DATE('31/03/2002', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (405979, '5592', 'DCNN', TO_DATE('01/01/1971', 'DD/MM/YYYY'), 'NCM', 
    13012, TO_DATE('01/01/1971', 'DD/MM/YYYY'), TO_DATE('30/06/1978', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (542970, '5592', 'DCNN', TO_DATE('01/01/1971', 'DD/MM/YYYY'), 'NCM', 
    20562, TO_DATE('30/12/1981', 'DD/MM/YYYY'), TO_DATE('05/02/1986', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (542971, '5592', 'DCNN', TO_DATE('01/01/1971', 'DD/MM/YYYY'), 'NCM', 
    20562, TO_DATE('07/03/1986', 'DD/MM/YYYY'), TO_DATE('10/01/1987', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (542972, '5592', 'DCNN', TO_DATE('01/01/1971', 'DD/MM/YYYY'), 'NCM', 
    20562, TO_DATE('07/02/1987', 'DD/MM/YYYY'), TO_DATE('09/09/1999', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (542976, '5592', 'DCNN', TO_DATE('01/01/1971', 'DD/MM/YYYY'), 'NCM', 
    35194, TO_DATE('02/11/1983', 'DD/MM/YYYY'), TO_DATE('02/05/1988', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (542977, '5592', 'DCNN', TO_DATE('01/01/1971', 'DD/MM/YYYY'), 'NCM', 
    35194, TO_DATE('30/03/1992', 'DD/MM/YYYY'), TO_DATE('29/06/2003', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (542979, '5592', 'DCNN', TO_DATE('01/01/1971', 'DD/MM/YYYY'), 'NCM', 
    35195, TO_DATE('02/11/1983', 'DD/MM/YYYY'), TO_DATE('02/05/1988', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (542980, '5592', 'DCNN', TO_DATE('01/01/1971', 'DD/MM/YYYY'), 'NCM', 
    35195, TO_DATE('30/03/1992', 'DD/MM/YYYY'), TO_DATE('29/06/2003', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (542982, '5592', 'DCNN', TO_DATE('01/01/1971', 'DD/MM/YYYY'), 'NCM', 
    35212, TO_DATE('02/11/1983', 'DD/MM/YYYY'), TO_DATE('03/05/1988', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (542983, '5592', 'DCNN', TO_DATE('01/01/1971', 'DD/MM/YYYY'), 'NCM', 
    35212, TO_DATE('31/03/1992', 'DD/MM/YYYY'), TO_DATE('29/06/2003', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (542985, '5592', 'DCNN', TO_DATE('01/01/1971', 'DD/MM/YYYY'), 'NCM', 
    35213, TO_DATE('02/11/1983', 'DD/MM/YYYY'), TO_DATE('03/05/1988', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (542986, '5592', 'DCNN', TO_DATE('01/01/1971', 'DD/MM/YYYY'), 'NCM', 
    35213, TO_DATE('31/03/1992', 'DD/MM/YYYY'), TO_DATE('29/06/2003', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (542988, '5592', 'DCNN', TO_DATE('01/01/1971', 'DD/MM/YYYY'), 'NCM', 
    35222, TO_DATE('09/07/1983', 'DD/MM/YYYY'), TO_DATE('01/11/1983', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (542989, '5592', 'DCNN', TO_DATE('01/01/1971', 'DD/MM/YYYY'), 'NCM', 
    35222, TO_DATE('16/11/1987', 'DD/MM/YYYY'), TO_DATE('29/03/1992', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (542990, '5592', 'DCNN', TO_DATE('01/01/1971', 'DD/MM/YYYY'), 'NCM', 
    35222, TO_DATE('03/10/2002', 'DD/MM/YYYY'), TO_DATE('04/10/2002', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (542991, '5592', 'DCNN', TO_DATE('01/01/1971', 'DD/MM/YYYY'), 'NCM', 
    35224, TO_DATE('08/07/1983', 'DD/MM/YYYY'), TO_DATE('31/10/1983', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (542992, '5592', 'DCNN', TO_DATE('01/01/1971', 'DD/MM/YYYY'), 'NCM', 
    35224, TO_DATE('15/11/1987', 'DD/MM/YYYY'), TO_DATE('28/03/1992', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (542993, '5592', 'DCNN', TO_DATE('01/01/1971', 'DD/MM/YYYY'), 'NCM', 
    35224, TO_DATE('03/10/2002', 'DD/MM/YYYY'), TO_DATE('04/10/2002', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (407355, '5592', 'DCNN', TO_DATE('01/01/2001', 'DD/MM/YYYY'), 'SYNOP', 
    14034, TO_DATE('07/01/2001', 'DD/MM/YYYY'), TO_DATE('28/06/2003', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (404670, '559201', 'WIND', TO_DATE('01/04/1993', 'DD/MM/YYYY'), 'HCM', 
    11523, TO_DATE('28/04/1993', 'DD/MM/YYYY'), TO_DATE('29/06/2003', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (404672, '559201', 'WIND', TO_DATE('01/04/1993', 'DD/MM/YYYY'), 'HCM', 
    35199, TO_DATE('28/04/1993', 'DD/MM/YYYY'), TO_DATE('29/06/2003', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (404674, '559201', 'WIND', TO_DATE('01/04/1993', 'DD/MM/YYYY'), 'HCM', 
    11521, TO_DATE('28/04/1993', 'DD/MM/YYYY'), TO_DATE('29/06/2003', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (404676, '559201', 'WIND', TO_DATE('01/04/1993', 'DD/MM/YYYY'), 'HCM', 
    11012, TO_DATE('28/04/1993', 'DD/MM/YYYY'), TO_DATE('29/06/2003', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (404680, '559201', 'WIND', TO_DATE('01/04/1993', 'DD/MM/YYYY'), 'HCM', 
    11511, TO_DATE('28/04/1993', 'DD/MM/YYYY'), TO_DATE('29/06/2003', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (542925, '559201', 'WIND', TO_DATE('01/04/1993', 'DD/MM/YYYY'), 'HCM', 
    35199, TO_DATE('01/04/1993', 'DD/MM/YYYY'), TO_DATE('06/04/1993', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (542915, '559201', 'WIND', TO_DATE('01/04/1993', 'DD/MM/YYYY'), 'HCM', 
    11012, TO_DATE('01/04/1993', 'DD/MM/YYYY'), TO_DATE('06/04/1993', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (542917, '559201', 'WIND', TO_DATE('01/04/1993', 'DD/MM/YYYY'), 'HCM', 
    11511, TO_DATE('01/04/1993', 'DD/MM/YYYY'), TO_DATE('06/04/1993', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (542919, '559201', 'WIND', TO_DATE('01/04/1993', 'DD/MM/YYYY'), 'HCM', 
    11521, TO_DATE('01/04/1993', 'DD/MM/YYYY'), TO_DATE('06/04/1993', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (542921, '559201', 'WIND', TO_DATE('01/04/1993', 'DD/MM/YYYY'), 'HCM', 
    11523, TO_DATE('01/04/1993', 'DD/MM/YYYY'), TO_DATE('06/04/1993', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (542946, '559201', 'WIND', TO_DATE('01/04/1993', 'DD/MM/YYYY'), 'HWND6910', 
    11523, TO_DATE('27/08/1997', 'DD/MM/YYYY'), TO_DATE('30/10/1997', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (542947, '559201', 'WIND', TO_DATE('01/04/1993', 'DD/MM/YYYY'), 'HWND6910', 
    11523, TO_DATE('13/01/1998', 'DD/MM/YYYY'), TO_DATE('21/02/1998', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (542948, '559201', 'WIND', TO_DATE('01/04/1993', 'DD/MM/YYYY'), 'HWND6910', 
    35199, TO_DATE('17/03/1997', 'DD/MM/YYYY'), TO_DATE('08/05/1997', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (542949, '559201', 'WIND', TO_DATE('01/04/1993', 'DD/MM/YYYY'), 'HWND6910', 
    35199, TO_DATE('18/07/1997', 'DD/MM/YYYY'), TO_DATE('31/07/1997', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (542950, '559201', 'WIND', TO_DATE('01/04/1993', 'DD/MM/YYYY'), 'HWND6910', 
    35199, TO_DATE('27/08/1997', 'DD/MM/YYYY'), TO_DATE('30/10/1997', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (542951, '559201', 'WIND', TO_DATE('01/04/1993', 'DD/MM/YYYY'), 'HWND6910', 
    35199, TO_DATE('13/01/1998', 'DD/MM/YYYY'), TO_DATE('21/02/1998', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (405377, '559201', 'WIND', TO_DATE('01/04/1993', 'DD/MM/YYYY'), 'HWND6910', 
    11521, TO_DATE('08/06/1997', 'DD/MM/YYYY'), TO_DATE('19/06/1997', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (405380, '559201', 'WIND', TO_DATE('01/04/1993', 'DD/MM/YYYY'), 'HWND6910', 
    11521, TO_DATE('25/11/1997', 'DD/MM/YYYY'), TO_DATE('27/11/1997', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (405383, '559201', 'WIND', TO_DATE('01/04/1993', 'DD/MM/YYYY'), 'HWND6910', 
    11012, TO_DATE('08/06/1997', 'DD/MM/YYYY'), TO_DATE('19/06/1997', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (405386, '559201', 'WIND', TO_DATE('01/04/1993', 'DD/MM/YYYY'), 'HWND6910', 
    11012, TO_DATE('25/11/1997', 'DD/MM/YYYY'), TO_DATE('27/11/1997', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (405389, '559201', 'WIND', TO_DATE('01/04/1993', 'DD/MM/YYYY'), 'HWND6910', 
    11511, TO_DATE('08/06/1997', 'DD/MM/YYYY'), TO_DATE('19/06/1997', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (405392, '559201', 'WIND', TO_DATE('01/04/1993', 'DD/MM/YYYY'), 'HWND6910', 
    11511, TO_DATE('25/11/1997', 'DD/MM/YYYY'), TO_DATE('27/11/1997', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (405365, '559201', 'WIND', TO_DATE('01/04/1993', 'DD/MM/YYYY'), 'HWND6910', 
    11523, TO_DATE('08/06/1997', 'DD/MM/YYYY'), TO_DATE('19/06/1997', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (405368, '559201', 'WIND', TO_DATE('01/04/1993', 'DD/MM/YYYY'), 'HWND6910', 
    11523, TO_DATE('25/11/1997', 'DD/MM/YYYY'), TO_DATE('27/11/1997', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (405371, '559201', 'WIND', TO_DATE('01/04/1993', 'DD/MM/YYYY'), 'HWND6910', 
    35199, TO_DATE('08/06/1997', 'DD/MM/YYYY'), TO_DATE('19/06/1997', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (405374, '559201', 'WIND', TO_DATE('01/04/1993', 'DD/MM/YYYY'), 'HWND6910', 
    35199, TO_DATE('25/11/1997', 'DD/MM/YYYY'), TO_DATE('27/11/1997', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (542936, '559201', 'WIND', TO_DATE('01/04/1993', 'DD/MM/YYYY'), 'HWND6910', 
    11012, TO_DATE('13/01/1998', 'DD/MM/YYYY'), TO_DATE('21/02/1998', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (542937, '559201', 'WIND', TO_DATE('01/04/1993', 'DD/MM/YYYY'), 'HWND6910', 
    11511, TO_DATE('17/03/1997', 'DD/MM/YYYY'), TO_DATE('08/05/1997', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (542938, '559201', 'WIND', TO_DATE('01/04/1993', 'DD/MM/YYYY'), 'HWND6910', 
    11511, TO_DATE('18/07/1997', 'DD/MM/YYYY'), TO_DATE('31/07/1997', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (542933, '559201', 'WIND', TO_DATE('01/04/1993', 'DD/MM/YYYY'), 'HWND6910', 
    11012, TO_DATE('17/03/1997', 'DD/MM/YYYY'), TO_DATE('08/05/1997', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (542934, '559201', 'WIND', TO_DATE('01/04/1993', 'DD/MM/YYYY'), 'HWND6910', 
    11012, TO_DATE('18/07/1997', 'DD/MM/YYYY'), TO_DATE('31/07/1997', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (542939, '559201', 'WIND', TO_DATE('01/04/1993', 'DD/MM/YYYY'), 'HWND6910', 
    11511, TO_DATE('27/08/1997', 'DD/MM/YYYY'), TO_DATE('30/10/1997', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (542940, '559201', 'WIND', TO_DATE('01/04/1993', 'DD/MM/YYYY'), 'HWND6910', 
    11511, TO_DATE('13/01/1998', 'DD/MM/YYYY'), TO_DATE('21/02/1998', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (542942, '559201', 'WIND', TO_DATE('01/04/1993', 'DD/MM/YYYY'), 'HWND6910', 
    11521, TO_DATE('17/03/1997', 'DD/MM/YYYY'), TO_DATE('08/05/1997', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (542943, '559201', 'WIND', TO_DATE('01/04/1993', 'DD/MM/YYYY'), 'HWND6910', 
    11521, TO_DATE('27/08/1997', 'DD/MM/YYYY'), TO_DATE('30/10/1997', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (542935, '559201', 'WIND', TO_DATE('01/04/1993', 'DD/MM/YYYY'), 'HWND6910', 
    11012, TO_DATE('27/08/1997', 'DD/MM/YYYY'), TO_DATE('30/10/1997', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (542944, '559201', 'WIND', TO_DATE('01/04/1993', 'DD/MM/YYYY'), 'HWND6910', 
    11521, TO_DATE('13/01/1998', 'DD/MM/YYYY'), TO_DATE('21/02/1998', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (542945, '559201', 'WIND', TO_DATE('01/04/1993', 'DD/MM/YYYY'), 'HWND6910', 
    11523, TO_DATE('21/03/1997', 'DD/MM/YYYY'), TO_DATE('08/05/1997', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62473, '61901', 'WMO', TO_DATE('01/01/1976', 'DD/MM/YYYY'), 'SYNOP', 
    10052, TO_DATE('01/01/1976', 'DD/MM/YYYY'), TO_DATE('30/08/1976', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62475, '61901', 'WMO', TO_DATE('01/01/1976', 'DD/MM/YYYY'), 'SYNOP', 
    11010, TO_DATE('01/01/1976', 'DD/MM/YYYY'), TO_DATE('30/08/1976', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62477, '61901', 'WMO', TO_DATE('01/01/1976', 'DD/MM/YYYY'), 'SYNOP', 
    11512, TO_DATE('01/01/1976', 'DD/MM/YYYY'), TO_DATE('30/08/1976', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62481, '61901', 'WMO', TO_DATE('01/01/1976', 'DD/MM/YYYY'), 'SYNOP', 
    12004, TO_DATE('01/01/1976', 'DD/MM/YYYY'), TO_DATE('30/08/1976', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62484, '61901', 'WMO', TO_DATE('01/01/1976', 'DD/MM/YYYY'), 'SYNOP', 
    12006, TO_DATE('01/01/1976', 'DD/MM/YYYY'), TO_DATE('30/08/1976', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62485, '61901', 'WMO', TO_DATE('01/01/1976', 'DD/MM/YYYY'), 'SYNOP', 
    12602, TO_DATE('01/01/1976', 'DD/MM/YYYY'), TO_DATE('30/08/1976', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62487, '61901', 'WMO', TO_DATE('01/01/1976', 'DD/MM/YYYY'), 'SYNOP', 
    20001, TO_DATE('01/01/1976', 'DD/MM/YYYY'), TO_DATE('30/08/1976', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62490, '61901', 'WMO', TO_DATE('01/01/1976', 'DD/MM/YYYY'), 'SYNOP', 
    20003, TO_DATE('01/01/1976', 'DD/MM/YYYY'), TO_DATE('30/08/1976', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62492, '61901', 'WMO', TO_DATE('01/01/1976', 'DD/MM/YYYY'), 'SYNOP', 
    20004, TO_DATE('01/01/1976', 'DD/MM/YYYY'), TO_DATE('30/08/1976', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62495, '61901', 'WMO', TO_DATE('01/01/1976', 'DD/MM/YYYY'), 'SYNOP', 
    20010, TO_DATE('01/01/1976', 'DD/MM/YYYY'), TO_DATE('30/08/1976', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62496, '61901', 'WMO', TO_DATE('01/01/1976', 'DD/MM/YYYY'), 'SYNOP', 
    20011, TO_DATE('01/01/1976', 'DD/MM/YYYY'), TO_DATE('30/08/1976', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62497, '61901', 'WMO', TO_DATE('01/01/1976', 'DD/MM/YYYY'), 'SYNOP', 
    20012, TO_DATE('01/01/1976', 'DD/MM/YYYY'), TO_DATE('30/08/1976', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62498, '61901', 'WMO', TO_DATE('01/01/1976', 'DD/MM/YYYY'), 'SYNOP', 
    20013, TO_DATE('01/01/1976', 'DD/MM/YYYY'), TO_DATE('30/08/1976', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62499, '61901', 'WMO', TO_DATE('01/01/1976', 'DD/MM/YYYY'), 'SYNOP', 
    20062, TO_DATE('01/01/1976', 'DD/MM/YYYY'), TO_DATE('30/08/1976', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62500, '61901', 'WMO', TO_DATE('01/01/1976', 'DD/MM/YYYY'), 'SYNOP', 
    20511, TO_DATE('01/01/1976', 'DD/MM/YYYY'), TO_DATE('30/08/1976', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62503, '61901', 'WMO', TO_DATE('01/01/1976', 'DD/MM/YYYY'), 'SYNOP', 
    20551, TO_DATE('01/01/1976', 'DD/MM/YYYY'), TO_DATE('30/08/1976', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62504, '61901', 'WMO', TO_DATE('01/01/1976', 'DD/MM/YYYY'), 'SYNOP', 
    20552, TO_DATE('01/01/1976', 'DD/MM/YYYY'), TO_DATE('28/08/1976', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62505, '61901', 'WMO', TO_DATE('01/01/1976', 'DD/MM/YYYY'), 'SYNOP', 
    20553, TO_DATE('01/01/1976', 'DD/MM/YYYY'), TO_DATE('28/08/1976', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62506, '61901', 'WMO', TO_DATE('01/01/1976', 'DD/MM/YYYY'), 'SYNOP', 
    20002, TO_DATE('05/01/1976', 'DD/MM/YYYY'), TO_DATE('30/08/1976', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62507, '61901', 'WMO', TO_DATE('01/01/1976', 'DD/MM/YYYY'), 'SYNOP', 
    20014, TO_DATE('01/01/1976', 'DD/MM/YYYY'), TO_DATE('28/08/1976', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62508, '61901', 'WMO', TO_DATE('01/01/1976', 'DD/MM/YYYY'), 'SYNOP', 
    20015, TO_DATE('01/01/1976', 'DD/MM/YYYY'), TO_DATE('28/08/1976', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62509, '61901', 'WMO', TO_DATE('01/01/1976', 'DD/MM/YYYY'), 'SYNOP', 
    20016, TO_DATE('01/01/1976', 'DD/MM/YYYY'), TO_DATE('28/08/1976', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62510, '61901', 'WMO', TO_DATE('01/01/1976', 'DD/MM/YYYY'), 'SYNOP', 
    20017, TO_DATE('17/07/1976', 'DD/MM/YYYY'), TO_DATE('17/07/1976', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62511, '61901', 'WMO', TO_DATE('01/01/1976', 'DD/MM/YYYY'), 'SYNOP', 
    20018, TO_DATE('17/07/1976', 'DD/MM/YYYY'), TO_DATE('17/07/1976', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62512, '61901', 'WMO', TO_DATE('01/01/1976', 'DD/MM/YYYY'), 'SYNOP', 
    20019, TO_DATE('17/07/1976', 'DD/MM/YYYY'), TO_DATE('17/07/1976', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62527, '61901', 'WMO', TO_DATE('01/09/1976', 'DD/MM/YYYY'), 'SYNOP', 
    10051, TO_DATE('01/09/1976', 'DD/MM/YYYY'), TO_DATE('31/12/3999', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62528, '61901', 'WMO', TO_DATE('01/09/1976', 'DD/MM/YYYY'), 'SYNOP', 
    10052, TO_DATE('16/12/1999', 'DD/MM/YYYY'), TO_DATE('06/03/2001', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62529, '61901', 'WMO', TO_DATE('01/09/1976', 'DD/MM/YYYY'), 'SYNOP', 
    11010, TO_DATE('01/09/1976', 'DD/MM/YYYY'), TO_DATE('31/12/3999', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62530, '61901', 'WMO', TO_DATE('01/09/1976', 'DD/MM/YYYY'), 'SYNOP', 
    11512, TO_DATE('01/09/1976', 'DD/MM/YYYY'), TO_DATE('31/12/3999', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62531, '61901', 'WMO', TO_DATE('01/09/1976', 'DD/MM/YYYY'), 'SYNOP', 
    11041, TO_DATE('21/01/1998', 'DD/MM/YYYY'), TO_DATE('21/01/1998', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62532, '61901', 'WMO', TO_DATE('01/09/1976', 'DD/MM/YYYY'), 'SYNOP', 
    12004, TO_DATE('01/09/1976', 'DD/MM/YYYY'), TO_DATE('31/12/3999', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62533, '61901', 'WMO', TO_DATE('01/09/1976', 'DD/MM/YYYY'), 'SYNOP', 
    12006, TO_DATE('01/09/1976', 'DD/MM/YYYY'), TO_DATE('31/12/3999', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62534, '61901', 'WMO', TO_DATE('01/09/1976', 'DD/MM/YYYY'), 'SYNOP', 
    12602, TO_DATE('01/09/1976', 'DD/MM/YYYY'), TO_DATE('31/12/3999', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62535, '61901', 'WMO', TO_DATE('01/09/1976', 'DD/MM/YYYY'), 'SYNOP', 
    20001, TO_DATE('01/09/1976', 'DD/MM/YYYY'), TO_DATE('31/12/3999', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62536, '61901', 'WMO', TO_DATE('01/09/1976', 'DD/MM/YYYY'), 'SYNOP', 
    20003, TO_DATE('01/09/1976', 'DD/MM/YYYY'), TO_DATE('31/12/3999', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62537, '61901', 'WMO', TO_DATE('01/09/1976', 'DD/MM/YYYY'), 'SYNOP', 
    20004, TO_DATE('01/09/1976', 'DD/MM/YYYY'), TO_DATE('31/12/3999', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62538, '61901', 'WMO', TO_DATE('01/09/1976', 'DD/MM/YYYY'), 'SYNOP', 
    20005, TO_DATE('01/01/1982', 'DD/MM/YYYY'), TO_DATE('31/12/3999', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62539, '61901', 'WMO', TO_DATE('01/09/1976', 'DD/MM/YYYY'), 'SYNOP', 
    20010, TO_DATE('01/09/1976', 'DD/MM/YYYY'), TO_DATE('31/12/3999', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62540, '61901', 'WMO', TO_DATE('01/09/1976', 'DD/MM/YYYY'), 'SYNOP', 
    20011, TO_DATE('01/09/1976', 'DD/MM/YYYY'), TO_DATE('31/12/3999', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62541, '61901', 'WMO', TO_DATE('01/09/1976', 'DD/MM/YYYY'), 'SYNOP', 
    20012, TO_DATE('01/09/1976', 'DD/MM/YYYY'), TO_DATE('31/12/3999', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62542, '61901', 'WMO', TO_DATE('01/09/1976', 'DD/MM/YYYY'), 'SYNOP', 
    20013, TO_DATE('01/09/1976', 'DD/MM/YYYY'), TO_DATE('31/12/3999', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62543, '61901', 'WMO', TO_DATE('01/09/1976', 'DD/MM/YYYY'), 'SYNOP', 
    20062, TO_DATE('01/09/1976', 'DD/MM/YYYY'), TO_DATE('07/01/2000', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62544, '61901', 'WMO', TO_DATE('01/09/1976', 'DD/MM/YYYY'), 'SYNOP', 
    20511, TO_DATE('01/09/1976', 'DD/MM/YYYY'), TO_DATE('31/12/3999', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62545, '61901', 'WMO', TO_DATE('01/09/1976', 'DD/MM/YYYY'), 'SYNOP', 
    20512, TO_DATE('01/01/1994', 'DD/MM/YYYY'), TO_DATE('31/12/3999', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62546, '61901', 'WMO', TO_DATE('01/09/1976', 'DD/MM/YYYY'), 'SYNOP', 
    20551, TO_DATE('01/09/1976', 'DD/MM/YYYY'), TO_DATE('31/12/3999', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62547, '61901', 'WMO', TO_DATE('01/09/1976', 'DD/MM/YYYY'), 'SYNOP', 
    20552, TO_DATE('01/09/1976', 'DD/MM/YYYY'), TO_DATE('31/12/3999', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62548, '61901', 'WMO', TO_DATE('01/09/1976', 'DD/MM/YYYY'), 'SYNOP', 
    20553, TO_DATE('06/09/1976', 'DD/MM/YYYY'), TO_DATE('31/12/3999', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62549, '61901', 'WMO', TO_DATE('01/09/1976', 'DD/MM/YYYY'), 'SYNOP', 
    20002, TO_DATE('02/09/1976', 'DD/MM/YYYY'), TO_DATE('31/12/3999', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62550, '61901', 'WMO', TO_DATE('01/09/1976', 'DD/MM/YYYY'), 'SYNOP', 
    20014, TO_DATE('01/09/1976', 'DD/MM/YYYY'), TO_DATE('31/12/3999', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62551, '61901', 'WMO', TO_DATE('01/09/1976', 'DD/MM/YYYY'), 'SYNOP', 
    20015, TO_DATE('01/09/1976', 'DD/MM/YYYY'), TO_DATE('31/12/3999', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62552, '61901', 'WMO', TO_DATE('01/09/1976', 'DD/MM/YYYY'), 'SYNOP', 
    20016, TO_DATE('01/09/1976', 'DD/MM/YYYY'), TO_DATE('31/12/3999', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62553, '61901', 'WMO', TO_DATE('01/09/1976', 'DD/MM/YYYY'), 'SYNOP', 
    20017, TO_DATE('03/09/1976', 'DD/MM/YYYY'), TO_DATE('31/12/3999', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62554, '61901', 'WMO', TO_DATE('01/09/1976', 'DD/MM/YYYY'), 'SYNOP', 
    20018, TO_DATE('03/09/1976', 'DD/MM/YYYY'), TO_DATE('31/12/3999', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62555, '61901', 'WMO', TO_DATE('01/09/1976', 'DD/MM/YYYY'), 'SYNOP', 
    20019, TO_DATE('03/09/1976', 'DD/MM/YYYY'), TO_DATE('31/12/3999', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62459, '9884', 'DCNN', TO_DATE('01/01/1962', 'DD/MM/YYYY'), 'NCM', 
    11601, TO_DATE('01/01/1962', 'DD/MM/YYYY'), TO_DATE('30/08/1976', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62460, '9884', 'DCNN', TO_DATE('01/01/1962', 'DD/MM/YYYY'), 'NCM', 
    35222, TO_DATE('01/01/1962', 'DD/MM/YYYY'), TO_DATE('30/08/1976', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62461, '9884', 'DCNN', TO_DATE('01/01/1962', 'DD/MM/YYYY'), 'NCM', 
    35224, TO_DATE('01/01/1962', 'DD/MM/YYYY'), TO_DATE('30/08/1976', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62462, '9884', 'DCNN', TO_DATE('01/01/1962', 'DD/MM/YYYY'), 'NCM', 
    35194, TO_DATE('01/01/1962', 'DD/MM/YYYY'), TO_DATE('30/08/1976', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62463, '9884', 'DCNN', TO_DATE('01/01/1962', 'DD/MM/YYYY'), 'NCM', 
    35195, TO_DATE('01/01/1962', 'DD/MM/YYYY'), TO_DATE('30/08/1976', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62464, '9884', 'DCNN', TO_DATE('01/01/1962', 'DD/MM/YYYY'), 'NCM', 
    35212, TO_DATE('01/01/1962', 'DD/MM/YYYY'), TO_DATE('30/08/1976', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62465, '9884', 'DCNN', TO_DATE('01/01/1962', 'DD/MM/YYYY'), 'NCM', 
    35213, TO_DATE('01/01/1962', 'DD/MM/YYYY'), TO_DATE('30/08/1976', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62466, '9884', 'DCNN', TO_DATE('01/01/1962', 'DD/MM/YYYY'), 'NCM', 
    13013, TO_DATE('01/05/1964', 'DD/MM/YYYY'), TO_DATE('30/08/1976', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62467, '9884', 'DCNN', TO_DATE('01/01/1962', 'DD/MM/YYYY'), 'NCM', 
    13601, TO_DATE('01/01/1962', 'DD/MM/YYYY'), TO_DATE('30/08/1976', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62469, '9884', 'DCNN', TO_DATE('01/01/1962', 'DD/MM/YYYY'), 'NCM', 
    13602, TO_DATE('01/01/1962', 'DD/MM/YYYY'), TO_DATE('30/08/1976', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62470, '9884', 'DCNN', TO_DATE('01/01/1962', 'DD/MM/YYYY'), 'NCM', 
    20601, TO_DATE('01/01/1962', 'DD/MM/YYYY'), TO_DATE('30/08/1976', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62513, '9885', 'DCNN', TO_DATE('01/01/1994', 'DD/MM/YYYY'), 'HSUN3445', 
    14031, TO_DATE('01/01/1994', 'DD/MM/YYYY'), TO_DATE('30/06/2001', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62514, '9885', 'DCNN', TO_DATE('01/09/1976', 'DD/MM/YYYY'), 'NCM', 
    11601, TO_DATE('01/09/1976', 'DD/MM/YYYY'), TO_DATE('29/04/1990', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62515, '9885', 'DCNN', TO_DATE('01/09/1976', 'DD/MM/YYYY'), 'NCM', 
    12013, TO_DATE('01/01/1977', 'DD/MM/YYYY'), TO_DATE('29/04/1990', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62516, '9885', 'DCNN', TO_DATE('01/09/1976', 'DD/MM/YYYY'), 'NCM', 
    35222, TO_DATE('01/09/1976', 'DD/MM/YYYY'), TO_DATE('29/04/1990', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62517, '9885', 'DCNN', TO_DATE('01/09/1976', 'DD/MM/YYYY'), 'NCM', 
    35224, TO_DATE('01/09/1976', 'DD/MM/YYYY'), TO_DATE('29/04/1990', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62518, '9885', 'DCNN', TO_DATE('01/09/1976', 'DD/MM/YYYY'), 'NCM', 
    35194, TO_DATE('01/09/1976', 'DD/MM/YYYY'), TO_DATE('29/04/1990', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62519, '9885', 'DCNN', TO_DATE('01/09/1976', 'DD/MM/YYYY'), 'NCM', 
    35195, TO_DATE('01/09/1976', 'DD/MM/YYYY'), TO_DATE('29/04/1990', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62520, '9885', 'DCNN', TO_DATE('01/09/1976', 'DD/MM/YYYY'), 'NCM', 
    35212, TO_DATE('01/09/1976', 'DD/MM/YYYY'), TO_DATE('29/04/1990', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62521, '9885', 'DCNN', TO_DATE('01/09/1976', 'DD/MM/YYYY'), 'NCM', 
    35213, TO_DATE('01/09/1976', 'DD/MM/YYYY'), TO_DATE('29/04/1990', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62522, '9885', 'DCNN', TO_DATE('01/09/1976', 'DD/MM/YYYY'), 'NCM', 
    13013, TO_DATE('01/09/1976', 'DD/MM/YYYY'), TO_DATE('29/04/1990', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62523, '9885', 'DCNN', TO_DATE('01/09/1976', 'DD/MM/YYYY'), 'NCM', 
    13601, TO_DATE('01/09/1976', 'DD/MM/YYYY'), TO_DATE('29/04/1990', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62524, '9885', 'DCNN', TO_DATE('01/09/1976', 'DD/MM/YYYY'), 'NCM', 
    13602, TO_DATE('01/09/1976', 'DD/MM/YYYY'), TO_DATE('29/04/1990', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62525, '9885', 'DCNN', TO_DATE('01/09/1976', 'DD/MM/YYYY'), 'NCM', 
    14032, TO_DATE('01/08/1977', 'DD/MM/YYYY'), TO_DATE('29/04/1990', 'DD/MM/YYYY'));
Insert into STATION_REPORT_ELEMENT
   (STN_RPT_ELEM_ID, ID, ID_TYPE, SRC_CAP_BGN_DATE, MET_DOMAIN_NAME, 
    MET_ELEMENT_ID, RPT_ELEM_BGN_DATE, RPT_ELEM_END_DATE)
 Values
   (62526, '9885', 'DCNN', TO_DATE('01/09/1976', 'DD/MM/YYYY'), 'NCM', 
    20601, TO_DATE('01/09/1976', 'DD/MM/YYYY'), TO_DATE('29/04/1990', 'DD/MM/YYYY'));
COMMIT;
Insert into STATION_ROLE
   (SRC_ID, ROLE_NAME_CODE, ROLE_BGN_DATE, ROLE_END_DATE)
 Values
   (838, 'OCLIM', TO_DATE('01/01/1965', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'));
Insert into STATION_ROLE
   (SRC_ID, ROLE_NAME_CODE, ROLE_BGN_DATE, ROLE_END_DATE)
 Values
   (838, 'PCLIM', TO_DATE('01/01/1965', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'));
Insert into STATION_ROLE
   (SRC_ID, ROLE_NAME_CODE, ROLE_BGN_DATE, ROLE_END_DATE)
 Values
   (838, 'SUPP', TO_DATE('01/01/1965', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'));
Insert into STATION_ROLE
   (SRC_ID, ROLE_NAME_CODE, ROLE_BGN_DATE, ROLE_END_DATE)
 Values
   (838, 'COLD_WX', TO_DATE('01/01/1965', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'));
Insert into STATION_ROLE
   (SRC_ID, ROLE_NAME_CODE, ROLE_BGN_DATE, ROLE_END_DATE)
 Values
   (838, 'EWP', TO_DATE('01/01/1965', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'));
Insert into STATION_ROLE
   (SRC_ID, ROLE_NAME_CODE, ROLE_BGN_DATE, ROLE_END_DATE)
 Values
   (1605, 'SMISSING', TO_DATE('09/08/2005', 'DD/MM/YYYY'), TO_DATE('31/12/3999', 'DD/MM/YYYY'));
Insert into STATION_ROLE
   (SRC_ID, ROLE_NAME_CODE, ROLE_BGN_DATE, ROLE_END_DATE)
 Values
   (1605, 'NMISSING', TO_DATE('09/08/2005', 'DD/MM/YYYY'), TO_DATE('31/12/3999', 'DD/MM/YYYY'));
Insert into STATION_ROLE
   (SRC_ID, ROLE_NAME_CODE, ROLE_BGN_DATE, ROLE_END_DATE)
 Values
   (1605, 'HMISSING', TO_DATE('09/08/2005', 'DD/MM/YYYY'), TO_DATE('31/12/3999', 'DD/MM/YYYY'));
Insert into STATION_ROLE
   (SRC_ID, ROLE_NAME_CODE, ROLE_BGN_DATE, ROLE_END_DATE)
 Values
   (1605, 'RMISSING', TO_DATE('09/08/2005', 'DD/MM/YYYY'), TO_DATE('31/12/3999', 'DD/MM/YYYY'));
Insert into STATION_ROLE
   (SRC_ID, ROLE_NAME_CODE, ROLE_BGN_DATE, ROLE_END_DATE)
 Values
   (1605, 'GNS MMS_B', TO_DATE('01/11/2017', 'DD/MM/YYYY'), TO_DATE('31/12/3999', 'DD/MM/YYYY'));
COMMIT;
Insert into STATION_STATUS
   (STATUS_CODE, SRC_ID, STATUS_BGN_DATE, STATUS_END_DATE)
 Values
   ('CLSD', 838, TO_DATE('01/01/1965', 'DD/MM/YYYY'), TO_DATE('30/06/2003', 'DD/MM/YYYY'));
Insert into STATION_STATUS
   (STATUS_CODE, SRC_ID, STATUS_BGN_DATE, STATUS_END_DATE)
 Values
   ('CLSD', 1604, TO_DATE('01/01/1925', 'DD/MM/YYYY'), TO_DATE('31/12/1976', 'DD/MM/YYYY'));
Insert into STATION_STATUS
   (STATUS_CODE, SRC_ID, STATUS_BGN_DATE, STATUS_END_DATE)
 Values
   ('OPEN', 1605, TO_DATE('01/01/1958', 'DD/MM/YYYY'), TO_DATE('31/12/3999', 'DD/MM/YYYY'));
COMMIT;
